      function bilin (ix,iy,x,y,f,im,jm)
c
c=======================================================================
c                                                                    ===
c  This routine performs a 16-point cubic bessel interpolation at    ===
c  the grid locations X and Y from a regularly grided 2-D field F.   ===
c                                                                    ===
c     On Input:                                                      ===
c                                                                    ===
c     F        field to interpolate from (real array)                ===
c     IM, JM   first and second dimensions of F (integer)            ===
c     IX, IY   SW corner  grid position (grid units; integer)        ===
c     X, Y     position in the box (grid units; real)                ===
c     On Output:                                                     ===
c                                                                    ===
c     BILIN    interpolated value  (real)                            ===
c                                                                    ===
c     Calls:      none                                               ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i1,i2,im,ix,iy,j1,j2,jm
      FLOAT
     *      f1,f2,x,y
      FLOAT
     *      bilin
      FLOAT
     *      f(im,jm)
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Get the indices for the 2 x 2 raw data window.
c-----------------------------------------------------------------------
c
      i1=ix
      i2=ix+1
      j1=iy
      j2=iy+1
c
c-----------------------------------------------------------------------
c  Achieve the two-dimensional interpolation by a series of
c  one-dimensional linear interpolations.
c-----------------------------------------------------------------------
c
      f1=(c1-y)*f(i1,j1) + y*f(i1,j2)
      f2=(c1-y)*f(i2,j1) + y*f(i2,j2)
      bilin=(c1-x)*f1 + x*f2
c
      return
      end

