      subroutine expand_depth
c
c=======================================================================
c                                                                    ===
c  This routine sets the depths at the tracers (T,S)  and velocity   ===
c  (u,v) points. These depths are used to interpolate these fields   ===
c  to hybrid (topography-following) coordinates.                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fields.h>
#include <vertical.h>
#include <scalar.h>
#include <vertslabs.h>
#include <fieldsbar.h>
#include <workspb.h>
#if defined shapiro & defined filtetat
# include <filtdat.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j
#ifndef barotropic
     &        ,k
#endif
#if defined shapiro & defined filtetat
     &        ,nn
#endif
      FLOAT
     &     fac1
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Set free surface at the T points.
c
      fac1=c1/grav
      do 100 j=1,jmt
      do 100 i=1,imt
#ifdef limpstshap
         etatbb(i,j)=etatb(i,j)
#endif
#if defined oias | defined nest2smaller | defined nest2larger
         etatb(i,j) = fac1*pb(i,j)
#else
         etatb(i,j) = etat(i,j)
#endif
         etat(i,j)=fac1*p(i,j)
         detat(i,j)=ptd(i,j)*fac1
#if defined scaltsunflt | defined scaluvunflt
         etatuf(i,j)=fac1*punflt(i,j)
#endif
 100  continue
c
#if defined shapiro & defined filtetat
c  Shapiro filter free surface at the T points.
c
      icntp=icntp+1
      if(icntp.eq.nfrqp)then
        icntp=0
        if(nordp.gt.0)then
          do 110 nn=1,ntimp
# if defined oias | defined nest2smaller | defined nest2larger
            call shap_lev(etatb,imt,jmt,pgrid,nordp)
# endif
            call shap_lev(etat,imt,jmt,pgrid,nordp)
 110      continue
        endif
      endif
c
#endif
c  Set free surface at the U-V points.
c
      do 130 j=1,jmtm1
        do 120 i=1,imtm1
#if defined oias | defined nest2smaller | defined nest2larger | defined spngtimavgBC
          etavb(i,j)=p25*
     *          (etatb(i,j)+etatb(i+1,j)+etatb(i,j+1)+etatb(i+1,j+1))
#else
          etavb(i,j)=etav(i,j)
#endif
          etav(i,j)=p25*
     *          (etat(i,j)+etat(i+1,j)+etat(i,j+1)+etat(i+1,j+1))
          detav(i,j)=p25*
     *      (detat(i,j)+detat(i+1,j)+detat(i,j+1)+detat(i+1,j+1))
#if defined scaluvunflt
          etavuf(i,j)=p25*
     *         (etatuf(i,j)+etatuf(i+1,j)+etatuf(i,j+1)+etatuf(i+1,j+1))
         fracvuf(i,j)=c1+etavuf(i,j)/hdv(i,j)
#endif
 120    continue
#ifdef cyclic
        etav(1,j)=etav(imtm1,j)
        etav(imt,j)=etav(2,j)
        detav(1,j)=detav(imtm1,j)
        detav(imt,j)=detav(2,j)
        etavb(1,j)=etavb(imtm1,j)
        etavb(imt,j)=etavb(2,j)
#else
        etav(imt,j)=etav(imtm1,j)
        detav(imt,j)=detav(imtm1,j)
        etavb(imt,j)=etavb(imtm1,j)
#endif
 130  continue
      do 140 i=1,imt
        etav(i,jmt)=etav(i,jmtm1)
        detav(i,jmt)=detav(i,jmtm1)
        etavb(i,jmt)=etavb(i,jmtm1)
 140  continue
c
#ifdef detaavg
c  Reaverage detat from detav
c
      do 160 j=2,jmt
         do 150 i=2,imt
            detat(i,j)=p25*
     &        (detav(i,j)+detav(i-1,j)+detav(i,j-1)+detav(i-1,j-1))
 150     continue
# ifdef cyclic
         detat(1,j)=detat(imtm1,j)
         detat(imt,j)=detat(2,j)
# else
         detat(1,j)=p5*(detav(1,j)+detav(1,j-1))
# endif
 160  continue
      do 170 i=2,imt
         detat(i,1)=p5*(detav(i,1)+detav(i-1,1))
 170  continue
# ifdef cyclic
      detat(1,1)=detat(imtm1,1)
      detat(imt,1)=detat(2,1)
# else
      detat(1,1)=detav(1,1)
# endif
c
#endif
c-----------------------------------------------------------------------
c  Set the depths ratios at tracer and velocity points and the inverse
c  of bottom depth at v-points
c-----------------------------------------------------------------------
c
      do 200 j=1,jmt
      do 200 i=1,imt
#ifdef limpstshap
         fractbb(i,j)=fractb(i,j)
#endif
         fractb(i,j)=c1+etatb(i,j)/hd(i,j)
         fract(i,j)=c1+etat(i,j)/hd(i,j)
#if defined scaltsunflt
         fractuf(i,j)=c1+etatuf(i,j)/hd(i,j)
#endif
         fracvb(i,j)=c1+etavb(i,j)/hdv(i,j)
         fracv(i,j)=c1+etav(i,j)/hdv(i,j)
#if defined scaluvunflt
         fracvuf(i,j)=c1+etavuf(i,j)/hdv(i,j)
#endif
#if defined freesurf
         hdvbf(i,j)=hdv(i,j)+etavb(i,j)
# if defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05
         hdvbfx(i,j)=hdvbf(i,j)*uland(i,j)
         hdvbfy(i,j)=hdvbf(i,j)*vland(i,j)
# endif
         hdvbf(i,j)=hdvbf(i,j)*min(fkmq(i,j),c1)
#endif
         hdvcf(i,j)=hdv(i,j)+etav(i,j)
#if defined sprsnrm01
         hdvcfx(i,j)=hdvcf(i,j)*uland(i,j)
         hdvcfy(i,j)=hdvcf(i,j)*vland(i,j)
#endif
         hdvcf(i,j)=hdvcf(i,j)*min(fkmq(i,j),c1)
#if defined oias
         hvavb(i,j) = dzv(i,j,1)*fracvb(i,j)
#endif
         hvav(i,j) = dzv(i,j,1)*fracv(i,j)
#if defined smallpsdt & defined smallpsdt4
         ubaradv(i,j)  = ubaradv(i,j)/fracv(i,j)
         vbaradv(i,j)  = vbaradv(i,j)/fracv(i,j)
#endif
 200  continue
c
#ifndef barotropic
      do 210 k = 2, km
      do 210 j = 1, jmt
      do 210 i = 1, imt
         hvav(i,j) = hvav(i,j) + dzv(i,j,k)*fracv(i,j)
# if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
         hvavb(i,j) = hvavb(i,j) + dzv(i,j,k)*fracvb(i,j)
# endif
 210  continue
c
#endif
      do 220 j = 1, jmt
      do 220 i = 1, imt
         hvav(i,j) = c1/hvav(i,j)
#if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
         hvavb(i,j) = c1/hvavb(i,j)
#endif
 220  continue
c
      return
      end
