      subroutine expdpthic
c
c=======================================================================
c                                                                    ===
c  This routine sets the depths at the tracers (T,S)  and velocity   ===
c  (u,v) points. These depths are used to interpolate these fields   ===
c  to hybrid (topography-following) coordinates.                     ===
c                                                                    ===
c  This version is used as a quick-fix for the free-surface          ===
c  boot-strap initialization for PB.  The true fix would be to modify===
c  start_ps.F to solve deta/dt + div([H+eta-deta]Ubaro) = 0 for deta.===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fields.h>
#include <vertical.h>
#include <scalar.h>
#include <vertslabs.h>
#include <fieldsbar.h>
#include <workspb.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j
#ifndef barotropic
     *        ,k
#endif
      FLOAT
     *     fac1
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Set free surface at the T points.
c
      fac1=c1/grav
      do 100 j=1,jmt
      do 100 i=1,imt
#if defined oias | defined nest2smaller | defined nest2larger | limpstshap
         etatb(i,j) = etat(i,j)
         etavb(i,j) = etav(i,j)
#endif
#ifdef limpstshap
         etatbb(i,j)=etatb(i,j)
#endif
         etat(i,j)=fac1*p(i,j)
         detat(i,j)=ptd(i,j)*fac1
 100  continue
c
c  Set free surface at the U-V points.
c
      do 130 j=1,jmtm1
        do 120 i=1,imtm1
          etav(i,j)=p25*
     *          (etat(i,j)+etat(i+1,j)+etat(i,j+1)+etat(i+1,j+1))
          detav(i,j)=p25*
     *      (detat(i,j)+detat(i+1,j)+detat(i,j+1)+detat(i+1,j+1))
 120    continue
#ifdef cyclic
        etav(1,j)=etav(imtm1,j)
        etav(imt,j)=etav(2,j)
        detav(1,j)=detav(imtm1,j)
        detav(imt,j)=detav(2,j)
#else
        etav(imt,j)=etav(imtm1,j)
        detav(imt,j)=detav(imtm1,j)
#endif
 130  continue
      do 140 i=1,imt
        etav(i,jmt)=etav(i,jmtm1)
        detav(i,jmt)=detav(i,jmtm1)
 140  continue
c
c-----------------------------------------------------------------------
c  Set the depths ratios at tracer and velocity points and the inverse
c  of bottom depth at v-points
c-----------------------------------------------------------------------
c
      do 200 j=1,jmt
      do 200 i=1,imt
#ifdef limpstshap
         fractbb(i,j)=fractb(i,j)
#endif
         fractb(i,j)=fract(i,j)
         fract(i,j)=c1+etat(i,j)/hd(i,j)
         fracvb(i,j)=fracv(i,j)
         fracv(i,j)=c1+etav(i,j)/hdv(i,j)
#if defined freesurf
         hdvbf(i,j)=hdvcf(i,j)
# if defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05
         hdvbfx(i,j)=hdvcfx(i,j)
         hdvbfy(i,j)=hdvcfy(i,j)
# endif
#endif
         hdvcf(i,j)=hdv(i,j)+etav(i,j)
#if defined sprsnrm01
         hdvcfx(i,j)=hdvcf(i,j)*uland(i,j)
         hdvcfy(i,j)=hdvcf(i,j)*vland(i,j)
#endif
         hdvcf(i,j)=hdvcf(i,j)*min(fkmq(i,j),c1)
#if defined oias
         hvavb(i,j) = hvav(i,j)
#endif
         hvav(i,j) = dzv(i,j,1)*fracv(i,j)
 200  continue
c
#ifndef barotropic
      do 210 k = 2, km
      do 210 j = 1, jmt
      do 210 i = 1, imt
         hvav(i,j) = hvav(i,j) + dzv(i,j,k)*fracv(i,j)
 210  continue
c
#endif
      do 220 j = 1, jmt
      do 220 i = 1, imt
         hvav(i,j) = c1/hvav(i,j)
 220  continue
c
      return
      end
