      subroutine external_vel
c
c=======================================================================
c                                                                    ===
c EXTERNAL_VEL computes vertically averaged velocity at interior     ===
c       velocity points- UBARONEW for TAU+1 - and updates            ===
c       vertically averaged velocity:                                ===
c       if mxpas .FALSE.                                             ===
c         UBARO -> UBAROB;  UBARONEW -> UBARO                        ===
c       else                                                         ===
c         UBARONEW -> UBARO                                          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fullwd.h>
#include <scalar.h>
#include <onedim.h>
#include <fieldsbar.h>
#include <workspb.h>
#include <sinfo.h>
#if defined sprsnrm01 & defined sprsnrm02
# include <vertslabs.h>
#endif
#if defined filtgraddps & !defined bioadjloc
# include <filtdat.h>
#endif
#if defined smallpsdt & defined smallpsdt4
# include <vertical.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j
#ifdef coast
      integer istr,iend,jptr,l
#endif
#if defined dumppsrst
      integer dmptim
      parameter (dmptim=3)
      character*4 ittstr
#endif
      FLOAT 
     &      presscorru,presscorrv,fx,fac
#if defined filtgraddps & !defined bioadjloc
      integer icntvv
      save    icntvv
      data icntvv /0/
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifndef bioadjloc
c-----------------------------------------------------------------------
c  Solve for the updated barotropic velocities.
c-----------------------------------------------------------------------
# if defined filtgraddps
c
      do 5, j = 1, jmt
      do 5, i = 1, imt
         ubaronew(i,j) = c0
         vbaronew(i,j) = c0
   5  continue
# endif
c
c  Set time scaling.
c
# ifndef try2dtpsic
#  ifdef freesurf
      fx=alphav*c2dtsf
#  else
      fx=c2dtsf
#  endif
      if((mix.eq.1).and.eb) then
         fac=c1
      else
         if((mxp.ne.0).or.(mix.ne.0)) then
            fac=p5
         else
            fac=c1
         endif
      endif
      fx=fac*fx
#  if defined check_dt | defined  dumptst
      print *,'***EXTERNAL_VEL: mix=',mix,'  eb=',eb
      print *,'                 mxp=',mxp,'  fac=',fac
      print *,'                 c2dtsf=',c2dtsf
#   ifdef freesurf
      print *,'                 alphav=',alphav
#   endif
      print *,'                 fx=',fx
#  endif
# else
#  ifdef freesurf
      fx=alphav*c2dtps
#  else
      fx=c2dtps
#  endif
#  if defined check_dt | defined  dumptst
      print *,'***EXTERNAL_VEL: c2dtps=',c2dtps
#   ifdef freesurf
      print *,'                 alphav=',alphav
#   endif
      print *,'                 fx=',fx
#  endif
# endif
c
c  Update barotropic velocity with time change of surface pressure gradient.
c
      do 20 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
         jptr = min( max(j, 2), jmtm2)
c
         do 20 l=1,lseg
            istr=isq(jptr,l)
            if(istr.eq.0) go to 20
#  ifndef cyclic
            if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
#  endif
            iend=ieq(jptr,l)
            if ((iend.eq.imtm2).and.(fkmq(imtm2,jptr).gt.c0)) iend=imtm1
            do 10 i=istr,iend
# elif !defined cyclic
c
            do 10 i=1,imtm1
# else
c
            do 10 i=2,imtm1
# endif
c
# if !defined sprsnrm01 | !defined sprsnrm02
               presscorru=(ptd(i+1,j+1)+ptd(i+1,j))-(ptd(i,j+1)
     &                     +ptd(i,j))
               presscorru=fx*presscorru*csr(j)*dxu2r(i)
c
               presscorrv=(ptd(i+1,j+1)+ptd(i,j+1))-(ptd(i+1,j)
     &                     +ptd(i,j))
               presscorrv=fx*presscorrv*dyu2r(j)
c
#  if !defined filtgraddps
               ubaronew(i,j)=ubarhat(i,j)-presscorru
               vbaronew(i,j)=vbarhat(i,j)-presscorrv
#  else
               ubaronew(i,j)=presscorru
               vbaronew(i,j)=presscorrv
#  endif
# else
               if (uland(i,j).gt.c0) then
                  presscorru=(ptd(i+1,j+1)-ptd(i,j+1))
#  if defined coast
     &                        *min(landt(i+1,j+1),landt(i,j+1))
#  endif
     &                       + (ptd(i+1,j)-ptd(i,j))
#  if defined coast
     &                        *min(landt(i+1,j),landt(i,j))
#  endif
                  presscorru=fx*presscorru*csr(j)*dxu2r(i)
#  if defined sprsnrm04 & defined sprsnrm06
     &                                 *ugdwt(i,j)
#  endif
#  if !defined filtgraddps
                  ubaronew(i,j)=ubarhat(i,j)-presscorru
#  else
                  ubaronew(i,j)=presscorru
#  endif
               endif
               if (vland(i,j).gt.c0) then
                  presscorrv=(ptd(i+1,j+1)-ptd(i+1,j))
#  if defined coast
     &                        *min(landt(i+1,j+1),landt(i+1,j))
#  endif
     &                      + (ptd(i,j+1)-ptd(i,j))
#  if defined coast
     &                        *min(landt(i,j+1),landt(i,j))
#  endif
                  presscorrv=fx*presscorrv*dyu2r(j)
#  if defined sprsnrm04 & defined sprsnrm06
     &                                 *vgdwt(i,j)
#  endif
#  if !defined filtgraddps
                  vbaronew(i,j)=vbarhat(i,j)-presscorrv
#  else
                  vbaronew(i,j)=presscorrv
#  endif
               endif
# endif
c
  10        continue
  20  continue
c
# ifdef cyclic
c  Impose periodic boundary conditions.
c
      do 30 j = 1, jmtm1
         ubaronew(1,j)=ubaronew(imtm1,j)
         vbaronew(1,j)=vbaronew(imtm1,j)
         ubaronew(imt,j)=ubaronew(2,j)
         vbaronew(imt,j)=vbaronew(2,j)
  30  continue
# endif
c
#else
      do 10 j=1,jmtm1
      do 10 i=1,imu
         ubaronew(i,j)=ubaro(i,j)
         vbaronew(i,j)=vbaro(i,j)
  10  continue
c
#endif
#if defined smallpsdt & defined smallpsdt4
c-----------------------------------------------------------------------
c  For refined time-stepping, sum advective fluxes.
c-----------------------------------------------------------------------
c
      icursm = 1 - icursm
      ioldsm = 1 - ioldsm
c
      do 35 j=1,jmtm1
      do 35 i=1,imu
         fx                 = p5*fracv(i,j)
         usmadv(i,j,icursm) = usmadv(i,j,icursm) +
     &                        fx*(ubaronew(i,j)+ubaro(i,j))
         vsmadv(i,j,icursm) = vsmadv(i,j,icursm) +
     &                        fx*(vbaronew(i,j)+vbaro(i,j))
  35  continue
c
#endif
#if defined filtgraddps & !defined bioadjloc
c-----------------------------------------------------------------------
c  Filter gradient of change of surface pressure. Form final barotropic
c  velocity.
c-----------------------------------------------------------------------
c
        icntvv=icntvv+1
        if ((icntvv.eq.nfrqv) .and. (nordv.gt.0)) then
           icntvv=0
#if defined dumppsrst
c           if (itt.eq.dmptim) then
         write (ittstr,'(i4.4)') itt
         open (413, file='dxptdunflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) ubaronew(i,j)
                 enddo
              enddo
              close(413)
         open (413, file='dyptdunflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) vbaronew(i,j)
                 enddo
              enddo
              close(413)
c           endif
#endif
           do 40, i = 1, ntimv
             call shap_lev (ubaronew,imu,jmtm1,vgrid,nordv)
             call shap_lev (vbaronew,imu,jmtm1,vgrid,nordv)
  40       continue
#if defined dumppsrst
c           if (itt.eq.dmptim) then
           open (413, file='dxptdflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) ubaronew(i,j)
                 enddo
              enddo
              close(413)
           open (413, file='dyptdflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) vbaronew(i,j)
                 enddo
              enddo
              close(413)
c           endif
#endif
        endif
c
c  Update barotropic velocity with time change of surface pressure gradient.
c
      do 60 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
         jptr = min( max(j, 2), jmtm2)
c
         do 60 l=1,lseg
            istr=isq(jptr,l)
            if(istr.eq.0) go to 60
#  ifndef cyclic
            if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
#  endif
            iend=ieq(jptr,l)
            if ((iend.eq.imtm2).and.(fkmq(imtm2,jptr).gt.c0)) iend=imtm1
            do 50 i=istr,iend
# elif !defined cyclic
c
            do 50 i=1,imtm1
# else
c
            do 50 i=2,imtm1
# endif
c
# if !defined sprsnrm01 | !defined sprsnrm02
               ubaronew(i,j)=ubarhat(i,j)-ubaronew(i,j)
               vbaronew(i,j)=vbarhat(i,j)-vbaronew(i,j)
# else
               if (uland(i,j).gt.c0) then
                  ubaronew(i,j)=ubarhat(i,j)-ubaronew(i,j)
               endif
               if (vland(i,j).gt.c0) then
                  vbaronew(i,j)=vbarhat(i,j)-vbaronew(i,j)
               endif
# endif
c
  50        continue
  60  continue
c
# ifdef cyclic
c  Impose periodic boundary conditions.
c
      do 70 j = 1, jmtm1
         ubaronew(1,j)=ubaronew(imtm1,j)
         vbaronew(1,j)=vbaronew(imtm1,j)
         ubaronew(imt,j)=ubaronew(2,j)
         vbaronew(imt,j)=vbaronew(2,j)
  70  continue
# endif
#endif
#if !defined freesurf | !defined rset_dps
c-----------------------------------------------------------------------
c  Update other barotropic velocity storage space.
c-----------------------------------------------------------------------
c
# if defined  dumptst
      print *,'***EXTERNAL_VEL: mxpas2=',mxpas2
# endif
      if(.not.mxpas2) then
c
         do 90 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to update at sea points only and avoid land points
c
            jptr = min( max(j, 2), jmtm2)
c
            do 90 l=1,lseg
               istr=isq(jptr,l)
               if(istr.eq.0) go to 90
               if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
               iend=ieq(jptr,l)
               if ((iend.eq.imum1).and.(fkmq(imum1,jptr).gt.c0))
     &            iend=imu
               do 80 i=istr,iend
# else
c
               do 80 i=1,imu
# endif
# if !defined sprsnrm01 | !defined sprsnrm02
                  ubarob(i,j)=ubaro(i,j)
                  vbarob(i,j)=vbaro(i,j)
                  ubaro(i,j)=ubaronew(i,j)
                  vbaro(i,j)=vbaronew(i,j)
# else
                  if (uland(i,j).gt.c0) then
                     ubarob(i,j)=ubaro(i,j)
                     ubaro(i,j)=ubaronew(i,j)
                  endif
                  if (vland(i,j).gt.c0) then
                     vbarob(i,j)=vbaro(i,j)
                     vbaro(i,j)=vbaronew(i,j)
                  endif
# endif
  80           continue
  90     continue
c
      else
c
         do 110 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
            jptr = min( max(j, 2), jmtm2)
c
            do 110 l=1,lseg
               istr=isq(jptr,l)
               if(istr.eq.0) go to 110
               if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
               iend=ieq(jptr,l)
               if ((iend.eq.imum1).and.(fkmq(imum1,jptr).gt.c0))
     &            iend=imu
               do 100 i=istr,iend
# else
               do 100 i=1,imu
# endif
# if !defined sprsnrm01 | !defined sprsnrm02
                  ubaro(i,j)=ubaronew(i,j)
                  vbaro(i,j)=vbaronew(i,j)
# else
                  if (uland(i,j).gt.c0) then
                     ubaro(i,j)=ubaronew(i,j)
                  endif
                  if (vland(i,j).gt.c0) then
                     vbaro(i,j)=vbaronew(i,j)
                  endif
# endif
 100           continue
 110     continue
c
      endif
c            
#endif
      return
      end
