      subroutine h_frc_rst (uf,vf,fac)
c
c=======================================================================
c                                                                    ===
c  H_FORCE computes the horizontal force balanced by the action of   ===
c       surface pressure gradients in the water column.              ===
c                                                                    ===
c  This version is for resetting the time change of surface pressure ===
c     to preserve continuity (e.g. after filtering)                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fullwd.h>
#include <scalar.h>
#include <onedim.h>
#include <fieldsbar.h>
#include <sinfo.h>
#if defined sprsnrm01 & defined sprsnrm02
# include <vertslabs.h>
#endif
#if defined dumptst | defined dumppsrst
# include <iounits.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
#ifdef dumppsrst
      integer dmptim
      parameter (dmptim=3)
      character*4 ittstr
#endif
      integer i,j
      integer istr,iend
#ifdef coast
      integer l
#endif
      FLOAT
     &     uf(imt,jmt),vf(imt,jmt),fac
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
      do 10 j=1,jmt
      do 10 i=1,imt
         uf(i,j)=c0
         vf(i,j)=c0
 10   continue
c
      do 40 j=2,jmt-2
c
#if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
         do 30 l=1,lseg
            istr=isq(j,l)
            if(istr.eq.0) go to 40
            iend=ieq(j,l)
#else
c
            istr=2
            iend=imt-1
#endif
            do 20 i=istr,iend
#if !defined sprsnrm01 | !defined sprsnrm02
               uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &              *ubarob(i,j)+ubaro(i,j)
               vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &              *vbarob(i,j)+vbaro(i,j)
#else
               if (uland(i,j).gt.c0) then
                  uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &                    *ubarob(i,j)+ubaro(i,j)
               endif
               if (vland(i,j).gt.c0) then
                  vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &                    *vbarob(i,j)+vbaro(i,j)
               endif
#endif
 20         continue
 30      continue
 40   continue
c
      fac= p5*c2dtps*grav
c
c Extend to outer boundary nodes (open boundaries)
c
      do 50 j=1,jmtm1
#if !defined sprsnrm01 | !defined sprsnrm02
         if(fkmq(2,j).gt.c0) then
            i=1
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
c
         if(fkmq(imum1,j).gt.c0) then
            i=imu
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
#else
         i=1
         if (uland(i,j).gt.c0) then
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
         endif
         if (vland(i,j).gt.c0) then
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
         i=imu
         if (uland(i,j).gt.c0) then
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
         endif
         if (vland(i,j).gt.c0) then
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     *          *vbarob(i,j)+vbaro(i,j)
         endif
#endif
 50   continue
c
      do 60 i=2,imum1
#if !defined sprsnrm01 | !defined sprsnrm02
         if(fkmq(i,2).gt.c0) then
            j=1
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
c
         if(fkmq(i,jmtm2).gt.c0) then
            j=jmtm1
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
#else
         j=1
         if (uland(i,j).gt.c0) then
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
         endif
         if (vland(i,j).gt.c0) then
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
         j=jmtm1
         if (uland(i,j).gt.c0) then
            uf(i,j)=thetasd*ubaronew(i,j)+(c1-thetasd)
     &          *ubarob(i,j)+ubaro(i,j)
         endif
         if (vland(i,j).gt.c0) then
            vf(i,j)=thetasd*vbaronew(i,j)+(c1-thetasd)
     &          *vbarob(i,j)+vbaro(i,j)
         endif
#endif
 60   continue
c
#ifdef cyclic
c-----------------------------------------------------------------------
c  Extra insurance of periodicity.
c-----------------------------------------------------------------------
c
      do 70, j = 1, jmt
         uf(1,j) = uf(imum1,j)
         vf(1,j) = vf(imum1,j)
         uf(imu,j) = uf(2,j)
         vf(imu,j) = vf(2,j)
  70  continue
c
#endif
#ifdef dumppsrst
c-----------------------------------------------------------------------
c  Debugging dumping.
c-----------------------------------------------------------------------
c
c      if (itt.eq.dmptim) then
         write (ittstr,'(i4.4)') itt
         open (413, file='uf'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) uf(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vf'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vf(i,j)
            enddo
         enddo
         close(413)
         open (413, file='ubaronew'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) ubaronew(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vbaronew'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vbaronew(i,j)
            enddo
         enddo
         close(413)
         open (413, file='ubaro'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) ubaro(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vbaro'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vbaro(i,j)
            enddo
         enddo
         close(413)
         open (413, file='ubarob'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) ubarob(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vbarob'//ittstr//'.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vbarob(i,j)
            enddo
         enddo
         close(413)
C      endif
# if defined coast
         open (413, file='isq'//ittstr//'.dat', status='unknown')
         open (415, file='ieq'//ittstr//'.dat', status='unknown')
         write (413,*) jmt,lseg
         write (415,*) jmt,lseg
         do j = 1, jmt
            write (413,*) (isq(j,l), l=1,lseg)
            write (415,*) (ieq(j,l), l=1,lseg)
         enddo
         close(413)
         close(415)
# endif
c
#endif
c-----------------------------------------------------------------------
c  Update other barotropic velocity storage space.
c-----------------------------------------------------------------------
c
# if defined  dumptst
      print *,'***EXTERNAL_VEL: mxpas2=',mxpas2
# endif
      if(.not.mxpas2) then
c
         do 90 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to update at sea points only and avoid land points
c
            jptr = min( max(j, 2), jmtm2)
c
            do 90 l=1,lseg
               istr=isq(jptr,l)
               if(istr.eq.0) go to 90
               if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
               iend=ieq(jptr,l)
               if ((iend.eq.imum1).and.(fkmq(imum1,jptr).gt.c0))
     &            iend=imu
               do 80 i=istr,iend
# else
c
               do 80 i=1,imu
# endif
# if !defined sprsnrm01 | !defined sprsnrm02
                  ubarob(i,j)=ubaro(i,j)
                  vbarob(i,j)=vbaro(i,j)
                  ubaro(i,j)=ubaronew(i,j)
                  vbaro(i,j)=vbaronew(i,j)
# else
                  if (uland(i,j).gt.c0) then
                     ubarob(i,j)=ubaro(i,j)
                     ubaro(i,j)=ubaronew(i,j)
                  endif
                  if (vland(i,j).gt.c0) then
                     vbarob(i,j)=vbaro(i,j)
                     vbaro(i,j)=vbaronew(i,j)
                  endif
# endif
  80           continue
  90     continue
c
      else
c
         do 110 j=1,jmtm1
# if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
            jptr = min( max(j, 2), jmtm2)
c
            do 110 l=1,lseg
               istr=isq(jptr,l)
               if(istr.eq.0) go to 110
               if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
               iend=ieq(jptr,l)
               if ((iend.eq.imum1).and.(fkmq(imum1,jptr).gt.c0))
     &            iend=imu
               do 100 i=istr,iend
# else
               do 100 i=1,imu
# endif
# if !defined sprsnrm01 | !defined sprsnrm02
                  ubaro(i,j)=ubaronew(i,j)
                  vbaro(i,j)=vbaronew(i,j)
# else
                  if (uland(i,j).gt.c0) then
                     ubaro(i,j)=ubaronew(i,j)
                  endif
                  if (vland(i,j).gt.c0) then
                     vbaro(i,j)=vbaronew(i,j)
                  endif
# endif
 100           continue
 110     continue
c
      endif
c            
      return
      end
