      subroutine nest_hfrc (ntstep,ufnst,vfnst)
c
c=======================================================================
c                                                                    ===
c This routine overwrites the augmented velocity with averaged values===
c from fine grid.                                                    ===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c    NOSUBD    number of nested sub-domains.            (integer)    ===
c    NTSTEP    Current time step.                       (integer)    ===
c    UFNST     Zonal augmented vel, sub domain          (real array) ===
c    VFNST     Meridional augmented vel, sub domain     (real array) ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /NEST/                                                             ===
c                                                                    ===
c   I_LL_S    Lower left corner of smaller grid in current grid.     ===
c             (integer)                                              ===
c   I_UR_S    Upper right corner of smaller grid in current grid.    ===
c             (integer)                                              ===
c   J_LL_S    Lower left corner of smaller grid in current grid.     ===
c             (integer)                                              ===
c   J_UR_S    Upper right corner of smaller grid in current grid.    ===
c             (integer)                                              ===
c   NXCS      Number of x-grid points in current domain              ===
c             covered by smaller domain.                 (integer)   ===
c   NYCS      Number of y-grid points in current domain              ===
c             covered by smaller domain.                 (integer)   ===
c   SMLTID    PVM task identifier for smaller grid.      (integer)   ===
c   SPVS      Flag value from smaller grid.              (real)      ===
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:                     ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c                                                                    ===
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /SINFO/                                                            ===
c                                                                    ===
c    UBARHAT   Augmented U velocity.                 (real array)    ===
c    VBARHAT   Augmented V velocity.                 (real array)    ===
c                                                                    ===
c ------                                                             ===
c Calls:                                                             ===
c ------                                                             ===
c                                                                    ===
c  HOPS:  HOPSRECV,      NEST_ERRCHK                                 ===
c  PVM:   PVMFINITSEND,  PVMFPACK,    PVMFSEND,  PVMFUNPACK          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <nest.h>
#include <options.h>
#include <sinfo.h>
#include <vertslabs.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bufid,i,ip,j,k,n,ntstep,status,xip
      FLOAT
     *      uf(imt,jmt),ufnst(imt,jmt),vf(imt,jmt),vfnst(imt,jmt)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Receive vertically integrated RHS from smaller grid.
c-----------------------------------------------------------------------
c
      if (ntstep.gt.nest_start) then
         if (mod(ntstep,itt_fac).eq.0) then
#ifndef nestnultest
c
c  Zonal RHS.
c
            do 5, n = 1, nosubd
# ifndef nstuvylm
            do 5, j = j_ll_s(n), j_ur_s(n)
# else
            do 5, j = j_ll_s(n), j_ur_s(n)-1
# endif
            do 5, i = i_ll_s(n), i_ur_s(n)-1
# if !defined nestover
#  ifndef freesurf
               if (ufnst(i,j).ne.spvs(n))
     &            ubarhat(i,j)=ufnst(i,j)/hdv(i,j)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               if ((ufnst(i,j).ne.spvs(n)).and.(abs(hdvcf(i,j)).gt.0))
     &            ubarhat(i,j)=ufnst(i,j)/hdvcf(i,j)
#  else
               if ((ufnst(i,j).ne.spvs(n)).and.(abs(hdvcfx(i,j)).gt.0))
     &            ubarhat(i,j)=ufnst(i,j)/hdvcfx(i,j)
#  endif
# else
#  ifndef freesurf
               if (ufnst(i,j).ne.spv)
     &            ubarhat(i,j)=ufnst(i,j)/hdv(i,j)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               if ((ufnst(i,j).ne.spv).and.(abs(hdvcf(i,j)).gt.0))
     &            ubarhat(i,j)=ufnst(i,j)/hdvcf(i,j)
#  else
               if ((ufnst(i,j).ne.spv).and.(abs(hdvcfx(i,j)).gt.0))
     &            ubarhat(i,j)=ufnst(i,j)/hdvcfx(i,j)
#  endif
# endif
   5        continue
c
c  Meridional RHS.
c
            do 10, n = 1, nosubd
# ifndef nstuvylm
            do 10, j = j_ll_s(n), j_ur_s(n)
# else
            do 10, j = j_ll_s(n), j_ur_s(n)-1
# endif
            do 10, i = i_ll_s(n), i_ur_s(n)-1
# if !defined nestover
#  ifndef freesurf
               if (vfnst(i,j).ne.spvs(n))
     &            vbarhat(i,j)=vfnst(i,j)/hdv(i,j)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               if ((vfnst(i,j).ne.spvs(n)).and.(abs(hdvcf(i,j)).gt.0))
     &            vbarhat(i,j)=vfnst(i,j)/hdvcf(i,j)
#  else
               if ((vfnst(i,j).ne.spvs(n)).and.(abs(hdvcfy(i,j)).gt.0))
     &            vbarhat(i,j)=vfnst(i,j)/hdvcfy(i,j)
#  endif
# else
#  ifndef freesurf
               if (vfnst(i,j).ne.spv)
     &            vbarhat(i,j)=vfnst(i,j)/hdv(i,j)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               if ((vfnst(i,j).ne.spv).and.(abs(hdvcf(i,j)).gt.0))
     &            vbarhat(i,j)=vfnst(i,j)/hdvcf(i,j)
#  else
               if ((vfnst(i,j).ne.spv).and.(abs(hdvcfy(i,j)).gt.0))
     &            vbarhat(i,j)=vfnst(i,j)/hdvcfy(i,j)
#  endif
# endif
  10        continue
c
#endif
         end if
      end if
c
      return
      end
