      subroutine nest_init
c
c=======================================================================
c                                                                    ===
c  This routine initializes the nesting process.                     ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /IOUNITS/                                                         ===
c                                                                    ===
c     STDOUT   standard output logical unit.                (integer)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
#ifdef nest2larger
c  /IOUNITS/                                                         ===
c                                                                    ===
c     NSTINM   Name of param. input file for this run.      (string) ===
c     NSTONM   Name of output log file for this run.        (string) ===
c     STDINP   standard input logical unit.                 (integer)===
c     STDOUT   standard output logical unit.                (integer)===
c                                                                    ===
#endif
c  /NEST/                                                            ===
c                                                                    ===
c     CURRTID   PVM task identifier for this run.       (integer)    ===
#ifdef nest2larger
c     LRGTID    PVM task identifier for larger grid.    (integer)    ===
#endif
c                                                                    ===
c  Calls:      EXITUS,        LENGTH,    HOPSRECV,  NEST_ERRCHK      ===
c  PVM Calls:  PVMFINITSEND,  PVMFPACK,  PVMFSEND,  PVMFUNPACK,      ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <iounits.h>
#include <nest.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
#if defined use_mpi | defined nest2larger
      integer lenstr,status
#endif
#ifdef use_mpi
      integer defid,n,nest_color
      integer recvstat(MPI_STATUS_SIZE)
#endif
#ifdef nest2larger
      integer bufid,ios,recval,sbgn,send,testval
# ifdef use_mpi
      character*128 progname
# endif
c
      parameter (testval=8)
c
#endif
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef use_mpi
c-----------------------------------------------------------------------
c  Determine Task identifier for this run.
c-----------------------------------------------------------------------
c
      call MPI_INIT (status)
c
c     Create a communicator for the nested run (just copy in this case)
c      call MPI_COMM_SPLIT (MPI_COMM_WORLD, nest_color, defid, comm_nest,
c     &                     status)
      comm_nest = MPI_COMM_WORLD
c     Determine process rank
      call MPI_COMM_RANK (comm_nest, currtid, status)
c
c      if (defid .ne. currtid) then
c         write (stdout,800) defid, currtid
c         call exitus ('NEST_INIT')
c      end if
c
# if !defined nest2larger
c-----------------------------------------------------------------------
c  MPI master needs to assemble entire nesting world.
c-----------------------------------------------------------------------
c
      call MPI_COMM_SIZE (comm_nest, tot_proc_nest, status)
c
c  only interested in sub-processes
c
      tot_proc_nest = tot_proc_nest - 1
      no_par_assgn  = 0
c
      do 10, n = 1, tot_proc_nest
         call MPI_RECV (lenstr, 1, MPI_INTEGER4, n, lnpronm,
     &                  comm_nest, recvstat, status)
         call MPI_RECV (nstproc(n), lenstr, MPI_CHARACTER, n, procnam,
     &                  comm_nest, recvstat, status)
         nstparn(n) = -1
 10   continue
# endif
#else
c-----------------------------------------------------------------------
c  Determine Task identifier for this run.
c-----------------------------------------------------------------------
c
      call pvmfmytid (currtid)
      call nest_errchk ('NEST_INIT','MyTid',currtid,1,1,1)
c
#endif
#ifdef nest2larger
c-----------------------------------------------------------------------
c  Determine Task identifier for parent run.
c-----------------------------------------------------------------------
c
# ifdef use_mpi
c  first send task name to master for assigning parents
c
      call get_command_argument (0,progname)
      call length (progname,lenstr,sbgn,send)
      call MPI_SEND (lenstr, 1, MPI_INTEGER4, 0, lnpronm,
     &               comm_nest, status)
      call MPI_SEND (progname(sbgn:send), lenstr, MPI_CHARACTER, 0,
     &               procnam, comm_nest, status)
c
c  now get parent ID
c
      call MPI_RECV (lrgtid, 1, MPI_INTEGER4, 0, nstparid,
     &                  comm_nest, recvstat, status)
# else
      call pvmfparent (lrgtid)
      call nest_errchk ('NEST_INIT','ParentTid',lrgtid,1,1,1)
# endif
c
c-----------------------------------------------------------------------
c  Test the connection.
c-----------------------------------------------------------------------
c
c  Receive test integer value from larger domain.
c
# ifdef use_mpi
      call MPI_RECV (recval,1,MPI_INTEGER4,lrgtid,spts2s,
     &               comm_nest,recvstat,status)
# else
      call hopsrecv ('NEST_INIT',lrgtid,spts2s,bufid)
      call pvmfunpack (INTEGER4,recval,1,1,status)
      call nest_errchk ('NEST_INIT','UnPack',status,1,1,1)
# endif
c
c  Send test integer value to larger domain.
c
# ifdef use_mpi
      call MPI_SEND (testval,1,MPI_INTEGER4,lrgtid,spts2l,
     &               comm_nest,status)
# else
      call pvmfinitsend (PVM_DATAMETHOD,bufid)
      call nest_errchk ('NEST_INIT','InitSend',bufid,1,1,1)
      call pvmfpack (INTEGER4,testval,1,1,status)
      call nest_errchk ('NEST_INIT','Pack',status,1,1,1)
      call pvmfsend (lrgtid,spts2l,status)
      call nest_errchk ('NEST_INIT','Send',status,1,1,1)
# endif
c
c  Compare values.
c
      if (testval.ne.recval) then
         write (stdout,900) testval,recval
         call exitus ('NEST_INIT')
      end if
c
c-----------------------------------------------------------------------
c  Receive I/O file names.
c-----------------------------------------------------------------------
c
c  Receive input file name & its length from larger domain.
c
# ifdef use_mpi
      call MPI_RECV (lenstr,1,MPI_INTEGER4,lrgtid,lnifil,
     &               comm_nest,recvstat,status)
# else
      call hopsrecv ('NEST_INIT',lrgtid,lnifil,bufid)
      call pvmfunpack (INTEGER4,lenstr,1,1,status)
      call nest_errchk ('NEST_INIT','UnPack',status,1,1,1)
# endif
c
# ifdef use_mpi
      call MPI_RECV (nstinm,lenstr,MPI_CHARACTER,lrgtid,ifilnm,
     &               comm_nest,recvstat,status)
      call length (nstinm,lenstr,sbgn,send)
# else
      call hopsrecv ('NEST_INIT',lrgtid,ifilnm,bufid)
      call pvmfunpack (STRING,nstinm,lenstr,1,status)
      call nest_errchk ('NEST_INIT','UnPack',status,1,1,1)
# endif
c
c  Receive output file name & its length from larger domain.
c
# ifdef use_mpi
      call MPI_RECV (lenstr,1,MPI_INTEGER4,lrgtid,lnofil,
     &               comm_nest,recvstat,status)
# else
      call hopsrecv ('NEST_INIT',lrgtid,lnofil,bufid)
      call pvmfunpack (INTEGER4,lenstr,1,1,status)
      call nest_errchk ('NEST_INIT','UnPack',status,1,1,1)
# endif
c
# ifdef use_mpi
      call MPI_RECV (nstonm,lenstr,MPI_CHARACTER,lrgtid,ofilnm,
     &               comm_nest,recvstat,status)
      call length (nstonm,lenstr,sbgn,send)
# else
      call hopsrecv ('NEST_INIT',lrgtid,ofilnm,bufid)
      call pvmfunpack (STRING,nstonm,lenstr,1,status)
      call nest_errchk ('NEST_INIT','UnPack',status,1,1,1)
# endif
c
c  Reset standard I/O units.
c
      stdinp = 101
      call length (nstinm,lenstr,sbgn,send)
      open (stdinp, file=nstinm(sbgn:send), status='old', iostat=ios)
      if (ios.ne.0) then
         write (stdout,910) 'input',nstinm(sbgn:send)
         call exitus ('NEST_INIT')
      end if
c
      stdout = 103
      call length (nstonm,lenstr,sbgn,send)
      open(stdout, file=nstonm(sbgn:send), status='unknown', iostat=ios)
      if (ios.ne.0) then
         write (stdout,910) 'output',nstonm(sbgn:send)
         call exitus ('NEST_INIT')
      end if
c
#endif
      return
c
#ifdef use_mpi
 800  format (/'***Error:  NEST_INIT - wrong processor ids in ',
     &        'nested grids communicator.'/11x,'expected:  ',i10
     &        /11x,'actual:  ',i10)
#endif
 900  format (/'***Error:  NEST_INIT - unable to properly exchange ',
     &        'test values with larger domain.'/11x,'test value:  ',i10
     &        /11x,'received value:  ',i10)
 910  format (/'***Error:  NEST_INIT - unable to open ',a,' file:'/11x,
     &        1h",a,1h")
c
      end
