#if !defined usrdiagnostic | !defined nesttime
      subroutine nest_intbar (ntstep,ufnst,vfnst)
#else
      subroutine nest_intbar (ntstep,ufnst,vfnst,tsn1,tsn2)
#endif
c
c=======================================================================
c                                                                    ===
c This routine governs the transfer of interior data from smaller    ===
c grids to larger grids.                                             ===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c    NTSTEP    Current time step.                        (integer)   ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
#ifdef nest2larger
# ifndef surfpress
c /FIELDS/                                                           ===
c                                                                    ===
c    ZTD   Time change of vorticity.                 (real array)    ===
# else
c /SINFO/                                                            ===
c                                                                    ===
c    UBARHAT   Augmented U velocity.                 (real array)    ===
c    VBARHAT   Augmented V velocity.                 (real array)    ===
# endif
c                                                                    ===
#endif
#ifdef coast
c /FULLWD/                                                           ===
c                                                                    ===
c    LANDT     Land/sea mask at tracer points.       (integer array) ===
c    LANDV     Land/sea mask at velocity points.     (integer array) ===
c                                                                    ===
#endif
c /NEST/                                                             ===
c                                                                    ===
#ifdef nest2larger
c   NXLC      Number of x-grid points in larger domain               ===
c             covered by current domain.                 (integer)   ===
c   NYLC      Number of y-grid points in larger domain               ===
c             covered by current domain.                 (integer)   ===
c   LRGTID    PVM task identifier for larger grid.       (integer)   ===
c   SPVL      Flag value from larger grid.               (real)      ===
#endif
#ifdef nest2smaller
c   I_LL_S    Lower left corner of smaller grid in current grid.     ===
c             (integer)                                              ===
c   I_UR_S    Upper right corner of smaller grid in current grid.    ===
c             (integer)                                              ===
c   J_LL_S    Lower left corner of smaller grid in current grid.     ===
c             (integer)                                              ===
c   J_UR_S    Upper right corner of smaller grid in current grid.    ===
c             (integer)                                              ===
c   NOSUBD    number of nested sub-domains.              (integer)   ===
c   NXCS      Number of x-grid points in current domain              ===
c             covered by smaller domain.                 (integer)   ===
c   NYCS      Number of y-grid points in current domain              ===
c             covered by smaller domain.                 (integer)   ===
c   SMLTID    PVM task identifier for smaller grid.      (integer)   ===
c   SPVS      Flag value from smaller grid.              (real)      ===
#endif
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:                     ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c          IOPT(8)  Number of tracers exchanged with larger domain.  ===
c          IOPT(9)  Number of tracers exchanged with smaller domain. ===
#ifdef nest2larger
c                                                                    ===
c /ONEDIM/                                                           ===
c                                                                    ===
c    CS        cosine metric factors at velocity points. (real array)===
c    CST       cosine metric factors at tracer points.   (real array)===
c    DXT       zonal grid spacing, tracer boxes.         (real array)===
c    DXU       zonal grid spacing, velocity boxes.       (real array)===
c    DYT       meridional grid spacing, tracer boxes.    (real array)===
c    DYU       meridional grid spacing, velocity boxes.  (real array)===
#endif
c                                                                    ===
#if defined nest2smaller | ( defined usrdiagnostic & defined nesttime )
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
# if defined usrdiagnostic & defined nesttime
c                                                                    ===
c    TSN1      Time spent in communications.          (real vector)  ===
c    TSN2      Time spent in auxillary calculations.  (real vector)  ===
# endif
c                                                                    ===
#if defined nest2smaller
c Common Blocks:                                                     ===
c                                                                    ===
# ifndef surfpress
c /FIELDS/                                                           ===
c                                                                    ===
c    ZTD   Time change of vorticity.                 (real array)    ===
# else
c /SINFO/                                                            ===
c                                                                    ===
c    ZUM   Vertically averaged zonal forcing.        (real array)    ===
c    ZVM   Vertically averaged meridional forcing.   (real array)    ===
# endif
c                                                                    ===
# endif
#endif
c  Calls:      HOPSRECV,      NEST_ERRCHK                            ===
c  PVM Calls:  PVMFINITSEND,  PVMFPACK,    PVMFSEND,  PVMFUNPACK     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <fields.h>
#ifdef surfpress
# include <sinfo.h>
# include <vertslabs.h>
#endif
#include <iounits.h>
#include <nest.h>
#include <options.h>
#ifdef nest2smaller
# include <filtdat.h>
#endif
#ifdef nest2larger
# include <onedim.h>
#endif
#ifdef coast
# include <fullwd.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bufid,i,ip,j,k,m,n,ntstep,status,xip
#ifdef nest2larger
     *        ,ii,jj
#  if defined coast
     *        ,in,jn,nin
#  endif
# ifdef use_mpi
      integer recvstat(MPI_STATUS_SIZE)
# endif
      FLOAT
     *      fac,tot_wt
      FLOAT
     *      hwt(imt,3,km),wt(imt,3,km)
#endif
#if defined nest2smaller & defined nestover
      integer nxtr(imt,jmt),nxu(imt,jmt),nxv(imt,jmt)
# ifndef surfpress
      integer nztd(imt,jmt)
# else
      integer nps(imt,jmt),nufnst(imt,jmt),nvfnst(imt,jmt)
# endif
      FLOAT
     &      wtover
#endif
      FLOAT
     *      ufnst(imt,jmt),vfnst(imt,jmt)
#if defined nest2smaller & defined surfpress
      integer puse(imt,jmt)
#endif
#if defined usrdiagnostic & defined nesttime
      FLOAT
     &      tsn1(2),tsn2(2),twk(2)
# ifdef iforttime
     &      ,dum
      FLOAT
     &      dtime
# endif
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef nest2smaller
# if defined nestover
c-----------------------------------------------------------------------
c  Initialize counters and some special values.
c-----------------------------------------------------------------------
c
      do 3, j = 1, jmt
      do 3, i = 1, imt
         nxu(i,j) = 0
         nxv(i,j) = 0
         nxtr(i,j) = 0
#  ifndef surfpress
         nztd(i,j) = 0
#  else
         nps(i,j)    = 0
         nufnst(i,j) = 0
         nvfnst(i,j) = 0
         ufnst(i,j) = spv
         vfnst(i,j) = spv
#  endif
  3   continue
c
# endif
# ifndef surfpress
c-----------------------------------------------------------------------
c  Receive barotropic vorticity tendency from smaller grid.
c-----------------------------------------------------------------------
c
      if (ntstep.gt.nest_start) then
         if (mod(ntstep,itt_fac).eq.0) then
#  ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,900) 'receiving'
c
            do 10, n = 1, nosubd
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#   endif
#   ifdef use_mpi
               call MPI_RECV (xvol,nxcs(n)*nycs(n),nstflt,smltid(n),
     &                        vortin,comm_nest,recvstat,status)
#   else
               call hopsrecv ('NEST_INTBAR',smltid(n),vortin,bufid)
               call pvmfunpack (nstflt,xvol,nxcs(n)*nycs(n),1,status)
               call nest_errchk ('NEST_INTBAR','UnPack',status,1,1,1)
#   endif
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#   endif
c
               do 10 j = j_ll_s(n), j_ur_s(n)
               do 10 i = i_ll_s(n), i_ur_s(n)
                  ip = (i-i_ll_s(n)+1) + (j-j_ll_s(n))*nxcs(n)
#   if !defined nestover
                  if (xvol(ip).ne.spvs(n)) ztd(i,j) = xvol(ip)
#   else
                  if (xvol(ip).ne.spvs(n)) then
                     nztd(i,j) = nztd(i,j)+1
                     wtover    = FLoaT(nztd(i,j)-1)/FLoaT(nztd(i,j))
                     ztd(i,j)  = wtover*ztd(i,j) + (c1-wtover)*xvol(ip)
                  endif
#   endif
  10        continue
c
#  endif
         end if
      end if
c
# else
c-----------------------------------------------------------------------
c  Receive vertically integrated RHS from smaller grid.
c-----------------------------------------------------------------------
c
      if (ntstep.gt.nest_start) then
         if (mod(ntstep,itt_fac).eq.0) then
#  ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,900) 'receiving'
c
c  Zonal RHS.
c
            do 5, n = 1, nosubd
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#   endif
#   ifdef use_mpi
#    ifndef nstuvylm
               call MPI_RECV (xvol,(nxcs(n)-1)*nycs(n),nstflt,
#    else
               call MPI_RECV (xvol,(nxcs(n)-1)*(nycs(n)-1),nstflt,
#    endif
     &                        smltid(n),zumin,comm_nest,recvstat,status)
#   else
               call hopsrecv ('NEST_INTBAR',smltid(n),zumin,bufid)
#    ifndef nstuvylm
               call pvmfunpack (nstflt,xvol,(nxcs(n)-1)*nycs(n),1,
     &                          status)
#    else
               call pvmfunpack (nstflt,xvol,(nxcs(n)-1)*(nycs(n)-1),1,
     &                          status)
#    endif
               call nest_errchk ('NEST_INTBAR','UnPack',status,1,1,1)
#   endif
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#   endif
c
#   ifndef nstuvylm
               do 5 j = j_ll_s(n), j_ur_s(n)
#   else
               do 5 j = j_ll_s(n), j_ur_s(n)-1
#   endif
               do 5 i = i_ll_s(n), i_ur_s(n)-1
                  ip = (i-i_ll_s(n)+1) + (j-j_ll_s(n))*(nxcs(n)-1)
#   if !defined nestover
c     test for special values in nest_hfrc.F
                  ufnst(i,j) = xvol(ip)
#   else
                  if (xvol(ip).ne.spvs(n)) then
                     nufnst(i,j) = nufnst(i,j)+1
                     wtover    = FLoaT(nufnst(i,j)-1)/FLoaT(nufnst(i,j))
                     ufnst(i,j) =wtover*ufnst(i,j) +(c1-wtover)*xvol(ip)
                  endif
#   endif
   5        continue
c
c  Meridional RHS.
c
            do 10, n = 1, nosubd
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#   endif
#   ifdef use_mpi
#    ifndef nstuvylm
               call MPI_RECV (xvol,(nxcs(n)-1)*nycs(n),nstflt,
#    else
               call MPI_RECV (xvol,(nxcs(n)-1)*(nycs(n)-1),nstflt,
#    endif
     &                        smltid(n),zvmin,comm_nest,recvstat,status)
#   else
               call hopsrecv ('NEST_INTBAR',smltid(n),zvmin,bufid)
#    ifndef nstuvylm
               call pvmfunpack (nstflt,xvol,(nxcs(n)-1)*nycs(n),1,
     &                          status)
#    else
               call pvmfunpack (nstflt,xvol,(nxcs(n)-1)*(nycs(n)-1),1,
     &                          status)
#    endif
               call nest_errchk ('NEST_INTBAR','UnPack',status,1,1,1)
#   endif
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
               call dtime (twk)
#    else
               dum = dtime (twk)
#    endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#   endif
c
#   ifndef nstuvylm
               do 10, j = j_ll_s(n), j_ur_s(n)
#   else
               do 10, j = j_ll_s(n), j_ur_s(n)-1
#   endif
               do 10, i = i_ll_s(n), i_ur_s(n)-1
                  ip = (i-i_ll_s(n)+1) + (j-j_ll_s(n))*(nxcs(n)-1)
#   if !defined nestover
c     test for special values in nest_hfrc.F
                  vfnst(i,j) = xvol(ip)
#   else
                  if (xvol(ip).ne.spvs(n)) then
                     nvfnst(i,j) = nvfnst(i,j)+1
                     wtover    = FLoaT(nvfnst(i,j)-1)/FLoaT(nvfnst(i,j))
                     vfnst(i,j) =wtover*vfnst(i,j) +(c1-wtover)*xvol(ip)
                  endif
#   endif
  10        continue
c
#  endif
c
c  Surface pressure.
c
#  ifndef bioadjloc
            call rsetubaro ('Remove',puse)
#  endif
            do 12 j = 1, jmt
            do 12 i = 1, imt
               puse(i,j) = 0
  12        continue
            do 2012, n = 1, nosubd
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,nxcs(n)*nycs(n),nstflt,smltid(n),
     &                        srfpin,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_INTBAR',smltid(n),srfpin,bufid)
               call pvmfunpack (nstflt,xvol,nxcs(n)*nycs(n),1,status)
               call nest_errchk ('NEST_INTBAR','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
               do 2012, j = j_ll_s(n), j_ur_s(n)
               do 2012, i = i_ll_s(n), i_ur_s(n)
                  xip = (i-i_ll_s(n)+1) + (j-j_ll_s(n))*nxcs(n)
                  if (xvol(xip).ne.spvs(n)) then
                     puse(i,j) = 1
#  if !defined nestover
#   if !defined smallpsdt
                     if ((icntp.eq.0).and.(nordp.gt.0)) then
                        punflt(i,j) = xvol(xip)
                      else
#   endif
                        p(i,j) = xvol(xip)
#   if !defined smallpsdt
                     endif
#   endif
                  endif
#  else
                     nps(i,j) = nps(i,j)+1
                     wtover    = FLoaT(nps(i,j)-1)/FLoaT(nps(i,j))
#   if !defined smallpsdt
                     if ((icntp.eq.0).and.(nordp.gt.0)) then
                        punflt(i,j) = wtover*punflt(i,j) +
     &                                (c1-wtover)*xvol(xip)
                     else
#   endif
                        p(i,j) = wtover*p(i,j) + (c1-wtover)*xvol(xip)
#   if !defined smallpsdt
                     endif
#   endif
                  endif
#  endif
2012        continue
#  if !defined smallpsdt
            if ((icntp.eq.0).and.(nordp.gt.0)) then
               do 1020 j = 1, jmt
               do 1020 i = 1, imt
                  p(i,j) = punflt(i,j)
1020           continue
               do 1030 nn=1,ntimp
                  call shap_lev(p,imt,jmt,pgrid,nordp)
1030           continue
            end if
#  endif
#  ifndef bioadjloc
            call rsetubaro ('Add',puse)
#  endif
         end if
      end if
c
# endif
#endif
#ifdef nest2larger
# ifndef surfpress
c-----------------------------------------------------------------------
c  Send barotropic vorticity tendency to larger grid.
c-----------------------------------------------------------------------
c
      if (ntstep.gt.nest_start) then
         if (mod(ntstep,itt_fac).eq.0) then
#  ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,900) 'sending'
c
#    if !defined coast
            fac = c1/c9
#    endif
            do 20 jj = 1, nylc
            do 20 ii = 1, nxlc
               i  = ii*horiz_fac
               j  = jj*horiz_fac
               ip = ii + (jj-1)*nxlc
#    if !defined coast
               xvol(ip)=fac*(ztd(i-1,j+1)+ztd(i,j+1)+ztd(i+1,j+1)+
     *                       ztd(i-1,j  )+ztd(i,j  )+ztd(i+1,j  )+
     *                       ztd(i-1,j-1)+ztd(i,j-1)+ztd(i+1,j-1))
#     else
               nin      = 0
               xvol(ip) = c0
               do 15 jn = -1, 1
               do 15 in = -1, 1
                  if (landt(i+in,j+jn).eq.t_act) then
                     xvol(ip) = xvol(ip) + ztd(i+in,j+jn)
                     nin      = nin + 1
                  end if
  15           continue
               if (nin.ge.mn_spprt) then
                  xvol(ip) = xvol(ip)/FLoaT(nin)
                 else
                  xvol(ip) = spv
               end if
#    endif
  20        continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
            call dtime (twk)
#   else
            dum = dtime (twk)
#   endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
            call MPI_SEND (xvol,nxlc*nylc,nstflt,lrgtid,
     &                     vortin,comm_nest,status)
#  else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_INTBAR','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxlc*nylc,1,status)
            call nest_errchk ('NEST_INTBAR','Pack',status,1,1,1)
            call pvmfsend (lrgtid,vortin,status)
            call nest_errchk ('NEST_INTBAR','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
            call dtime (twk)
#   else
            dum = dtime (twk)
#   endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
#  endif
c
#  endif
         end if
      end if
c
# else
c-----------------------------------------------------------------------
c  Send vertically integrated RHS from smaller grid.
c-----------------------------------------------------------------------
c
      if (ntstep.gt.nest_start) then
         if (mod(ntstep,itt_fac).eq.0) then
#  ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,900) 'sending'
c
c  Construct augmented velocities without correct boundary values
c
            call UV_hat ('Filter')
c
c  Zonal RHS
c
#    ifndef nstuvylm
            do 15 jj = 1, nylc
#    else
            do 15 jj = 1, nylc-1
#    endif
               j  = jj*horiz_fac
               do 11 i = 1, imt
                  hwt(i,1,1) = cs(j)*dyu(j)*dxu(i)
                  hwt(i,2,1) = cs(j+1)*dyu(j+1)*dxu(i)
                  hwt(i,3,1) = cs(j+2)*dyu(j+2)*dxu(i)
#    ifndef freesurf
                  wt(i,1,1)  = hwt(i,1,1)*hdv(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdv(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdv(i,j+2)
#    elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  wt(i,1,1)  = hwt(i,1,1)*hdvcf(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdvcf(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdvcf(i,j+2)
#    else
                  wt(i,1,1)  = hwt(i,1,1)*hdvcfx(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdvcfx(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdvcfx(i,j+2)
#    endif
  11           continue
c
               do 15 ii = 1, nxlc-1
                  i  = ii*horiz_fac
                  ip = ii + (jj-1)*(nxlc-1)
#    if !defined coast
                  tot_wt = hwt(i,3,1)+hwt(i+1,3,1)+hwt(i+2,3,1)+
     &                     hwt(i,2,1)+hwt(i+1,2,1)+hwt(i+2,2,1)+
     &                     hwt(i,1,1)+hwt(i+1,1,1)+hwt(i+2,1,1)
                  xvol(ip)=(ubarhat(i  ,j+2)*wt(i  ,3,1) +
     &                      ubarhat(i+1,j+2)*wt(i+1,3,1) +
     &                      ubarhat(i+2,j+2)*wt(i+2,3,1) +
     &                      ubarhat(i  ,j+1)*wt(i  ,2,1) +
     &                      ubarhat(i+1,j+1)*wt(i+1,2,1) +
     &                      ubarhat(i+2,j+1)*wt(i+2,2,1) +
     &                      ubarhat(i  ,j  )*wt(i  ,1,1) +
     &                      ubarhat(i+1,j  )*wt(i+1,1,1) +
     &                      ubarhat(i+2,j  )*wt(i+2,1,1) ) / tot_wt
#    else
                  nin      = 0
                  tot_wt   = c0
                  xvol(ip) = c0
                  do 13 jn = 0, 2
                  do 13 in = 0, 2
#     if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                     if (landv(i+in,j+jn).eq.v_act) then
#     else
                     if (uland(i+in,j+jn).eq.1) then
#     endif
                        xvol(ip) = xvol(ip) +
     &                             ubarhat(i+in,j+jn)*wt(i+in,1+jn,1)
                        tot_wt   = tot_wt + hwt(i+in,1+jn,1)
                        nin      = nin + 1
                     end if
  13              continue
                  if (nin.ge.mn_spprt) then
                     xvol(ip) = xvol(ip)/tot_wt
                    else
                     xvol(ip) = spv
                  end if
#    endif
  15        continue
c
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
            call dtime (twk)
#    else
            dum = dtime (twk)
#    endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
#   endif
#   ifdef use_mpi
#    ifndef nstuvylm
            call MPI_SEND (xvol,(nxlc-1)*nylc,nstflt,lrgtid,
#    else
            call MPI_SEND (xvol,(nxlc-1)*(nylc-1),nstflt,lrgtid,
#    endif
     &                     zumin,comm_nest,status)
#   else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_INTBAR','InitSend',bufid,1,1,1)
#    ifndef nstuvylm
            call pvmfpack (nstflt,xvol,(nxlc-1)*nylc,1,status)
#    else
            call pvmfpack (nstflt,xvol,(nxlc-1)*(nylc-1),1,status)
#    endif
            call nest_errchk ('NEST_INTBAR','Pack',status,1,1,1)
            call pvmfsend (lrgtid,zumin,status)
            call nest_errchk ('NEST_INTBAR','Send',status,1,1,1)
#   endif
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
            call dtime (twk)
#    else
            dum = dtime (twk)
#    endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
#   endif
c
c  Meridional RHS
c
#    ifndef nstuvylm
            do 20 jj = 1, nylc
#    else
            do 20 jj = 1, nylc-1
#    endif
               j  = jj*horiz_fac
               do 16 i = 1, imt
                  hwt(i,1,1) = cs(j)*dyu(j)*dxu(i)
                  hwt(i,2,1) = cs(j+1)*dyu(j+1)*dxu(i)
                  hwt(i,3,1) = cs(j+2)*dyu(j+2)*dxu(i)
#    ifndef freesurf
                  wt(i,1,1)  = hwt(i,1,1)*hdv(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdv(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdv(i,j+2)
#    elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  wt(i,1,1)  = hwt(i,1,1)*hdvcf(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdvcf(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdvcf(i,j+2)
#    else
                  wt(i,1,1)  = hwt(i,1,1)*hdvcfy(i,j)
                  wt(i,2,1)  = hwt(i,2,1)*hdvcfy(i,j+1)
                  wt(i,3,1)  = hwt(i,3,1)*hdvcfy(i,j+2)
#    endif
  16           continue
c
               do 20 ii = 1, nxlc-1
                  i  = ii*horiz_fac
                  ip = ii + (jj-1)*(nxlc-1)
#    if !defined coast
                  tot_wt = hwt(i,3,1)+hwt(i+1,3,1)+hwt(i+2,3,1)+
     &                     hwt(i,2,1)+hwt(i+1,2,1)+hwt(i+2,2,1)+
     &                     hwt(i,1,1)+hwt(i+1,1,1)+hwt(i+2,1,1)
                  xvol(ip)=(vbarhat(i  ,j+2)*wt(i  ,3,1) +
     &                      vbarhat(i+1,j+2)*wt(i+1,3,1) +
     &                      vbarhat(i+2,j+2)*wt(i+2,3,1) +
     &                      vbarhat(i  ,j+1)*wt(i  ,2,1) +
     &                      vbarhat(i+1,j+1)*wt(i+1,2,1) +
     &                      vbarhat(i+2,j+1)*wt(i+2,2,1) +
     &                      vbarhat(i  ,j  )*wt(i  ,1,1) +
     &                      vbarhat(i+1,j  )*wt(i+1,1,1) +
     &                      vbarhat(i+2,j  )*wt(i+2,1,1) ) / tot_wt
#    else
                  nin      = 0
                  tot_wt   = c0
                  xvol(ip) = c0
                  do 18 jn = 0, 2
                  do 18 in = 0, 2
#     if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                     if (landv(i+in,j+jn).eq.v_act) then
#     else
                     if (vland(i+in,j+jn).eq.1) then
#     endif
                        xvol(ip) = xvol(ip) +
     &                             vbarhat(i+in,j+jn)*wt(i+in,1+jn,1)
                        tot_wt   = tot_wt + hwt(i+in,1+jn,1)
                        nin      = nin + 1
                     end if
  18              continue
                  if (nin.ge.mn_spprt) then
                     xvol(ip) = xvol(ip)/tot_wt
                    else
                     xvol(ip) = spv
                  end if
#    endif
  20        continue
c
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
            call dtime (twk)
#    else
            dum = dtime (twk)
#    endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
#   endif
#   ifdef use_mpi
#    ifndef nstuvylm
            call MPI_SEND (xvol,(nxlc-1)*nylc,nstflt,lrgtid,
#    else
            call MPI_SEND (xvol,(nxlc-1)*(nylc-1),nstflt,lrgtid,
#    endif
     &                     zvmin,comm_nest,status)
#   else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_INTBAR','InitSend',bufid,1,1,1)
#    ifndef nstuvylm
            call pvmfpack (nstflt,xvol,(nxlc-1)*nylc,1,status)
#    else
            call pvmfpack (nstflt,xvol,(nxlc-1)*(nylc-1),1,status)
#    endif
            call nest_errchk ('NEST_INTBAR','Pack',status,1,1,1)
            call pvmfsend (lrgtid,zvmin,status)
            call nest_errchk ('NEST_INTBAR','Send',status,1,1,1)
#   endif
#   if defined usrdiagnostic & defined nesttime
#    ifndef iforttime
            call dtime (twk)
#    else
            dum = dtime (twk)
#    endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
#   endif
c
c  Surface pressure
c
            do 25 jj = 1, nylc
               j = jj*horiz_fac
               do 21 i = 1, imt
                  wt(i,1,1) = cst(j-1)*dyt(j-1)*dxt(i)
                  wt(i,2,1) = cst(j)*dyt(j)*dxt(i)
                  wt(i,3,1) = cst(j+1)*dyt(j+1)*dxt(i)
  21           continue
#  ifndef coast
               do 22 ii = 1, nxlc
                  i = ii*horiz_fac
                  tot_wt = wt(i-1,3,1)+wt(i,3,1)+wt(i+1,3,1)+
     *                     wt(i-1,2,1)+wt(i,2,1)+wt(i+1,2,1)+
     *                     wt(i-1,1,1)+wt(i,1,1)+wt(i+1,1,1)
                  ip  = i + (j-1)*imt
                  xip = ii + (jj-1)*nxlc
                  xvol(xip)=(p(i  ,j+1)*wt(i,  3,1)+
     *                       p(i  ,j-1)*wt(i,  1,1)+
     *                       p(i+1,j  )*wt(i+1,2,1)+
     *                       p(i-1,j  )*wt(i-1,2,1)+
     *                       p(i-1,j-1)*wt(i-1,1,1)+
     *                       p(i+1,j+1)*wt(i+1,3,1)+
     *                       p(i+1,j-1)*wt(i+1,1,1)+
     *                       p(i-1,j+1)*wt(i-1,3,1)+
     *                       p(i  ,j  )*wt(i  ,2,1))/tot_wt
  22           continue
#   else
               do 24 ii = 1, nxlc
                  i   = ii*horiz_fac
                  ip  = i + (j-1)*imt
                  nin = 0
                  do 23 jn = -1, 1
                  do 23 in = -1, 1
                     if (landt(i+in,j+jn).eq.t_act) then
                        nin = nin+1
                       else
                           wt(i+in,jn+2,1)=c0
                     end if
  23              continue
                     xip = ii + (jj-1)*nxlc
                     if (nin.ge.mn_spprt) then
                        tot_wt = wt(i-1,3,1)+wt(i,3,1)+wt(i+1,3,1)+
     *                           wt(i-1,2,1)+wt(i,2,1)+wt(i+1,2,1)+
     *                           wt(i-1,1,1)+wt(i,1,1)+wt(i+1,1,1)
                        xvol(xip)=(p(i  ,j+1)*wt(i,  3,1)+
     *                             p(i  ,j-1)*wt(i,  1,1)+
     *                             p(i+1,j  )*wt(i+1,2,1)+
     *                             p(i-1,j  )*wt(i-1,2,1)+
     *                             p(i-1,j-1)*wt(i-1,1,1)+
     *                             p(i+1,j+1)*wt(i+1,3,1)+
     *                             p(i+1,j-1)*wt(i+1,1,1)+
     *                             p(i-1,j+1)*wt(i-1,3,1)+
     *                             p(i  ,j  )*wt(i  ,2,1))/tot_wt
                       else
                        xvol(xip)=spv
                     end if
  24           continue
#  endif
  25        continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
            call dtime (twk)
#   else
            dum = dtime (twk)
#   endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
            call MPI_SEND (xvol,nxlc*nylc,nstflt,lrgtid,
     &                     srfpin,comm_nest,status)
#  else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_INTBAR','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxlc*nylc,1,status)
            call nest_errchk ('NEST_INTBAR','Pack',status,1,1,1)
            call pvmfsend (lrgtid,srfpin,status)
            call nest_errchk ('NEST_INTBAR','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
            call dtime (twk)
#   else
            dum = dtime (twk)
#   endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
#  endif
c
c
#  endif
         end if
      end if
c
# endif
#endif
#ifdef sunflush
c  Flush output buffers.
c
      call flush(stdout)
#endif
c
      return
c
#ifndef surfpress
 900  format ('NEST_INTBAR:  ',a,' interior ztd')
#else
 900  format ('NEST_INTBAR:  ',a,' interior RHS')
#endif
c
      end
