#if !defined usrdiagnostic | !defined nesttime
      subroutine nest_recbar_bc
#else
      subroutine nest_recbar_bc (tsn1,tsn2)
#endif
c
c=======================================================================
c                                                                    ===
c This routine receives the boundary conditions from a larger domain.===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /FULLWD/                                                           ===
c                                                                    ===
c    ITT    timestep counter.                     (integer)          ===
c    LABS   disk unit number (13-15) for slabs.   (integer vector)   ===
c                                                                    ===
c /IOUNITS/                                                          ===
c                                                                    ===
c    STDOUT    Unit number for standard output.          (integer)   ===
c                                                                    ===
c /NEST/                                                             ===
c                                                                    ===
c    LRGTID    PVM task identifier for larger grid.      (integer)   ===
c    SPVL      Flag value from larger grid.              (real)      ===
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:    (integer vector) ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c          IOPT(8)  Number of tracers exchanged with larger domain.  ===
c                                                                    ===
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
#if defined usrdiagnostic & defined nesttime
c                                                                    ===
c    TSN1      Time spent in communications.          (real vector)  ===
c    TSN2      Time spent in auxillary calculations.  (real vector)  ===
#endif
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /BNDATA/                                                           ===
c                                                                    ===
# ifndef surfpress
c    PO        Transport boundary conditions             (real array)===
# else
c    PO        Pressure boundary conditions              (real array)===
# endif
c                                                                    ===
# ifndef surfpress
c /FIELDS/                                                           ===
c                                                                    ===
c    ZTD       Time change of vorticity with BCs.    (real array)    ===
# else
c /SINFO/                                                            ===
c                                                                    ===
c    ZUM   Vertically averaged zonal forcing.        (real array)    ===
c    ZVM   Vertically averaged meridional forcing.   (real array)    ===
# endif
c                                                                    ===
c  Calls:      HOPSRECV,      NEST_ERRCHK                            ===
c  PVM Calls:  PVMFUNPACK                                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <bndata.h>
#include <iounits.h>
#include <nest.h>
#include <options.h>
#include <workspa.h>
#include <fullwd.h>
#ifndef surfpress
# include <fields.h>
# include <scalar.h>
#else
# include <sinfo.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer bufid,i,j,k,n,nn,status,toff,xip
#ifdef use_mpi
      integer recvstat(MPI_STATUS_SIZE)
#endif
#if defined usrdiagnostic & defined nesttime
      FLOAT
     &      tsn1(2),tsn2(2),twk(2)
# ifdef iforttime
     &      ,dum
      FLOAT
     &      dtime
# endif
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
#ifndef surfpress
c  Receive boundary conditions for transport streamfunction.
#else
c  Receive boundary conditions for surface pressure.
#endif
c-----------------------------------------------------------------------
c
      if (itt.ge.nest_start) then
         if (mod(itt,itt_fac).eq.0) then
c
            if (iopt(5).eq.1) write (stdout,900)
c
c  Western boundary.
c
            do 15 i = 1, 3
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#endif
#ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        psibdw,comm_nest,recvstat,status)
# ifdef surfpress
               call MPI_RECV (xvolb,jmt,nstflt,lrgtid,
     &                        psibdw,comm_nest,recvstat,status)
# endif
#else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# ifdef surfpress
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibdw,bufid)
               call pvmfunpack (nstflt,xvolb,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# endif
#endif
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#endif
c
               do 10 j = 1, jmt
                  if (xvol(j).ne.spvl) pbc0(j,i,itbp,west) = xvol(j)
#ifdef surfpress
                  if (xvolb(j).ne.spvl) pbc0(j,i,itb,west) = xvolb(j)
#endif
  10           continue
  15        continue
c
c  Eastern boundary.
c
            do 25 i = 1, 3
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#endif
#ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        psibde,comm_nest,recvstat,status)
# ifdef surfpress
               call MPI_RECV (xvolb,jmt,nstflt,lrgtid,
     &                        psibde,comm_nest,recvstat,status)
# endif
#else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# ifdef surfpress
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibde,bufid)
               call pvmfunpack (nstflt,xvolb,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# endif
#endif
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#endif
c
               do 20 j = 1, jmt
                  if (xvol(j).ne.spvl) pbc0(j,i,itbp,east) = xvol(j)
#ifdef surfpress
                  if (xvolb(j).ne.spvl) pbc0(j,i,itb,east) = xvolb(j)
#endif
  20           continue
  25        continue
c
c  Southern boundary.
c
            do 35 j = 1, 3
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#endif
#ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        psibds,comm_nest,recvstat,status)
# ifdef surfpress
               call MPI_RECV (xvolb,imt,nstflt,lrgtid,
     &                        psibds,comm_nest,recvstat,status)
# endif
#else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# ifdef surfpress
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibds,bufid)
               call pvmfunpack (nstflt,xvolb,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# endif
#endif
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#endif
c
               do 30 i = 1, imt
                  if (xvol(i).ne.spvl) pbc0(i,j,itbp,south) = xvol(i)
#ifdef surfpress
                  if (xvolb(i).ne.spvl) pbc0(i,j,itb,south) = xvolb(i)
#endif
  30           continue
  35        continue
c
c  Northern boundary.
c
            do 45 j = 1, 3
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#endif
#ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        psibdn,comm_nest,recvstat,status)
# ifdef surfpress
               call MPI_RECV (xvolb,imt,nstflt,lrgtid,
     &                        psibdn,comm_nest,recvstat,status)
# endif
#else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# ifdef surfpress
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,psibdn,bufid)
               call pvmfunpack (nstflt,xvolb,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
# endif
#endif
#if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#endif
c
               do 40 i = 1, imt
                  if (xvol(i).ne.spvl) pbc0(i,j,itbp,north) = xvol(i)
#ifdef surfpress
                  if (xvolb(i).ne.spvl) pbc0(i,j,itb,north) = xvolb(i)
#endif
  40           continue
  45        continue
c
         endif
      endif
c
#ifndef surfpress
c-----------------------------------------------------------------------
c  Receive ZTD boundary conditions from larger domain
c-----------------------------------------------------------------------
c
      if(itt.ge.nest_start)then
         if(mod(itt,itt_fac).eq.0)then
# ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,910)
c
c  Western boundary.
c
            do 185 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        vrtbdw,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,vrtbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 180 j = 1, jmt
                  if (xvol(j).ne.spvl) qbc0(j,nn,itbp,west) = xvol(j)
 180           continue
 185        continue
c
c  Eastern boundary.
c
            do 195 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        vrtbde,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,vrtbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 190 j = 1, jmt
                  if (xvol(j).ne.spvl) qbc0(j,nn,itbp,east) = xvol(j)
 190           continue
 195        continue
c
c  Southern boundary.
c
            do 205 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        vrtbds,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,vrtbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 200 i = 1, imt
                  if (xvol(i).ne.spvl) qbc0(i,nn,itbp,south) = xvol(i)
 200           continue
 205        continue
c
c  Northern boundary.
c
            do 215 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        vrtbdn,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,vrtbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 210 i = 1, imt
                  if (xvol(i).ne.spvl) qbc0(i,nn,itbp,north) = xvol(i)
 210           continue
 215        continue
c
# endif
          endif
       endif
c
#else
c-----------------------------------------------------------------------
# ifndef freesurf
c  Receive barotropic velocity BCs from larger domain.
# else
c  Receive transport BCs from larger domain.
# endif
c-----------------------------------------------------------------------
c
      if(itt.ge.nest_start)then
         if(mod(itt,itt_fac).eq.0)then
# ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,910)
c
c  -------------
c  --- Zonal ---
c  -------------
c
c  Western boundary.
c
            do 185 nn = 1, nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        zumbdw,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zumbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 180 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) ubaroo(j,nn,itbp,west) = xvol(j)
# else
                  if (xvol(j).ne.spvl) utrano(j,nn,itbp,west) = xvol(j)
# endif
 180           continue
 185        continue
c
c  Eastern boundary.
c
            do 195 nn = 1, nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        zumbde,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zumbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 190 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) ubaroo(j,nn,itbp,east) = xvol(j)
# else
                  if (xvol(j).ne.spvl) utrano(j,nn,itbp,east) = xvol(j)
# endif
 190           continue
 195        continue
c
c  Southern boundary.
c
            do 205 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        zumbds,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zumbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 200 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) ubaroo(i,nn,itbp,south) = xvol(i)
# else
                  if (xvol(i).ne.spvl) utrano(i,nn,itbp,south) = xvol(i)
# endif
 200           continue
 205        continue
c
c  Northern boundary.
c
            do 215 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        zumbdn,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zumbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 210 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) ubaroo(i,nn,itbp,north) = xvol(i)
# else
                  if (xvol(i).ne.spvl) utrano(i,nn,itbp,north) = xvol(i)
# endif
 210           continue
 215        continue
c
c  ------------------
c  --- Meridional ---
c  ------------------
c
c  Western boundary.
c
            do 225 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        zvmbdw,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zvmbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 220 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) vbaroo(j,nn,itbp,west) = xvol(j)
# else
                  if (xvol(j).ne.spvl) vtrano(j,nn,itbp,west) = xvol(j)
# endif
 220           continue
 225        continue
c
c  Eastern boundary.
c
            do 235 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,jmt,nstflt,lrgtid,
     &                        zvmbde,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zvmbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 230 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) vbaroo(j,nn,itbp,east) = xvol(j)
# else
                  if (xvol(j).ne.spvl) vtrano(j,nn,itbp,east) = xvol(j)
# endif
 230           continue
 235        continue
c
c  Southern boundary.
c
            do 245 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        zvmbds,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zvmbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 240 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) vbaroo(i,nn,itbp,south) = xvol(i)
# else
                  if (xvol(i).ne.spvl) vtrano(i,nn,itbp,south) = xvol(i)
# endif
 240           continue
 245        continue
c
c  Northern boundary.
c
            do 255 nn = 1,nnmvb
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_RECV (xvol,imt,nstflt,lrgtid,
     &                        zvmbdn,comm_nest,recvstat,status)
#  else
               call hopsrecv ('NEST_RECBAR_BC',lrgtid,zvmbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_RECBAR_BC','UnPack',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 250 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) vbaroo(i,nn,itbp,north) = xvol(i)
# else
                  if (xvol(i).ne.spvl) vtrano(i,nn,itbp,north) = xvol(i)
# endif
 250           continue
 255        continue
c
# endif
          endif
       endif
c
#endif
c-----------------------------------------------------------------------
c  On first call, only need to spread data back in time.
c-----------------------------------------------------------------------
c
      if (itt.eq.0) then
c
c  East and West boundaries.
c
         do 260 nn = 1, 3
         do 260 j = 1, jmt
#if !defined surfpress
            qbc0(j,nn,itb ,west) = qbc0(j,nn,itbp,west)
            qbc0(j,nn,itbm,west) = qbc0(j,nn,itbp,west)
            qbc0(j,nn,itb ,east) = qbc0(j,nn,itbp,east)
            qbc0(j,nn,itbm,east) = qbc0(j,nn,itbp,east)
#elif !defined freesurf
            ubaroo(j,nn,itb ,west) = ubaroo(j,nn,itbp,west)
            ubaroo(j,nn,itbm,west) = ubaroo(j,nn,itbp,west)
            vbaroo(j,nn,itb ,west) = vbaroo(j,nn,itbp,west)
            vbaroo(j,nn,itbm,west) = vbaroo(j,nn,itbp,west)
            ubaroo(j,nn,itb ,east) = ubaroo(j,nn,itbp,east)
            ubaroo(j,nn,itbm,east) = ubaroo(j,nn,itbp,east)
            vbaroo(j,nn,itb ,east) = vbaroo(j,nn,itbp,east)
            vbaroo(j,nn,itbm,east) = vbaroo(j,nn,itbp,east)
#else
            utrano(j,nn,itb ,west) = utrano(j,nn,itbp,west)
            utrano(j,nn,itbm,west) = utrano(j,nn,itbp,west)
            vtrano(j,nn,itb ,west) = vtrano(j,nn,itbp,west)
            vtrano(j,nn,itbm,west) = vtrano(j,nn,itbp,west)
            utrano(j,nn,itb ,east) = utrano(j,nn,itbp,east)
            utrano(j,nn,itbm,east) = utrano(j,nn,itbp,east)
            vtrano(j,nn,itb ,east) = vtrano(j,nn,itbp,east)
            vtrano(j,nn,itbm,east) = vtrano(j,nn,itbp,east)
#endif
            pbc0(j,nn,itb ,west) = pbc0(j,nn,itbp,west)
            pbc0(j,nn,itbm,west) = pbc0(j,nn,itbp,west)
            pbc0(j,nn,itb ,east) = pbc0(j,nn,itbp,east)
            pbc0(j,nn,itbm,east) = pbc0(j,nn,itbp,east)
 260        continue
c
         if (nnmvb.gt.3) then
            do 263 nn = 4, nnmvb
            do 263 j = 1, jmt
#if !defined surfpress
#elif !defined freesurf
               ubaroo(j,nn,itb ,west) = ubaroo(j,nn,itbp,west)
               ubaroo(j,nn,itbm,west) = ubaroo(j,nn,itbp,west)
               vbaroo(j,nn,itb ,west) = vbaroo(j,nn,itbp,west)
               vbaroo(j,nn,itbm,west) = vbaroo(j,nn,itbp,west)
               ubaroo(j,nn,itb ,east) = ubaroo(j,nn,itbp,east)
               ubaroo(j,nn,itbm,east) = ubaroo(j,nn,itbp,east)
               vbaroo(j,nn,itb ,east) = vbaroo(j,nn,itbp,east)
               vbaroo(j,nn,itbm,east) = vbaroo(j,nn,itbp,east)
#else
               utrano(j,nn,itb ,west) = utrano(j,nn,itbp,west)
               utrano(j,nn,itbm,west) = utrano(j,nn,itbp,west)
               vtrano(j,nn,itb ,west) = vtrano(j,nn,itbp,west)
               vtrano(j,nn,itbm,west) = vtrano(j,nn,itbp,west)
               utrano(j,nn,itb ,east) = utrano(j,nn,itbp,east)
               utrano(j,nn,itbm,east) = utrano(j,nn,itbp,east)
               vtrano(j,nn,itb ,east) = vtrano(j,nn,itbp,east)
               vtrano(j,nn,itbm,east) = vtrano(j,nn,itbp,east)
#endif
c
 263        continue
         endif
c
c  North and South boundaries.
c
         do 270 nn = 1, 3
         do 270 i = 1, imt
#if !defined surfpress
            qbc0(i,nn,itb ,south) = qbc0(i,nn,itbp,south)
            qbc0(i,nn,itbm,south) = qbc0(i,nn,itbp,south)
            qbc0(i,nn,itb ,north) = qbc0(i,nn,itbp,north)
            qbc0(i,nn,itbm,north) = qbc0(i,nn,itbp,north)
#elif !defined freesurf
            ubaroo(i,nn,itb ,south) = ubaroo(i,nn,itbp,south)
            ubaroo(i,nn,itbm,south) = ubaroo(i,nn,itbp,south)
            vbaroo(i,nn,itb ,south) = vbaroo(i,nn,itbp,south)
            vbaroo(i,nn,itbm,south) = vbaroo(i,nn,itbp,south)
            ubaroo(i,nn,itb ,north) = ubaroo(i,nn,itbp,north)
            ubaroo(i,nn,itbm,north) = ubaroo(i,nn,itbp,north)
            vbaroo(i,nn,itb ,north) = vbaroo(i,nn,itbp,north)
            vbaroo(i,nn,itbm,north) = vbaroo(i,nn,itbp,north)
#else
            utrano(i,nn,itb ,south) = utrano(i,nn,itbp,south)
            utrano(i,nn,itbm,south) = utrano(i,nn,itbp,south)
            vtrano(i,nn,itb ,south) = vtrano(i,nn,itbp,south)
            vtrano(i,nn,itbm,south) = vtrano(i,nn,itbp,south)
            utrano(i,nn,itb ,north) = utrano(i,nn,itbp,north)
            utrano(i,nn,itbm,north) = utrano(i,nn,itbp,north)
            vtrano(i,nn,itb ,north) = vtrano(i,nn,itbp,north)
            vtrano(i,nn,itbm,north) = vtrano(i,nn,itbp,north)
#endif
            pbc0(i,nn,itb ,south) = pbc0(i,nn,itbp,south)
            pbc0(i,nn,itbm,south) = pbc0(i,nn,itbp,south)
            pbc0(i,nn,itb ,north) = pbc0(i,nn,itbp,north)
            pbc0(i,nn,itbm,north) = pbc0(i,nn,itbp,north)
c
 270     continue
c
         if (nnmvb.gt.3) then
         do 273 nn = 4, nnmvb
         do 273 i = 1, imt
#if !defined surfpress
#elif !defined freesurf
            ubaroo(i,nn,itb ,south) = ubaroo(i,nn,itbp,south)
            ubaroo(i,nn,itbm,south) = ubaroo(i,nn,itbp,south)
            vbaroo(i,nn,itb ,south) = vbaroo(i,nn,itbp,south)
            vbaroo(i,nn,itbm,south) = vbaroo(i,nn,itbp,south)
            ubaroo(i,nn,itb ,north) = ubaroo(i,nn,itbp,north)
            ubaroo(i,nn,itbm,north) = ubaroo(i,nn,itbp,north)
            vbaroo(i,nn,itb ,north) = vbaroo(i,nn,itbp,north)
            vbaroo(i,nn,itbm,north) = vbaroo(i,nn,itbp,north)
#else
            utrano(i,nn,itb ,south) = utrano(i,nn,itbp,south)
            utrano(i,nn,itbm,south) = utrano(i,nn,itbp,south)
            vtrano(i,nn,itb ,south) = vtrano(i,nn,itbp,south)
            vtrano(i,nn,itbm,south) = vtrano(i,nn,itbp,south)
            utrano(i,nn,itb ,north) = utrano(i,nn,itbp,north)
            utrano(i,nn,itbm,north) = utrano(i,nn,itbp,north)
            vtrano(i,nn,itb ,north) = vtrano(i,nn,itbp,north)
            vtrano(i,nn,itbm,north) = vtrano(i,nn,itbp,north)
#endif
c
 273     continue
         endif
c
         return
      endif
c
c-----------------------------------------------------------------------
c  Copy boundary data to old boundary arrays.
c-----------------------------------------------------------------------
c
c  East and West boundaries.
c
      do 280 j = 1, jmt
#ifndef surfpress
         po(j,2,west) = qbc0(j,1,itbp,west)/c2dtsf
         po(j,2,east) = qbc0(j,1,itbp,east)/c2dtsf
#endif
         po(j,1,west) = pbc0(j,1,itbp,west)
         po(j,1,east) = pbc0(j,1,itbp,east)
c
 280  continue
c
c  North and South boundaries.
c
      do 290 nn = 1, 3
      do 290 i = 1, imt
#ifndef surfpress
         po(i,2,south) = qbc0(i,1,itbp,south)/c2dtsf
         po(i,2,north) = qbc0(i,1,itbp,north)/c2dtsf
#endif
         po(i,1,south) = pbc0(i,1,itbp,south)
         po(i,1,north) = pbc0(i,1,itbp,north)
c
 290  continue
c
#ifdef sunflush
c
c  Flush output buffers.
c
      call flush(stdout)
#endif
c
      return
c
#ifndef surfpress
 900  format ('NEST_RECBAR_BC:  receiving boundary transport')
 910  format ('NEST_RECBAR_BC:  receiving bc for rate of change of ',
     &        'barotropic vorticity')
#else
 900  format ('NEST_RECBAR_BC:  receiving boundary pressure')
 910  format('NEST_RECBAR_BC:  receiving bc for vertically integrated ',
     &       'RHS')
#endif
c
      end
