#if !defined usrdiagnostic | !defined nesttime
      subroutine nest_snd_bc (n_tim,smlind)
#else
      subroutine nest_snd_bc (n_tim,smlind,tsn1,tsn2)
#endif
c
c=======================================================================
c                                                                    ===
c This routine sends the boundary conditions to a smaller domain.    ===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c    N_TIM     Current time step.                        (integer)   ===
c    SMLIND    Index for small domain.                   (integer)   ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /FIELDS/                                                           ===
c                                                                    ===
# ifndef surfpress
c    P         Transport stream function.            (real array)    ===
c    ZTDB      Preserved time change of vorticity.   (real array)    ===
# else
c    P         Surface Pressure.                     (real array)    ===
c                                                                    ===
c /fieldsbar/                                                        ===
c                                                                    ===
c    UBARONEW  updated zonal external mode velocity.     (real array)===
c    VBARONEW  updated meridional external mode velocity.(real array)===
c                                                                    ===
#  ifdef freesurf
c /vertslabs/                                                        ===
c                                                                    ===
c    HDVCF   weighted  bottom topography, V-points.   (real array)   ===
#  endif
# endif
c                                                                    ===
#ifdef coast
c /FULLWD/                                                           ===
c                                                                    ===
c    LANDT     Land/sea mask at tracer points.       (integer array) ===
c    LANDV     Land/sea mask at velocity points.     (integer array) ===
c                                                                    ===
#endif
c                                                                    ===
c /IOUNITS/                                                          ===
c                                                                    ===
c    STDOUT    Unit number for standard output.          (integer)   ===
c                                                                    ===
c /NEST/                                                             ===
c                                                                    ===
c    I_LL_S    Lower left corner of smaller grid in                  ===
c              current grid.                             (integer)   ===
c    J_LL_S    Lower left corner of current grid in                  ===
c              larger grid.                              (integer)   ===
c    NXS       Number of x-grid points in smaller grid.  (integer)   ===
c    NYS       Number of y-grid points in smaller grid.  (integer)   ===
c    SMLTID    PVM task identifier for smaller grid.     (integer)   ===
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:                     ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c          IOPT(9)  Number of tracers exchanged with smaller domain. ===
c                                                                    ===
c /RHOMEAN/                                                          ===
c                                                                    ===
c    SMEAN     Mean salinity subtracted during                       ===
c              computations.                             (real)      ===
c                                                                    ===
c /VOLDAT/                                                           ===
c                                                                    ===
c    XT        Tracer fields.                            (real array)===
c    XU        Zonal internal mode velocity.             (real array)===
c    XV        Meridional internal mode velocity.        (real array)===
c                                                                    ===
#if defined usrdiagnostic & defined nesttime
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
c                                                                    ===
c    TSN1      Time spent in communications.          (real vector)  ===
c    TSN2      Time spent in auxillary calculations.  (real vector)  ===
c                                                                    ===
#endif
#if !defined coast
c  Calls:      BESS2D,       NEST_ERRCHK                             ===
#elif defined surfpress
c  Calls:      BESS2D_MSK,   NEST_ERRCHK                             ===
#else
c  Calls:      BESS2D_MSK,   BESS2D_PMSK,   NEST_ERRCHK              ===
#endif
c  PVM Calls:  PVMFINITSEND,  PVMFPACK,    PVMFSEND                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <fields.h>
#include <iounits.h>
#include <nest.h>
#include <options.h>
#include <rhomean.h>
#include <voldat.h>
#ifdef coast
# include <fullwd.h>
#endif
#ifdef surfpress
# include <fieldsbar.h>
# ifdef freesurf
#  include <vertslabs.h>
#  include <vertical.h>
# endif
#endif
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer n_tim,smlind,toff
#ifndef nestnultest
     &        ,bufid,i_p,i_s,ip,j_s,j_p,k,n,nn,status
      FLOAT
     &       trc_shft,x,y
# if defined surfpress & defined freesurf 
     &       ,fx
# endif
      FLOAT
     &      wk(nwds,km)
      FLOAT
# if !defined coast
     &      bess2d
# elif defined surfpress
     &      bess2d_msk
# else
     &      bess2d_msk,bess2d_pmsk
# endif
#endif
#if defined usrdiagnostic & defined nesttime
      FLOAT
     &      tsn1(2),tsn2(2)
# ifndef nestnultest
     &      ,twk(2)
# endif
# ifdef iforttime
     &      ,dum
      FLOAT
     &      dtime
# endif
#endif
      logical first
c
      save first,toff
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set tracer code offset.
c-----------------------------------------------------------------------
c
      if (first) then
         toff  = trofst + iopt(9) + 1
         first = .false.
      end if
c
c-----------------------------------------------------------------------
c  Send boundary conditions for 3D fields.
c-----------------------------------------------------------------------
c
      if (n_tim.ge.nest_start) then
#ifndef nestnultest
c
         if (iopt(5).eq.1) write (stdout,900)
c
c  -- Internal mode zonal velocity.
c
c     Scale by box thickness to ensure baroclinicity.
c
         call scalvcln (xu,wk)
c
c     Western boundary
c
         do 55 i_s = 1, nnmvbs(smlind)
            i_p = i_ll_s(smlind)-2+(i_s+2)/3
            x = FLoaT( mod(i_s+2,3) )*r3
            do 50 k = 1, km
            do 50 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
  50        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,
     &                     smltid(smlind),ucbdyw,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),ucbdyw,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
  55     continue
c
c     Eastern boundary
c
         do 65 i_s = nxs(smlind)-1, nxs(smlind)-nnmvbs(smlind), -1
            i_p = i_ll_s(smlind)-2+(i_s+2)/3
            x = FLoaT( mod(i_s+2,3) )*r3
            do 60 k = 1, km
            do 60 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
  60        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,
     &                     smltid(smlind),ucbdye,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),ucbdye,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
  65     continue
c
c     Southern boundary
c
         do 75 j_s = 1, nnmvbs(smlind)
            j_p = j_ll_s(smlind)-2+(j_s+2)/3
            y = FLoaT( mod(j_s+2,3) )*r3
            do 70 k = 1, km
            do 70 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
  70        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,
     &                     smltid(smlind),ucbdys,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),ucbdys,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
  75     continue
c
c     Northern boundary
c
         do 85 j_s = nys(smlind)-1, nys(smlind)-nnmvbs(smlind), -1
            j_p = j_ll_s(smlind)-2+(j_s+2)/3
            y = FLoaT( mod(j_s+2,3) )*r3
            do 80 k = 1, km
            do 80 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
  80        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,
     &                     smltid(smlind),ucbdyn,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),ucbdyn,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
  85     continue
c
c  -- Internal mode meridional velocity.
c
c     Scale by box thickness to ensure baroclinicity.
c
         call scalvcln (xv,wk)
c
c     Western boundary
c
         do 95 i_s = 1, nnmvbs(smlind)
            i_p = i_ll_s(smlind)-2+(i_s+2)/3
            x = FLoaT( mod(i_s+2,3) )*r3
            do 90 k = 1, km
            do 90 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
  90        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,
     &                     smltid(smlind),vcbdyw,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),vcbdyw,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
  95     continue
c
c     Eastern boundary
c
         do 105 i_s = nxs(smlind)-1, nxs(smlind)-nnmvbs(smlind), -1
            i_p = i_ll_s(smlind)-2+(i_s+2)/3
            x = FLoaT( mod(i_s+2,3) )*r3
            do 100 k = 1, km
            do 100 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
 100        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,
     &                     smltid(smlind),vcbdye,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),vcbdye,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
 105     continue
c
c     Southern boundary
c
         do 115 j_s = 1, nnmvbs(smlind)
            j_p = j_ll_s(smlind)-2+(j_s+2)/3
            y = FLoaT( mod(j_s+2,3) )*r3
            do 110 k = 1, km
            do 110 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
 110        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,
     &                     smltid(smlind),vcbdys,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),vcbdys,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
 115     continue
c
c     Northern boundary
c
         do 125 j_s = nys(smlind)-1, nys(smlind)-nnmvbs(smlind), -1
            j_p = j_ll_s(smlind)-2+(j_s+2)/3
            y = FLoaT( mod(j_s+2,3) )*r3
            do 120 k = 1, km
            do 120 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
# ifndef coast
               xvol(ip) = bess2d (i_p,j_p,x,y,wk(1,k),imt,jmt)
#  if defined surfpress & defined freesurf 
               xvol(ip) = xvol(ip) / bess2d(i_p,j_p,x,y,fracv,imt,jmt)
#  endif
# else
               xvol(ip)= bess2d_msk (i_p,j_p,x,y,wk(1,k),landv,imt,
     &                               jmt,v_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fracv,landv,imt,jmt,v_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
# endif
 120        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,
     &                     smltid(smlind),vcbdyn,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),vcbdyn,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
 125     continue
c
c  -- Tracers.
c
         do 170 n = 1, iopt(9)
         do 170 nn = 1, nnmtbs(smlind)
c
            if (n.ne.2) then
               trc_shft = c0
              else
               trc_shft = smean
            end if
            call scaltrc (xt(1,1,n),wk)
c
c     Western boundary
c
            i_s = nn
            i_p = i_ll_s(smlind)-1+i_s/3
            x = FLoaT( mod(i_s,3) )*r3
            do 130 k = 1, km
            do 130 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
# ifndef coast
#  if !defined surfpress | !defined freesurf 
               xvol(ip) = bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt) + trc_shft
#  else
               fx = bess2d (i_p,j_p,x,y,fract,imt,jmt)
               xvol(ip)=bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt)/fx +trc_shft
#  endif
# else
               xvol(ip) =bess2d_msk (i_p,j_p,x,y,wk(1,k),landt,imt,
     &                               jmt,t_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fract,landt,imt,jmt,t_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
               if (xvol(ip).ne.spv) xvol(ip) = xvol(ip) + trc_shft
# endif
 130        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,
     &                     smltid(smlind),toff+(n-1)*4,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),toff+(n-1)*4,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
c
c     Eastern boundary
c
            i_s = nxs(smlind)+1-nn
            i_p = i_ll_s(smlind)-1+i_s/3
            x = FLoaT( mod(i_s,3) )*r3
            do 140 k = 1, km
            do 140 j_s = 1, nys(smlind)
               ip = j_s + (k-1)*nys(smlind)
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
# ifndef coast
#  if !defined surfpress | !defined freesurf 
               xvol(ip) = bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt) + trc_shft
#  else
               fx = bess2d (i_p,j_p,x,y,fract,imt,jmt)
               xvol(ip)=bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt)/fx +trc_shft
#  endif
# else
               xvol(ip) = bess2d_msk (i_p,j_p,x,y,wk(1,k),landt,imt,
     &                                jmt,t_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fract,landt,imt,jmt,t_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
               if (xvol(ip).ne.spv) xvol(ip) = xvol(ip) + trc_shft
# endif
 140        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind)*km,nstflt,smltid(smlind),
     &                     toff+1+(n-1)*4,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),toff+1+(n-1)*4,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
c
c     Southern boundary
c
            j_s = nn
            j_p = j_ll_s(smlind)-1+j_s/3
            y = FLoaT( mod(j_s,3) )*r3
            do 150 k = 1, km
            do 150 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
# ifndef coast
#  if !defined surfpress | !defined freesurf 
               xvol(ip) = bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt) + trc_shft
#  else
               fx = bess2d (i_p,j_p,x,y,fract,imt,jmt)
               xvol(ip)=bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt)/fx +trc_shft
#  endif
# else
               xvol(ip) = bess2d_msk (i_p,j_p,x,y,wk(1,k),landt,imt,
     &                                jmt,t_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fract,landt,imt,jmt,t_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
               if (xvol(ip).ne.spv) xvol(ip) = xvol(ip) + trc_shft
# endif
 150        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,smltid(smlind),
     &                     toff+2+(n-1)*4,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),toff+2+(n-1)*4,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
c
c     Northern boundary
c
            j_s = nys(smlind)-nn
            j_p = j_ll_s(smlind)-1+j_s/3
            y = FLoaT( mod(j_s,3) )*r3
            do 160 k = 1, km
            do 160 i_s = 1, nxs(smlind)
               ip = i_s + (k-1)*nxs(smlind)
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
# ifndef coast
#  if !defined surfpress | !defined freesurf 
               xvol(ip) = bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt) + trc_shft
#  else
               fx = bess2d (i_p,j_p,x,y,fract,imt,jmt)
               xvol(ip)=bess2d(i_p,j_p,x,y,wk(1,k),imt,jmt)/fx +trc_shft
#  endif
# else
               xvol(ip) = bess2d_msk (i_p,j_p,x,y,wk(1,k),landt,imt,
     &                                jmt,t_act,spv)
#  if defined surfpress & defined freesurf 
               fx =bess2d_msk(i_p,j_p,x,y,fract,landt,imt,jmt,t_act,spv)
               if((xvol(ip).ne.spv).and.(fx.ne.spv).and.(fx.ne.c0)) then
                  xvol(ip) = xvol(ip)/fx
               else
                  xvol(ip) = spv
               endif
#  endif
               if (xvol(ip).ne.spv) xvol(ip) = xvol(ip) + trc_shft
# endif
 160        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind)*km,nstflt,smltid(smlind),
     &                     toff+3+(n-1)*4,comm_nest,status)
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SND_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind)*km,1,status)
            call nest_errchk ('NEST_SND_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),toff+3+(n-1)*4,status)
            call nest_errchk ('NEST_SND_BC','Send',status,1,1,1)
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
c
 170     continue
c
#endif
      end if
c
#ifdef sunflush
c
c  Flush output buffers.
c
      call flush(stdout)
#endif
c
      return
c
 900  format ('NEST_SND_BC:  sending bc for 3D fields')
c
      end
