#if !defined usrdiagnostic | !defined nesttime
      subroutine nest_sndbar_bc (n_tim,smlind)
#else
      subroutine nest_sndbar_bc (n_tim,smlind,tsn1,tsn2)
#endif
c
c=======================================================================
c                                                                    ===
c This routine sends the boundary conditions to a smaller domain.    ===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c    N_TIM     Current time step.                        (integer)   ===
c    SMLIND    Index for small domain.                   (integer)   ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /FIELDS/                                                           ===
c                                                                    ===
# ifndef surfpress
c    P         Transport stream function.            (real array)    ===
c    ZTDB      Preserved time change of vorticity.   (real array)    ===
# else
c    P         Surface Pressure.                     (real array)    ===
c                                                                    ===
c /fieldsbar/                                                        ===
c                                                                    ===
c    UBARONEW  updated zonal external mode velocity.     (real array)===
c    VBARONEW  updated meridional external mode velocity.(real array)===
c                                                                    ===
#  ifdef freesurf
c /vertslabs/                                                        ===
c                                                                    ===
c    HDVCF   weighted  bottom topography, V-points.   (real array)   ===
#  endif
# endif
c                                                                    ===
#ifdef coast
c /FULLWD/                                                           ===
c                                                                    ===
c    LANDT     Land/sea mask at tracer points.       (integer array) ===
c    LANDV     Land/sea mask at velocity points.     (integer array) ===
c                                                                    ===
#endif
c                                                                    ===
c /IOUNITS/                                                          ===
c                                                                    ===
c    STDOUT    Unit number for standard output.          (integer)   ===
c                                                                    ===
c /NEST/                                                             ===
c                                                                    ===
c    I_LL_S    Lower left corner of smaller grid in                  ===
c              current grid.                             (integer)   ===
c    J_LL_S    Lower left corner of current grid in                  ===
c              larger grid.                              (integer)   ===
c    NXS       Number of x-grid points in smaller grid.  (integer)   ===
c    NYS       Number of y-grid points in smaller grid.  (integer)   ===
c    SMLTID    PVM task identifier for smaller grid.     (integer)   ===
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:                     ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c          IOPT(9)  Number of tracers exchanged with smaller domain. ===
c                                                                    ===
#if defined usrdiagnostic & defined nesttime
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
c                                                                    ===
c    TSN1      Time spent in communications.          (real vector)  ===
c    TSN2      Time spent in auxillary calculations.  (real vector)  ===
c                                                                    ===
#endif
#if !defined coast
c  Calls:      BESS2D,       NEST_ERRCHK                             ===
#elif defined surfpress
c  Calls:      BESS2D_MSK,   NEST_ERRCHK                             ===
#else
c  Calls:      BESS2D_MSK,   BESS2D_PMSK,   NEST_ERRCHK              ===
#endif
c  PVM Calls:  PVMFINITSEND,  PVMFPACK,    PVMFSEND                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <fields.h>
#include <iounits.h>
#include <nest.h>
#include <options.h>
#ifdef coast
# include <fullwd.h>
#endif
#ifdef surfpress
# include <fieldsbar.h>
# ifdef freesurf
#  include <vertslabs.h>
#  include <vertical.h>
# endif
#endif
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer n_tim,smlind
#ifndef nestnultest
     &        ,bufid,i_p,i_s,ip,j_s,j_p,k,n,nn,status
      FLOAT
     &       trc_shft,x,y
# if defined surfpress & defined freesurf 
     &       ,fx
# endif
      FLOAT
     &      wk(nwds,km)
      FLOAT
# if !defined coast
     &      bess2d
# elif defined surfpress
     &      bess2d_msk
# else
     &      bess2d_msk,bess2d_pmsk
# endif
#endif
#if defined usrdiagnostic & defined nesttime
      FLOAT
     &      tsn1(2),tsn2(2)
# ifndef nestnultest
     &      ,twk(2)
# endif
# ifdef iforttime
     &      ,dum
      FLOAT
     &      dtime
# endif
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
#ifndef surfpress
c  Send boundary conditions for transport streamfunction.
#else
c  Send boundary conditions for surface pressure.
#endif
c-----------------------------------------------------------------------
c
      if(n_tim.ge.nest_start)then
#ifndef nestnultest
c
         if (iopt(5).eq.1) write (stdout,900)
c
c  Western boundary.
c
         do i_s = 1, 3
            i_p = i_ll_s(smlind)-1+i_s/3
            x = FLoaT( mod(i_s,3) )*r3
            do 10 j_s = 1, nys(smlind)
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
# if !defined coast
               xvol(j_s) = bess2d (i_p,j_p,x,y,p,imt,jmt)
#  ifdef surfpress
               xvolb(j_s) = bess2d (i_p,j_p,x,y,pb,imt,jmt)
#  endif
# elif defined surfpress
               xvol(j_s) = bess2d_msk (i_p,j_p,x,y,p,landt,imt,jmt,
     &                                 t_act,spv)
               xvolb(j_s) = bess2d_msk (i_p,j_p,x,y,pb,landt,imt,jmt,
     &                                  t_act,spv)
# else
               xvol(j_s) = bess2d_pmsk (i_p,j_p,x,y,p,landp,imt,jmt,0,
     &                                  ncseg,mclen,icoast,jcoast,spv)
# endif
  10        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind),nstflt,
     &                     smltid(smlind),psibdw,comm_nest,status)
#  ifdef surfpress
            call MPI_SEND (xvolb,nys(smlind),nstflt,
     &                     smltid(smlind),psibdw,comm_nest,status)
#  endif
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibdw,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  ifdef surfpress
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvolb,nys(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibdw,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
         enddo
c
c  Eastern boundary.
c
         do i_s = nxs(smlind), nxs(smlind)-2, -1
            i_p = i_ll_s(smlind)-1+i_s/3
            x = FLoaT( mod(i_s,3) )*r3
            do 20 j_s = 1, nys(smlind)
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
# if !defined coast
               xvol(j_s) = bess2d (i_p,j_p,x,y,p,imt,jmt)
#  ifdef surfpress
               xvolb(j_s) = bess2d (i_p,j_p,x,y,pb,imt,jmt)
#  endif
# elif defined surfpress
               xvol(j_s) = bess2d_msk (i_p,j_p,x,y,p,landt,imt,jmt,
     &                                 t_act,spv)
               xvolb(j_s) = bess2d_msk (i_p,j_p,x,y,pb,landt,imt,jmt,
     &                                  t_act,spv)
# else
               xvol(j_s) = bess2d_pmsk (i_p,j_p,x,y,p,landp,imt,jmt,0,
     &                                  ncseg,mclen,icoast,jcoast,spv)
# endif
  20        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nys(smlind),nstflt,
     &                     smltid(smlind),psibde,comm_nest,status)
#  ifdef surfpress
            call MPI_SEND (xvolb,nys(smlind),nstflt,
     &                     smltid(smlind),psibde,comm_nest,status)
#  endif
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nys(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibde,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  ifdef surfpress
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvolb,nys(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibde,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
         enddo
c
c  Southern boundary.
c
         do j_s = 1, 3
            j_p = j_ll_s(smlind)-1+j_s/3
            y = FLoaT( mod(j_s,3) )*r3
            do 30 i_s = 1, nxs(smlind)
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
# if !defined coast
               xvol(i_s) = bess2d (i_p,j_p,x,y,p,imt,jmt)
#  ifdef surfpress
               xvolb(i_s) = bess2d (i_p,j_p,x,y,pb,imt,jmt)
#  endif
# elif defined surfpress
               xvol(i_s) = bess2d_msk (i_p,j_p,x,y,p,landt,imt,jmt,
     &                                 t_act,spv)
               xvolb(i_s) = bess2d_msk (i_p,j_p,x,y,pb,landt,imt,jmt,
     &                                  t_act,spv)
# else
               xvol(i_s) = bess2d_pmsk (i_p,j_p,x,y,p,landp,imt,jmt,0,
     &                                  ncseg,mclen,icoast,jcoast,spv)
# endif
  30        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind),nstflt,
     &                     smltid(smlind),psibds,comm_nest,status)
#  ifdef surfpress
            call MPI_SEND (xvolb,nxs(smlind),nstflt,
     &                     smltid(smlind),psibds,comm_nest,status)
#  endif
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibds,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  ifdef surfpress
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvolb,nxs(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibds,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
         enddo
c
c  Northern boundary.
c
         do j_s = nys(smlind), nys(smlind)-2, -1
            j_p = j_ll_s(smlind)-1+j_s/3
            y = FLoaT( mod(j_s,3) )*r3
            do 40 i_s = 1, nxs(smlind)
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
# if !defined coast
               xvol(i_s) = bess2d (i_p,j_p,x,y,p,imt,jmt)
#  ifdef surfpress
               xvolb(i_s) = bess2d (i_p,j_p,x,y,pb,imt,jmt)
#  endif
# elif defined surfpress
               xvol(i_s) = bess2d_msk (i_p,j_p,x,y,p,landt,imt,jmt,
     &                                 t_act,spv)
               xvolb(i_s) = bess2d_msk (i_p,j_p,x,y,pb,landt,imt,jmt,
     &                                  t_act,spv)
# else
               xvol(i_s) = bess2d_pmsk (i_p,j_p,x,y,p,landp,imt,jmt,0,
     &                               ncseg,mclen,icoast,jcoast,spv)
# endif
  40        continue
c
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
# ifdef use_mpi
            call MPI_SEND (xvol,nxs(smlind),nstflt,
     &                     smltid(smlind),psibdn,comm_nest,status)
#  ifdef surfpress
            call MPI_SEND (xvolb,nxs(smlind),nstflt,
     &                     smltid(smlind),psibdn,comm_nest,status)
#  endif
# else
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibdn,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  ifdef surfpress
            call pvmfinitsend (PVM_DATAMETHOD,bufid)
            call nest_errchk ('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
            call pvmfpack (nstflt,xvolb,nxs(smlind),1,status)
            call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
            call pvmfsend (smltid(smlind),psibdn,status)
            call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
# endif
# if defined usrdiagnostic & defined nesttime
#  ifndef iforttime
            call dtime (twk)
#  else
            dum = dtime (twk)
#  endif
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
         enddo
c
#endif
      endif
c
#ifndef surfpress
c-----------------------------------------------------------------------
c  Send ZTD boundary conditions to smaller domain.  Looking in variable
c  ZTDB since relax modified ZTD but saved a copy in ZTDB.
c-----------------------------------------------------------------------
c
      if (n_tim.ge.nest_start) then
         if(mod(n_tim,itt_fac).eq.0)then
# ifndef nestnultest
c
         if (iopt(5).eq.1) write (stdout,910)
c
c  Western boundary of smaller domain.
c
            do 185 i_s = 2, 4
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
               do 180 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-1+j_s/3
                  y = FLoaT( mod(j_s,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,ztdb,imt,jmt)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,ztdb,landt,imt,
     &                                    jmt,t_act,spv)
#  endif
 180           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        vrtbdw,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),vrtbdw,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 185        continue
c
c  Eastern boundary of smaller domain.
c
            do 195 i_s = nxs(smlind)-1, nxs(smlind)-3, -1
               i_p = i_ll_s(smlind)-1+i_s/3
               x = FLoaT( mod(i_s,3) )*r3
               do 190 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-1+j_s/3
                  y = FLoaT( mod(j_s,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,ztdb,imt,jmt)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,ztdb,landt,imt,
     &                                    jmt,t_act,spv)
#  endif
 190           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        vrtbde,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),vrtbde,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 195        continue
c
c  Southern boundary of smaller domain.
c
            do 205 j_s = 2, 4
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
               do 200 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-1+i_s/3
                  x = FLoaT( mod(i_s,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,ztdb,imt,jmt)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,ztdb,landt,imt,
     &                                    jmt,t_act,spv)
#  endif
 200           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        vrtbds,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),vrtbds,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 205        continue
c
c  Northern boundary of smaller domain.
c
            do 215 j_s = nys(smlind)-1, nys(smlind)-3, -1
               j_p = j_ll_s(smlind)-1+j_s/3
               y = FLoaT( mod(j_s,3) )*r3
               do 210 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-1+i_s/3
                  x = FLoaT( mod(i_s,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,ztdb,imt,jmt)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,ztdb,landt,imt,
     &                                    jmt,t_act,spv)
#  endif
 210           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        vrtbdn,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),vrtbdn,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
# endif
 215        continue
          endif
      endif
#else
c-----------------------------------------------------------------------
# ifndef freesurf
c  Send barotropic velocity BCs from larger domain.
# else
c  Send transport BCs from larger domain.
# endif
c-----------------------------------------------------------------------
c
      if (n_tim.ge.nest_start) then
         if(mod(n_tim,itt_fac).eq.0)then
# ifndef nestnultest
c
         if (iopt(5).eq.1) write (stdout,910)
c
c  -------------
c  --- Zonal ---
c  -------------
c
            do 175 j_s = 1, jmt
            do 175 i_s = 1, imt
               ip = i_s + (j_s-1)*imt
# ifndef freesurf
               wk(ip,1) = ubaronew(i_s,j_s)
# elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               wk(ip,1) = ubaronew(i_s,j_s)*hdvcf(i_s,j_s)
# else
               wk(ip,1) = ubaronew(i_s,j_s)*hdvcfx(i_s,j_s)
# endif
 175        continue
c
c  Western boundary of smaller domain.
c
            do 185 i_s = 1, nnmvbs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
               do 180 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-2+(j_s+2)/3
                  y = FLoaT( mod(j_s+2,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,uland,imt,jmt,
     &                                    1,spv)
#  endif
 180           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        zumbdw,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zumbdw,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 185        continue
c
c  Eastern boundary of smaller domain.
c
            do 195 i_s = nxs(smlind)-1, nxs(smlind)-nnmvbs(smlind), -1
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
               do 190 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-2+(j_s+2)/3
                  y = FLoaT( mod(j_s+2,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,uland,imt,jmt,
     &                                    1,spv)
#  endif
 190           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        zumbde,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zumbde,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 195        continue
c
c  Southern boundary of smaller domain.
c
            do 205 j_s = 1,nnmvbs(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
               do 200 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-2+(i_s+2)/3
                  x = FLoaT( mod(i_s+2,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,uland,imt,jmt,
     &                                    1,spv)
#  endif
 200           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        zumbds,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zumbds,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 205        continue
c
c  Northern boundary of smaller domain.
c
            do 215 j_s = nys(smlind)-1, nys(smlind)-nnmvbs(smlind), -1
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
               do 210 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-2+(i_s+2)/3
                  x = FLoaT( mod(i_s+2,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,uland,imt,jmt,
     &                                    1,spv)
#  endif
 210           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        zumbdn,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zumbdn,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 215        continue
c
c  ------------------
c  --- Meridional ---
c  ------------------
c
            do 217 j_s = 1, jmt
            do 217 i_s = 1, imt
               ip = i_s + (j_s-1)*imt
# ifndef freesurf
               wk(ip,1) = vbaronew(i_s,j_s)
# elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
               wk(ip,1) = vbaronew(i_s,j_s)*hdvcf(i_s,j_s)
# else
               wk(ip,1) = vbaronew(i_s,j_s)*hdvcfy(i_s,j_s)
# endif
 217        continue
c
c  Western boundary of smaller domain.
c
            do 225 i_s = 1, nnmvbs(smlind)
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
               do 220 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-2+(j_s+2)/3
                  y = FLoaT( mod(j_s+2,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,vland,imt,jmt,
     &                                    1,spv)
#  endif
 220           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        zvmbdw,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zvmbdw,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 225        continue
c
c  Eastern boundary of smaller domain.
c
            do 235 i_s = nxs(smlind)-1, nxs(smlind)-nnmvbs(smlind), -1
               i_p = i_ll_s(smlind)-2+(i_s+2)/3
               x = FLoaT( mod(i_s+2,3) )*r3
               do 230 j_s = 1, nys(smlind)
                  j_p = j_ll_s(smlind)-2+(j_s+2)/3
                  y = FLoaT( mod(j_s+2,3) )*r3
#  ifndef coast
                  xvol(j_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(j_s) = bess2d_msk (i_p,j_p,x,y,wk,vland,imt,jmt,
     &                                    1,spv)
#  endif
 230           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nys(smlind),nstflt,smltid(smlind),
     &                        zvmbde,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nys(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zvmbde,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 235        continue
c
c  Southern boundary of smaller domain.
c
            do 245 j_s = 1, nnmvbs(smlind)
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
               do 240 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-2+(i_s+2)/3
                  x = FLoaT( mod(i_s+2,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,vland,imt,jmt,
     &                                    1,spv)
#  endif
 240           continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        zvmbds,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zvmbds,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
 245        continue
c
c  Northern boundary of smaller domain.
c
            do 255 j_s = nys(smlind)-1, nys(smlind)-nnmvbs(smlind), -1
               j_p = j_ll_s(smlind)-2+(j_s+2)/3
               y = FLoaT( mod(j_s+2,3) )*r3
               do 250 i_s = 1, nxs(smlind)
                  i_p = i_ll_s(smlind)-2+(i_s+2)/3
                  x = FLoaT( mod(i_s+2,3) )*r3
#  ifndef coast
                  xvol(i_s) = bess2d (i_p,j_p,x,y,wk,imt,jmt)
#  elif !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,landv,imt,jmt,
     &                                    v_act,spv)
#  else
                  xvol(i_s) = bess2d_msk (i_p,j_p,x,y,wk,vland,imt,jmt,
     &                                    1,spv)
#  endif
 250        continue
c
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
#  ifdef use_mpi
               call MPI_SEND (xvol,nxs(smlind),nstflt,smltid(smlind),
     &                        zvmbdn,comm_nest,status)
#  else
               call pvmfinitsend (PVM_DATAMETHOD,bufid)
               call nest_errchk('NEST_SNDBAR_BC','InitSend',bufid,1,1,1)
               call pvmfpack (nstflt,xvol,nxs(smlind),1,status)
               call nest_errchk ('NEST_SNDBAR_BC','Pack',status,1,1,1)
               call pvmfsend (smltid(smlind),zvmbdn,status)
               call nest_errchk ('NEST_SNDBAR_BC','Send',status,1,1,1)
#  endif
#  if defined usrdiagnostic & defined nesttime
#   ifndef iforttime
               call dtime (twk)
#   else
               dum = dtime (twk)
#   endif
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
# endif
 255        continue
          endif
      endif
#endif
#ifdef sunflush
c
c  Flush output buffers.
c
      call flush(stdout)
#endif
c
      return
c
#ifndef surfpress
 900  format ('NEST_SNDBAR_BC:  sending boundary transport')
 910  format ('NEST_SNDBAR_BC:  sending bc for rate of change of ',
     &        'barotropic vorticity')
#else
 900  format ('NEST_SNDBAR_BC:  sending boundary pressure')
 910  format ('NEST_SNDBAR_BC:  sending bc for vertically integrated ',
     &        'RHS')
#endif
c
      end
