      subroutine nest_spawn
c
c=======================================================================
c                                                                    ===
c  This routine spawns a nested subdomain process.                   ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /IOUNITS/                                                         ===
c                                                                    ===
c     SMLHNM   Name of host on which to run smaller grid.   (string) ===
c     SMLINM   Name of param. input file for smaller grid.  (string) ===
c     SMLONM   Name of output log file for smaller grid.    (string) ===
c     SMLTNM   Name of executable for smaller grid.         (string) ===
c     STDOUT   standard output logical unit.                (integer)===
c                                                                    ===
c  /NEST/                                                            ===
c                                                                    ===
c     NOSUBD   number of nested sub-domains.                (integer)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /NEST/                                                            ===
c                                                                    ===
c     SMLTID    PVM task identifier for smaller grid.   (integer)    ===
c                                                                    ===
c  Calls:      EXITUS,        LENGTH,    HOPSRECV,  HOST_CHECK,      ===
c              NEST_ERRCHK                                           ===
c  PVM Calls:  PVMFINITSEND,  PVMFPACK,  PVMFSEND,  PVMFSPAWN,       ===
c              PVMFUNPACK                                            ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <iounits.h>
#include <nest.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bufid,lenstr,lnstr2,n,nsml,recval,sbgn,sbn2,send,snd2,
     &        status,testval
#ifdef use_mpi
      integer recvstat(MPI_STATUS_SIZE)
#endif
      logical hostok
#if defined use_mpi & !defined nest2larger
      integer       wkchlid,wkid
      character*128 wkname
#endif
c
      parameter (testval=8)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Loop over all subdomains.
c-----------------------------------------------------------------------
c
      do 10, n = 1, nosubd
c
c-----------------------------------------------------------------------
c  Spawn nested subdomain process.
c-----------------------------------------------------------------------
c
         call length (smltnm(n),lenstr,sbgn,send)
         call flush (stdout)
#ifdef use_mpi
# if !defined nest2larger
         call getchildid (smltnm(n)(sbgn:send),0,smltid(n))
         call MPI_SEND (0, 1, MPI_INTEGER4, smltid(n), nstparid,
     &                  comm_nest, status)
# else
         call MPI_SEND (lenstr, 1, MPI_INTEGER4, 0, lnchlnam,
     &                  comm_nest, status)
         call MPI_SEND (smltnm(n)(sbgn:send), lenstr, MPI_CHARACTER, 0,
     &                  chlname, comm_nest, status)
         call MPI_RECV (smltid(n), 1, MPI_INTEGER4, 0, chldid,
     &                  comm_nest, recvstat, status)
# endif
#else
         call host_check (smlhnm(n),lnstr2,sbn2,snd2,hostok)
c
         if (.not.hostok) then
            call pvmfspawn (smltnm(n)(sbgn:send),PVMTASKDEFAULT,'*',1,
     &                      smltid(n),nsml)
          else
            call pvmfspawn (smltnm(n)(sbgn:send),PVMTASKHOST,
     &                      smlhnm(n)(sbn2:snd2),1,smltid(n),nsml)
         endif
c
         call nest_errchk ('NEST_SPAWN','Spawn',0,1,smltid(n),nsml)
#endif
c
c-----------------------------------------------------------------------
c  Test the connection.
c-----------------------------------------------------------------------
c
c  Send test integer value to smaller domain.
c
#ifdef use_mpi
         call MPI_SEND (testval, 1, MPI_INTEGER4, smltid(n),spts2s,
     &                  comm_nest, status)
#else
         call pvmfinitsend (PVM_DATAMETHOD,bufid)
         call nest_errchk ('NEST_SPAWN','InitSend',bufid,1,1,1)
         call pvmfpack (INTEGER4,testval,1,1,status)
         call nest_errchk ('NEST_SPAWN','Pack',status,1,1,1)
         call pvmfsend (smltid(n),spts2s,status)
         call nest_errchk ('NEST_SPAWN','Send',status,1,1,1)
#endif
c
c  Receive test integer value from smaller domain.
c
#ifdef use_mpi
         call MPI_RECV (recval, 1, MPI_INTEGER4, smltid(n),spts2l,
     &                  comm_nest, recvstat, status)
#else
         call hopsrecv ('NEST_SPAWN',smltid(n),spts2l,bufid)
         call pvmfunpack (INTEGER4,recval,1,1,status)
         call nest_errchk ('NEST_SPAWN','UnPack',status,1,1,1)
#endif
c
c  Compare values.
c
         if (testval.ne.recval) then
            write (stdout,900) testval,recval
            call exitus ('NEST_SPAWN')
         end if
c
c-----------------------------------------------------------------------
c  Send I/O file names for smaller domain.
c-----------------------------------------------------------------------
c
c  Send input file name & its length to smaller domain.
c
         call length (smlinm(n),lenstr,sbgn,send)
#ifdef use_mpi
         call MPI_SEND (lenstr,1,MPI_INTEGER4,smltid(n),lnifil,
     &                  comm_nest, status)
#else
         call pvmfinitsend (PVM_DATAMETHOD,bufid)
         call nest_errchk ('NEST_SPAWN','InitSend',bufid,1,1,1)
         call pvmfpack (INTEGER4,lenstr,1,1,status)
         call nest_errchk ('NEST_SPAWN','Pack',status,1,1,1)
         call pvmfsend (smltid(n),lnifil,status)
         call nest_errchk ('NEST_SPAWN','Send',status,1,1,1)
#endif
c
#ifdef use_mpi
         call MPI_SEND (smlinm(n)(sbgn:send),lenstr,MPI_CHARACTER,
     &                  smltid(n),ifilnm,comm_nest,status)
#else
         call pvmfinitsend (PVM_DATAMETHOD,bufid)
         call nest_errchk ('NEST_SPAWN','InitSend',bufid,1,1,1)
         call pvmfpack (STRING,smlinm(n)(sbgn:sbgn),lenstr,1,status)
         call nest_errchk ('NEST_SPAWN','Pack',status,1,1,1)
         call pvmfsend (smltid(n),ifilnm,status)
         call nest_errchk ('NEST_SPAWN','Send',status,1,1,1)
#endif
c
c  Send output file name & its length to smaller domain.
c
         call length (smlonm(n),lenstr,sbgn,send)
#ifdef use_mpi
         call MPI_SEND (lenstr,1,MPI_INTEGER4,smltid(n),lnofil,
     &                  comm_nest, status)
#else
         call pvmfinitsend (PVM_DATAMETHOD,bufid)
         call nest_errchk ('NEST_SPAWN','InitSend',bufid,1,1,1)
         call pvmfpack (INTEGER4,lenstr,1,1,status)
         call nest_errchk ('NEST_SPAWN','Pack',status,1,1,1)
         call pvmfsend (smltid(n),lnofil,status)
         call nest_errchk ('NEST_SPAWN','Send',status,1,1,1)
#endif
c
#ifdef use_mpi
         call MPI_SEND (smlonm(n)(sbgn:send),lenstr,MPI_CHARACTER,
     &                  smltid(n),ofilnm,comm_nest,status)
#else
         call pvmfinitsend (PVM_DATAMETHOD,bufid)
         call nest_errchk ('NEST_SPAWN','InitSend',bufid,1,1,1)
         call pvmfpack (STRING,smlonm(n)(sbgn:sbgn),lenstr,1,status)
         call nest_errchk ('NEST_SPAWN','Pack',status,1,1,1)
         call pvmfsend (smltid(n),ofilnm,status)
         call nest_errchk ('NEST_SPAWN','Send',status,1,1,1)
#endif
c
  10  continue
c
#if defined use_mpi & !defined nest2larger
c-----------------------------------------------------------------------
c  MPI master program needs to manually define parent/child relations.
c-----------------------------------------------------------------------
c
      do 20 while (no_par_assgn.lt.tot_proc_nest)
         call MPI_RECV (lenstr,1,MPI_INTEGER4,MPI_ANY_SOURCE,lnchlnam,
     &                  comm_nest,recvstat,status)
         wkid = recvstat(MPI_SOURCE)
         wkname = ' '
         call MPI_RECV (wkname,lenstr,MPI_CHARACTER,wkid,chlname,
     &                  comm_nest,recvstat,status)
c
         call length (wkname,lenstr,sbgn,send)
         call getchildid (wkname(sbgn:send),wkid,wkchlid)
c
         call MPI_SEND (wkchlid, 1, MPI_INTEGER4, wkid, chldid,
     &                  comm_nest, status)
         call MPI_SEND (wkid, 1, MPI_INTEGER4, wkchlid, nstparid,
     &                  comm_nest, status)
  20  continue
c
#endif
      return
c
 900  format (/'***Error:  NEST_SPAWN - unable to properly exchange ',
     &        'test values with smaller domain.'/11x,'test value:  ',i10
     &        /11x,'received value:  ',i10)
c
      end
