c
c=======================================================================
c  Include file "param.h" for PEMODEL.
c=======================================================================
#ifndef rmdocinc
c
c  IMT     Number of tracer points in the x-direction.
c  JMT     Number of tracer points in the y-direction.
c  IJMX    Either IMT or JMT, whichever is greater.
c  KM      Number of vertical levels.
c  LBC     Number of arrays of slab incidental data (usually, LBC=2).
c  LSEG    Maximum number of sets of Start and End indices per row or
c          per column (number of coastal segments plus one).
# ifdef bioDuse
c  LM      Number of intervals in light spectra (for PAR).
# endif
c  MISLE   Maximum number of islands in the model basin.
c  MPROF   Maximum number of points in mean TS profile.
c  MXNRMBD Maximum number of normal rows for BC data (>=3, generally 3,
c          wider for sponging in nested subdomains)
c  NT      Number of tracer type variables (generally, NT=2 for T & S).
# ifdef coast
c  MCLEN   Maximum number of points in a coastal segment.
c  MCSEG   Maximum number of coastal segments.
# endif
# ifdef ext_tide
c  MAXCOMP Maximum number of tidal components.
# endif
c  MAXEXT  Maximum length for exterior boundary.
# if defined posmxtid & ( !defined mixtide | !defined ext_tide )
c  TDBOXMX maximum number of tidally active boxes.
# endif
# ifdef extraction
c  MSUBDOM maximum number of subdomains to extract.
c  XIMT    maximum number of tracer points in the x-direction to
c          extract.
c  XKM     maximum number of vertical levels to extract.
# endif
# ifdef peprf
c  MHDR    Maximum number of lines of text in the file header.
c  MHFLDS  Maximum number of field types supported.
c  MHPTS   Maximum number of data points per station.
c  MHVAR   Maximum number of variables per station.  (MHVAR<=MHFLDS)
c  MNBPRF  Maximum number of profile per instrument.
# endif
# if defined pttrcsrc & defined rivsrc
c  MXSRC    maximum number of tracer sources allowed.
# endif
# if defined nest2larger | defined nest2smaller
c  MXSUBD  maximum number of nested sub-domains
c  XMDAT   maximum number of points in arrays for passing to external
c          models.  A loose upper bound is given by max(nx*ny*nz)
# endif
# if defined surfpress | defined pcg5
c  NMAX    SPARSKIT workspace ~IM*JM (number of rows in Ellip. Matrix)
c  NZMAX   SPARSKIT workspace. ~nmax*2*(fillin+1)
c  LWK     SPARSKIT workspace.
c  ISESIZE  >= LSEG*JMT 
# endif
c
c=======================================================================
#endif
c
      integer ijmx,imt,imtjmt,imtkm,imtm1,imtm2,imtp1,imu,imum1,imum2,
     &        jmt,jmtm1,jmtm2,jmtp1,jscan,km,kmm1,kmp1,kmp2,lbc,lseg,
     &        maxext,misle,mprof,mxnrmbd,ndices,nkflds,nslab,nswich,nt,
     &        ntmin2,nwds
#ifdef coast
      integer mcseg,mclen
#endif
#ifdef ext_tide
      integer maxcomp
#endif
#if (defined posmxtid & ( !defined mixtide | !defined ext_tide )) | defined cdbotbox
      integer tdboxmx
#endif
#ifdef extraction
      integer msubdom,ximt,ximtkm,xkm
#endif
#ifdef peprf
      integer mhdr,mhflds,mhpts,mhvar,mnbprf
#endif
#if defined pttrcsrc & defined rivsrc
      integer mxsrc
#endif
#if defined nest2larger | defined nest2smaller
      integer mdomp1,mxsubd,xmdat
# if defined use_mpi & !defined nest2larger
     &        ,max_proc_nest
# endif
#endif
#ifdef bioDuse
       integer lm
#endif
c
#ifndef rmdocinc
c-----------------------------------------------------------------------
c  User set parameters.
c-----------------------------------------------------------------------
c
#endif
      parameter(imt=185,jmt=168,ijmx=185,km=70,lseg=11,misle=29,lbc=2,
     &          mxnrmbd=3)
#if defined codunlim | defined codlim
# define CodAdd 1
#else
# define CodAdd 0
#endif
#if defined bioAnder
      parameter(nt=7+CodAdd)
#elif defined bioFasham
      parameter(nt=9+CodAdd)
#elif defined bioMcGillic
      parameter(nt=6+CodAdd)
#elif defined bioDuse
       parameter(nt=9+CodAdd,lm=61)
#else
      parameter(nt=2)
#endif
      parameter(mprof=1000)
#ifdef coast
      parameter(mcseg=31,mclen=411)
#endif
#ifdef ext_tide
      parameter(maxcomp=8)
#endif
#if (defined posmxtid & ( !defined mixtide | !defined ext_tide )) | defined cdbotbox
      parameter (tdboxmx=100)
#endif
#ifdef extraction
      parameter(msubdom=2,ximt=53,xkm=16)
#endif
#ifdef peprf
      parameter (mhdr=20,mhflds=10,mhvar=4,mnbprf=52000)
#endif
#if defined pttrcsrc & defined rivsrc
      parameter (mxsrc=200)
#endif
#if defined nest2larger | defined nest2smaller
      parameter(xmdat=3477*km, mxsubd=10)
# if defined use_mpi & !defined nest2larger
      parameter(max_proc_nest=100)
# endif
#endif
#if defined surfpress | defined pcg5
      integer fillmx
      parameter (fillmx=50)
#endif
c
#ifndef rmdocinc
c-----------------------------------------------------------------------
c  End of user set parameters.
c-----------------------------------------------------------------------
c
#endif
      parameter(imtjmt=imt*jmt
#ifdef cyclic
     &    ,imu=imt
#else
     &    ,imu=imt-1
#endif
     &    ,imtp1=imt+1,imtm1=imt-1,imtm2=imt-2,imum1=imu-1,imum2=imu-2
     &    ,jmtp1=jmt+1,jmtm1=jmt-1,jmtm2=jmt-2
     &    ,jscan=jmtm2
     &    ,kmp1=km+1,kmp2=km+2,kmm1=km-1
     &    ,nslab=imt*((nt+2)*km+lbc),nwds=imt*jmt,nswich=lbc*imt
     &    ,ndices=2*lseg*jmt+4*misle
     &    ,imtkm=imt*km,ntmin2=nt+1/nt,nkflds=7+(ndices/nwds))
#ifdef extraction
      parameter(ximtkm=ximt*xkm)
#endif
#if defined coast & !defined surfpress
      parameter (maxext=mcseg*mclen+2*imt+2*jmt)
#else
      parameter (maxext=2*imt+2*jmt)
#endif
#if defined nest2larger | defined nest2smaller
      parameter (mdomp1=mxsubd+1)
#endif
#ifdef peprf
      parameter (mhpts=kmp1)
#endif
#if defined surfpress | defined pcg5
      integer isesize
      parameter (isesize=ijmx*lseg)
      integer nmax, nzmax,lwk
      parameter (nmax=imt*jmt,nzmax=nmax*2*(fillmx+1),lwk=nmax*40)
#endif
