       subroutine Pressure
c
c=======================================================================
c                                                                    ===
#if !defined freesurf
c  Rigid Lid Pressure Formulation                                    ===
#else
c  Free Surface  Pressure Formulation                                ===  
#endif
#ifdef solvercg
c Elliptic Solver : CG.                                              ===
#else
c Elliptic Solver : CG with Right preconditioner.                    ===
#endif
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fullwd.h>
#include <scalar.h>
#include <onedim.h>
#include <fields.h>
#include <workspb.h>
#include <bndata.h>
#include <moddat.h>
#include <filtdat.h>
#include <iounits.h>
#include <vertslabs.h>
#include <sinfo.h>
#include <convinfo.h>
#if defined tidepredctr
# include <tidesp.h>
#endif
#if defined limpstshap & defined shapetalag
# include <vertical.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer i,j,luptd,luptdb
#ifdef shapiro
     &        ,nn
#endif
#if defined coast & defined dumpmask
      integer prsmsk(imt,jmt)
#endif
#if defined dumppsrst
      integer dmptim
      parameter (dmptim=3)
      character*4 ittstr
#endif
      FLOAT 
     &     fxa,fxb
#ifdef freesurf
     &     ,diagcof
#endif
      FLOAT
     &     a(imt,jmt,0:8),hvex(imt,jmt),vmtxoy(imt,jmt),vmtyox(imt,jmt)
#if !defined smallpsdt
     &     ,ptdb(imt,jmt)
#endif
#ifdef freesurf
     &     ,tmetxy(imt,jmt)
#endif
#if defined localfilter
     &     ,xtest(imt*jmt)
#endif
#ifdef avgptd
     &     ,dum(imt,jmt)
#endif
#ifdef sprsnrm01
     &     ,hvey(imt,jmt)
#endif
#if defined shapiro & defined shaprstdps & !defined shapdpsdir
     &     ,psave(imt,jmt)
#endif
c
#ifndef solvercg
      integer ir(imt*jmt),ia(imt*jmt+1),ja(9*imt*jmt)
      FLOAT
     &     amt(9*imt*jmt),rp(imt*jmt),pspar(imt*jmt)
#else
      double precision wk(imt*jmt,4)
#endif
      logical first
c
      save first,vmtxoy,vmtyox
#ifdef freesurf
     &     ,tmetxy
#endif
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c=======================================================================
c  Begin introductory section to prepare the iterations      ===========
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save unchanging combinations of metric factors
c-----------------------------------------------------------------------
c
      if (first) then
         first = .false.
         do 10 j = 1, jmt
         do 10 i = 1, imt
#ifdef freesurf
            tmetxy(i,j) = cst(j)
#endif
            vmtxoy(i,j) = cs(j)
            vmtyox(i,j) = csr(j)
  10     continue
      endif
c
#if !defined smallpsdt
c-----------------------------------------------------------------------
c  Initiate reading of relaxation solution of 2 timesteps back
c  for the purpose of computing an initial guess for the present pass
c  (input unit alternates on timesteps between 5 & 6)
c-----------------------------------------------------------------------
c
      luptdb=6-mod(itt,2)
      luptd =5+mod(itt,2)
      call ofind(kflds,nwds,(luptdb-1)*nwds+1)
c
c-----------------------------------------------------------------------
c  Complete reading of relaxation solution of 2 timesteps back and
c  initiate reading of relaxation solution of previous timestep
c  (input unit alternates on timesteps between 6 & 5)
c-----------------------------------------------------------------------
c
      call oget(kflds,nwds,(luptdb-1)*nwds+1,ptdb)
      call ofind(kflds,nwds,(luptd-1)*nwds+1)
c
#endif
c-----------------------------------------------------------------------
c  Save rate change of barotropic divergence in array ZTDB for output
c  purposes.
c-----------------------------------------------------------------------
c
      do 40 j=1,jmt
      do 40 i=1,imt
        ztdb(i,j)=ztd(i,j)
  40  continue
c
c-----------------------------------------------------------------------
c  Compute a first guess for the relaxation by extrapolating the two
c  previous solutions forward in time.
c-----------------------------------------------------------------------
c
#if !defined smallpsdt
c  1st, complete reading of previous timestep solution.
c
      call oget(kflds,nwds,(luptd-1)*nwds+1,ptd)
c
#endif
c  2nd, perform time extrapolation (accounting for mixing timestep).
c
      fxa=c1
      fxb=c2
      if(mixts.or.mxpas2) fxa=p5
      do 110 j=1,jmt
      do 110 i=1,imt
#if defined smallpsdt
        ptdb(i,j) =ptdbsv(i,j)
#endif
        ptd(i,j)  =fxa*(fxb*ptd(i,j)-ptdb(i,j))
#if defined smallpsdt
        ptdbsv(i,j) =ptd(i,j)
#endif
 110  continue
#if defined shapiro & defined shapetalag & defined shapetalag2
c-----------------------------------------------------------------------
c  Filter/smooth surface pressure field
c-----------------------------------------------------------------------
c
c  If requested, apply Shapiro filter:
c
c       ICNTP = counter (for frequency of application)
c       NFRQP = frequency with which filter is applied
c       NTIMP = number of times filter is applied per time step
c       NORDP = order of the filter
c
      icntpb=icntpb+1
      if(icntp.eq.nfrqp)then
        icntpb=0
        if(nordp.gt.0)then
# ifndef filtetat
#  if defined etalimshap
c          call shap_elim (0)
          call shap_pslim (0)
#  endif
          do 113 nn=1,ntimp
            call shap_lev(pb,imt,jmt,pgrid,nordp)
 113      continue
#  if defined etalimshap
c          call shap_elim (1)
          call shap_pslim (1)
#  endif
c
#  ifndef cyclic 
#   ifdef coast
          pb(1,1)=p5*pb(1,2)+p5*pb(2,1)
          pb(imt,1)=p5*pb(imt-1,1)+p5*pb(imt,2)
          pb(1,jmt)=p5*pb(1,jmt-1)+p5*pb(2,jmt)
          pb(imt,jmt)=p5*pb(imt,jmt-1)+p5*pb(imt-1,jmt)
#   endif
#  else
c
c  Set Cyclic boundary conditions.
c
      do 117 j=1,jmt
        pb(1  ,j)=pb(imtm1,j)
        pb(imt,j)=pb(2    ,j)
 117  continue

#  endif
# endif
        endif
      endif
c
#endif
c-----------------------------------------------------------------------
c  Get Dirichlet boundary conditions at North, South, East, West 
c  boundaries or cyclic boundary conditions in the East-West direction.
c-----------------------------------------------------------------------
c
#ifndef cyclic
c  Filter boundary conditions at the pressure stage.
c  Probably incompatible with Cyclic conditions.
c
      call putpbry (ptd)
      call fltpbn (ptd)
      call poppbry (ptd)
c
#endif
c  Update the time change of stream function at the southern and
c  northern boundaries.
c
      do 120 i=2,imtm1
#if !defined tidepredctr
        ptd(i,1)=po(i,1,south)-pb(i,1)
        ptd(i,jmt)=po(i,1,north)-pb(i,jmt)
#else
        ptd(i,1)=po(i,1,south)-srftd(i,1,itda)*grav
        ptd(i,jmt)=po(i,1,north)-srftd(i,jmt,itda)*grav
#endif
 120  continue
c
#ifdef cyclic
c  Set Cyclic boundary conditions.
c
      do 130 j=1,jmt
        ptd(1  ,j)=ptd(imtm1,j)
        ptd(imt,j)=ptd(2    ,j)
 130  continue
c
#else
c  Update the time change of stream function at the western and
c  eastern boundaries.
c
      do 140 j=1,jmt
#if !defined tidepredctr
        ptd(1,j)=po(j,1,west)-pb(1,j)
        ptd(imt,j)=po(j,1,east)-pb(imt,j)
#else
        ptd(1,j)=po(j,1,west)-srftd(1,j,itda)*grav
        ptd(imt,j)=po(j,1,east)-srftd(imt,j,itda)*grav
#endif
 140  continue
c
c  Filter boundary conditions at the pressure tendency stage.
c  Probably incompatible with Cyclic conditions.
c
      call fltpbn (ptd)
c
#endif
c-----------------------------------------------------------------------
c  Get the weighted depth : Rigid-Lid or Free surface 
c  computation.
c-----------------------------------------------------------------------
c
      do 146 i=1,imt
        do  148 j=1,jmt
#ifndef freesurf
          hvex(i,j)=hdvc(i,j)
#elif !defined  sprsnrm01
          hvex(i,j)=hdvcf(i,j)
#elif !defined  sprsnrm04
          hvex(i,j)=hdvcfx(i,j)
          hvey(i,j)=hdvcfy(i,j)
#else 
          hvex(i,j)=hdvcfx(i,j)*ugdwt(i,j)
          hvey(i,j)=hdvcfy(i,j)*vgdwt(i,j)
#endif
148     continue
146   continue
c
#ifdef freesurf
      diagcof=c2/(alphav*thetasd*grav*c2dtps*c2dtps)
# ifdef dumptst
        write (stdout,*) '--- in pressure, c2dtps=',c2dtps
        write (stdout,*) '--- in pressure, thetasd=',thetasd
        write (stdout,*) '--- in pressure, alphav=',alphav
        write (stdout,*) '--- in pressure, grav=',grav
        write (stdout,*) '--- in pressure, c2=',c2
        write (stdout,*) '--- in pressure, diagcof=',diagcof
# endif
# ifdef check_dt
      print *,'***PRESSURE: mixts=',mixts,'  mxpas2=',mxpas2
      print *,'             fxa=',fxa,'  diagcof=',diagcof
      print *,'             c2dtps=',c2dtps
# endif
c
#endif
c-----------------------------------------------------------------------
c  Call elliptic solver
c-----------------------------------------------------------------------
c
      call Press_solve (imt,jmt,dxt2r,dxu2r,dyt2r,dyu2r,hvex,vmtxoy,
     &                  vmtyox,a,ptd,ztd,
#ifdef coast
     &                  lseg,isq,ieq,isp,iep,
# ifdef dumpmask
     &                  prsmsk,
# endif
#endif
#ifdef sprsnrm01
     &                 hvey,landt,
#endif
#ifdef freesurf
     &                  diagcof,tmetxy,
#endif
#ifndef solvercg
     &                  ir,ia,ja,amt,rp,pspar
#else
     &                  wk,imt*jmt
#endif
#if defined localfilter
     &                  ,xtest
#endif
#if defined lapfilter & defined killwlap
     &                  ,c2dtps,landt
#endif
     &                  )
c
c  Report convergence information.
c
      if (mod(itt,ntsi).eq.0)
     &   write(stdout,900) resini,residu,restarget,mican
c
#ifdef avgptd
c-------------------------------------------------------------------
c  Average ptd to velocity grid then back.
c-------------------------------------------------------------------
c
c  Average to velocity grid.
c
      do 310, j=1, jmtm1
         do 300, i=1, imtm1
            dum(i,j) = p25*(ptd(i,j)+ptd(i+1,j)+ptd(i,j+1)+ptd(i+1,j+1))
 300     continue
# ifdef cyclic
         dum(1  ,j) = dum(imtm1,j)
         dum(imt,j) = dum(2    ,j)
# else
         dum(imt,j) = p5*(ptd(imt,j)+ptd(imt,j+1))
# endif
 310  continue
      do 320, i=1, imtm1
         dum(i,jmt) = p5*(ptd(i,jmt)+ptd(i+1,jmt))
 320  continue
# ifdef cyclic
      dum(1  ,jmt) = dum(imtm1,jmt)
      dum(imt,jmt) = dum(2    ,jmt)
# else
      dum(imt,jmt) = p5*(dum(imtm1,jmt)+dum(imt,jmtm1))
# endif
c
c  Average to tracer grid.
c
      do 340, j=2, jmt
         do 330, i=2, imt
            ptd(i,j) = p25*(dum(i,j)+dum(i-1,j)+dum(i,j-1)+dum(i-1,j-1))
 330     continue
# ifdef cyclic
         ptd(1  ,j) = ptd(imtm1,j)
         ptd(imt,j) = ptd(2    ,j)
# else
         ptd(1  ,j) = p5*(dum(1,j)+dum(1,j-1))
# endif
 340  continue
      do 350, i=2, imt
         ptd(i,1) = p5*(dum(i,1)+dum(i-1,1))
 350  continue
# ifdef cyclic
      ptd(1  ,1) = ptd(imtm1,1)
      ptd(imt,1) = ptd(2    ,1)
# else
      ptd(1,1) = p5*(ptd(2,1)+ptd(1,2))
# endif
#endif
#if defined shapiro & defined shapetalag & !defined shapetalag2
c-----------------------------------------------------------------------
c  Filter/smooth surface pressure field
c-----------------------------------------------------------------------
c
c  If requested, apply Shapiro filter:
c
c       ICNTP = counter (for frequency of application)
c       NFRQP = frequency with which filter is applied
c       NTIMP = number of times filter is applied per time step
c       NORDP = order of the filter
c
      icntpb=icntpb+1
      if(icntpb.eq.nfrqp)then
        icntpb=0
        if(nordp.gt.0)then
# ifndef filtetat
#  if defined etalimshap
c          call shap_elim (0)
          call shap_pslim (0)
#  endif
          do 600 nn=1,ntimp
            call shap_lev(pb,imt,jmt,pgrid,nordp)
 600      continue
#  if defined etalimshap
c          call shap_elim (1)
          call shap_pslim (1)
#  endif
c
#  ifndef cyclic 
#   ifdef coast
          pb(1,1)=p5*pb(1,2)+p5*pb(2,1)
          pb(imt,1)=p5*pb(imt-1,1)+p5*pb(imt,2)
          pb(1,jmt)=p5*pb(1,jmt-1)+p5*pb(2,jmt)
          pb(imt,jmt)=p5*pb(imt,jmt-1)+p5*pb(imt-1,jmt)
#   endif
#  else
c
c  Set Cyclic boundary conditions.
c
      do 610 j=1,jmt
        pb(1  ,j)=pb(imtm1,j)
        pb(imt,j)=pb(2    ,j)
 610  continue

#  endif
# endif
        endif
      endif
c
#elif defined shapiro & defined shapdpsdir
c-----------------------------------------------------------------------
c  Filter/smooth surface pressure field
c-----------------------------------------------------------------------
c
c  If requested, apply Shapiro filter:
c
c       ICNTP = counter (for frequency of application)
c       NFRQP = frequency with which filter is applied
c       NTIMP = number of times filter is applied per time step
c       NORDP = order of the filter
c
      icntp=icntp+1
      if(icntp.eq.nfrqp)then
        icntp=0
        if(nordp.gt.0)then
#if defined dumppsrst
c           if (itt.eq.dmptim) then
         write (ittstr,'(i4.4)') itt
           open (413, file='ptdunflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) ptd(i,j)
                 enddo
              enddo
              close(413)
c           endif
#endif
          do 600 nn=1,ntimp
            call shap_lev(ptd,imt,jmt,pgrid,nordp)
 600      continue
#if defined dumppsrst
c           if (itt.eq.dmptim) then
             open (413, file='ptdflt'//ittstr//'.dat', status='unknown')
              do j = 1, jmt
                 do i = 1, imt
                    write (413,*) ptd(i,j)
                 enddo
              enddo
              close(413)
c           endif
#endif
c
# ifdef cyclic 
c
c  Set Cyclic boundary conditions.
c
      do 610 j=1,jmt
        ptd(1  ,j)=ptd(imtm1,j)
        ptd(imt,j)=ptd(2    ,j)
 610  continue

# endif
        endif
      endif
c
#endif
#if !defined freesurf | !defined rset_dps
c-------------------------------------------------------------------
c  Update the surface pressure.
c-------------------------------------------------------------------
c
      if(.not.mxpas2) then
        do 620 j=1,jmt
        do 620 i=1,imt
# ifdef psnull
          ptd(i,j)=c0
# endif
#if (defined scaltsunflt | defined scaluvunflt) & defined smldtscl
          ptdb(i,j)=pbunflt(i,j)+ptd(i,j)
          pbunflt(i,j)=punflt(i,j)
          punflt(i,j)=ptdb(i,j)
# endif
# if !defined tidepredctr
          ptdb(i,j)=pb(i,j)+ptd(i,j)
# else
          ptdb(i,j)=srftd(i,j,itda)*grav+ptd(i,j)
# endif
# if defined limpstshap & defined shapetalag
          etatbb(i,j)=pb(i,j)/grav
# endif
# if defined shapiro & defined shaprstdps & !defined shapdpsdir
          psave(i,j)=pb(i,j)
# endif
          pb(i,j)=p(i,j)
          p(i,j)=ptdb(i,j)
#if (defined nest2smaller | defined scaltsunflt | defined scaluvunflt) & !defined smldtscl
          punflt(i,j)=p(i,j)
# endif
 620    continue
      else
        do 630 j=1,jmt
        do 630 i=1,imt
# ifdef psnull
          ptd(i,j)=c0
# endif
# if defined shapiro & defined shaprstdps & !defined shapdpsdir
          psave(i,j)=pb(i,j)
# endif
# if !defined tidepredctr
          p(i,j)=pb(i,j)+ptd(i,j)
# else
          p(i,j)=srftd(i,j,itda)*grav+ptd(i,j)
# endif
#if defined nest2smaller | defined scaltsunflt | defined scaluvunflt
# if !defined smallpsdt & !defined smldtscl
          punflt(i,j)=p(i,j)
# elif !defined smldtscl
          punflt(i,j)=punflt(i,j)+ptd(i,j)
# else
          punflt(i,j)=pbunflt(i,j)+ptd(i,j)
# endif
#endif
 630    continue
      endif
c
# if defined shapiro & !defined shapetalag & !defined rset_dps
c-----------------------------------------------------------------------
c  Filter/smooth surface pressure field
c-----------------------------------------------------------------------
c
c  If requested, apply Shapiro filter:
c
c       ICNTP = counter (for frequency of application)
c       NFRQP = frequency with which filter is applied
c       NTIMP = number of times filter is applied per time step
c       NORDP = order of the filter
c
      icntp=icntp+1
      if(icntp.eq.nfrqp)then
        icntp=0
        if(nordp.gt.0)then
#  ifdef nest2smaller
          do 635 j=1,jmt
          do 635 i=1,imt
            punflt(i,j)=p(i,j)
 635      continue
#  endif
#  ifndef filtetat
#   if defined etalimshap
c          call shap_elim (0)
          call shap_pslim (0)
#   endif
          do 640 nn=1,ntimp
            call shap_lev(p,imt,jmt,pgrid,nordp)
 640      continue
#   if defined etalimshap
c          call shap_elim (1)
          call shap_pslim (1)
#   endif
c
#   ifndef cyclic 
#    ifdef coast
          p(1,1)=p5*p(1,2)+p5*p(2,1)
          p(imt,1)=p5*p(imt-1,1)+p5*p(imt,2)
          p(1,jmt)=p5*p(1,jmt-1)+p5*p(2,jmt)
          p(imt,jmt)=p5*p(imt,jmt-1)+p5*p(imt-1,jmt)
#    endif
#   else
c
c  Set Cyclic boundary conditions.
c
      do 645 j=1,jmt
        p(1  ,j)=p(imtm1,j)
        p(imt,j)=p(2    ,j)
 645  continue

#   endif
          do 650 j=1,jmt
          do 650 i=1,imt
            ptdb(i,j)=p(i,j)
 650      continue
#  endif
        endif
      endif
c
# endif
# if defined shapiro & defined shaprstdps & !defined shapdpsdir
       do 655 j=1,jmt
       do 655 i=1,imt
          ptd(i,j)=p(i,j)-psave(i,j)
 655   continue
# endif
c-----------------------------------------------------------------------
c  Save PTD to compute 1st guess for  next timestep
c  (..note.. on 1st pass of Euler backward timestep, bypass this
c            save, since it will be done on the 2nd pass)
c  (..note.. on a mixing timestep, alter ptd to be consistent with
c            normal, leap-frog stepping)
c-----------------------------------------------------------------------
c
# ifndef try2dtpsic
      c2dtps = c2dtsf
      if((mix.eq.1).and.eb) return
      if((mxp.ne.0).or.(mix.ne.0)) then
        c2dtps = c2*c2dtps
        do 660 j=1,jmt
        do 660 i=1,imt
          ptd(i,j)=c2*ptd(i,j)
 660    continue
      endif
# else
      c2dtps = c2*dtsf
# endif
# if !defined smallpsdt
      call oput(kflds,nwds,(luptdb-1)*nwds+1,ptd)
# endif
#endif
c
 900  format (
#ifndef solvercg
     *        ' PCG res.:',
#else
     *        ' CG res.:',
#endif
     *        ' Initial ',1pe10.3,
     *        ' Final ',1pe10.3,
     *        ' Target ',1pe10.3,
     *        ' MICAN ', i4  )
c
      return
      end
