      subroutine randomize (seed)

C-------------------------------------------------------------------------------
C     This subroutine returns a large integer seed value to be used in the     |
C     FORTRAN random number generator.  This seed is chosen by interpreting the|
C     day, date and time information as six integers to be added.  A seventh   |
C     integer, the decimal portion of the elapsed program execution time scaled|
C     by a suitably large factor, is added to the previous result.             |
C                                                                              |
C     Calls:  etime, fdate                                                     |
C                                                                              |
C     Arguments:                                                               |
C                                                                              |
C     seed...Integer.  Variable initial value to be used with the FORTRAN      |
C               random number generator.   {output}                            |
C-------------------------------------------------------------------------------

      implicit none

      real    elapse,etime,tra(2),p5,c1000,p1
      integer      seed,part,i,fac,sum
      character*24 string,fdate

      parameter (fac =  306 783, p5 = 0.5, c1000 = 1000.0, p1 = 0.1)

C=======================================================================
C     Begin executable code.                                           #
C=======================================================================

C-----------------------------------------------------------------------
C     Get the today's date and the current time.  Initialize sum.      |
C-----------------------------------------------------------------------

      string = fdate()
      sum = 0

C-----------------------------------------------------------------------
C     Take the time and date string apart 4 characters at a time.      |
C     Interpret the resulting binary string as an integer and          |
C     accumulate the result.                                           |
C-----------------------------------------------------------------------

      do 10 i = 1, 24, 4
         read(string(i:i+3),20) part
         sum = sum + abs(part/7)
 10   continue

C-----------------------------------------------------------------------
C     Get the elapsed time since the beginning of the program execution|
C     and extract the tenths and hundredths of seconds digits.         |
C-----------------------------------------------------------------------

      elapse = etime(tra)
      part = int (c1000*(p1*elapse - int(p1*elapse)) + p5)

C-----------------------------------------------------------------------
C     Multiply the result by a suitably large number and add to sum to |
C     form seed.                                                       |
C-----------------------------------------------------------------------

      seed = sum + fac*part

C-----------------------------------------------------------------------
C     Make sure result is an odd integer.                              |
C-----------------------------------------------------------------------

      if ( mod(seed,2) .eq. 0 )  seed = seed - 1

      return

 20   format (a4)

      end
