      subroutine resetbc (itau)
c
c=======================================================================
c                                                                    ===
c  This routine resets the boundary data based on time averaging     ===
c  an exponentially decaying weight in the past.                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <bndata.h>
#include <bndyrlx.h>
#include <fields.h>
#include <fieldsbar.h>
#include <options.h>
#include <scalar.h>
#include <vertical.h>
#include <voldat.h>
#include <workspr.h>
#if defined ext_tide & !defined mixtideonly
# include <tidesp.h>
#endif
#if defined transbc | defined nest2larger
# include <vertslabs.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer imup1
      parameter (imup1=imu+1)
c
      integer i,ibn,ip,itau,j,k,m
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Average baroclinic velocity boundary data.
c-----------------------------------------------------------------------
c
      if (ibcavg(2)) then
c
c  East/West Boundaries.
c
         do 10, j=1,jmtm1
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
            do 10, ibn=1,3
            do 10, k=1,km
                ip=(j-1)*imt+ibn
                ubc0(j,k,ibn,itbp,west) = spngtp1w*(xu(ip,k)+au(ibn,k))+
     &                                    spngtwt*ubc0(j,k,ibn,itb,west)
                vbc0(j,k,ibn,itbp,west) = spngtp1w*(xv(ip,k)+av(ibn,k))+
     &                                    spngtwt*vbc0(j,k,ibn,itb,west)
                i = imup1 - ibn
                ip=(j-1)*imt+i
                ubc0(j,k,ibn,itbp,east) = spngtp1w*(xu(ip,k)+au(i,k))+
     &                                    spngtwt*ubc0(j,k,ibn,itb,east)
                vbc0(j,k,ibn,itbp,east) = spngtp1w*(xv(ip,k)+av(i,k))+
     &                                    spngtwt*vbc0(j,k,ibn,itb,east)
  10     continue
c
c  North/South Boundaries.
c
         do 20, ibn=1,3
            j = ibn
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
             do 15, k=1,km
             do 15, i=1,imu
                ip=(ibn-1)*imt+i
                ubc0(i,k,ibn,itbp,south) = spngtp1w*(xu(ip,k)+au(i,k))+
     &                                   spngtwt*ubc0(i,k,ibn,itb,south)
                vbc0(i,k,ibn,itbp,south) = spngtp1w*(xv(ip,k)+av(i,k))+
     &                                   spngtwt*vbc0(i,k,ibn,itb,south)
  15         continue
            j = jmt - ibn
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
             do 20, k=1,km
             do 20, i=1,imu
                ip=(j-1)*imt+i
                ubc0(i,k,ibn,itbp,north) = spngtp1w*(xu(ip,k)+au(i,k))+
     &                                   spngtwt*ubc0(i,k,ibn,itb,north)
                vbc0(i,k,ibn,itbp,north) = spngtp1w*(xv(ip,k)+av(i,k))+
     &                                   spngtwt*vbc0(i,k,ibn,itb,north)
  20     continue
      endif
c
c-----------------------------------------------------------------------
c  Average tracer boundary data.
c-----------------------------------------------------------------------
c
      if (ibcavg(1)) then
c
c  East/West Boundaries.
c
         do 30, j=1,jmtm1
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
         do 30, ibn=1,3
         do 30, m=1,nt
         do 30, k=1,km
            i = ibn
            ip=(j-1)*imt+i
            tbc0(j,k,m,ibn,itbp,west) = spngtp1w*(xt(ip,k,m)+at(i,k,m))+
     &                                  spngtwt*tbc0(j,k,m,ibn,itb,west)
                i = imtp1 - ibn
            ip=(j-1)*imt+i
            tbc0(j,k,m,ibn,itbp,east) = spngtp1w*(xt(ip,k,m)+at(i,k,m))+
     &                                  spngtwt*tbc0(j,k,m,ibn,itb,east)
  30     continue
c
c  North/South Boundaries.
c
         do 40, ibn=1,3
            j = ibn
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
         do 35, m=1,nt
         do 35, k=1,km
         do 35, i=1,imt
            ip=(j-1)*imt+i
            tbc0(i,k,m,ibn,itbp,south) =spngtp1w*(xt(ip,k,m)+at(i,k,m))+
     &                                 spngtwt*tbc0(i,k,m,ibn,itb,south)
  35     continue
            j = jmt - ibn
            call oget(itau  ,nslab,(j-1)*nslab+1,at)
         do 40, m=1,nt
         do 40, k=1,km
         do 40, i=1,imt
            ip=(j-1)*imt+i
            tbc0(i,k,m,ibn,itbp,north) =spngtp1w*(xt(ip,k,m)+at(i,k,m))+
     &                                 spngtwt*tbc0(i,k,m,ibn,itb,north)
  40     continue
      endif
c
#if defined freesurf
c-----------------------------------------------------------------------
c  Average (subtidal) V-point surface elevation data.
c-----------------------------------------------------------------------
c
      if (ibcavg(4)) then
c
c  East/West Boundaries.
c
         do 50, ibn=1,3
         do 50, j=1,jmtm1
            evbco(j,ibn,itbp,west) = spngtp1w*(etav(ibn,j)+etavb(ibn,j)
# if defined ext_tide & !defined mixtideonly
     &                            - p25*((srftd(ibn,j,itda)+
     &                                    srftd(ibn,j+1,itda)+
     &                                    srftd(ibn+1,j,itda)+
     &                                    srftd(ibn+1,j+1,itda))
     &                                 + (srftd(ibn,j,itd)+
     &                                    srftd(ibn,j+1,itd)+
     &                                    srftd(ibn+1,j,itd)+
     &                                    srftd(ibn+1,j+1,itd)))
# endif
     &                               )  + spngtwt*evbco(j,ibn,itb,west)
            i = imup1 - ibn
            evbco(j,ibn,itbp,east) = spngtp1w*(etav(i,j)+etavb(i,j)
# if defined ext_tide & !defined mixtideonly
     &                            - p25*((srftd(i,j,itda)+
     &                                    srftd(i,j+1,itda)+
     &                                    srftd(i+1,j,itda)+
     &                                    srftd(i+1,j+1,itda))
     &                                 + (srftd(i,j,itd)+
     &                                    srftd(i,j+1,itd)+
     &                                    srftd(i+1,j,itd)+
     &                                    srftd(i+1,j+1,itd)))
# endif
     &                                ) + spngtwt*evbco(j,ibn,itb,east)
  50     continue
c
c  North/South Boundaries.
c
         do 60, ibn=1,3
         do 60, i=1,imu
            evbco(i,ibn,itbp,south) = spngtp1w*(etav(i,ibn)+etavb(ibn,j)
# if defined ext_tide & !defined mixtideonly
     &                            - p25*((srftd(i,ibn,itda)+
     &                                    srftd(i,ibn+1,itda)+
     &                                    srftd(i+1,ibn,itda)+
     &                                    srftd(i+1,ibn+1,itda))
     &                                 + (srftd(i,ibn,itd)+
     &                                    srftd(i,ibn+1,itd)+
     &                                    srftd(i+1,ibn,itd)+
     &                                    srftd(i+1,ibn+1,itd)))
# endif
     &                                ) + spngtwt*evbco(i,ibn,itb,south)
            j = jmt - ibn
            evbco(i,ibn,itbp,north) = spngtp1w*(etav(i,j)+etavb(i,j)
# if defined ext_tide & !defined mixtideonly
     &                            - p25*((srftd(i,j,itda)+
     &                                    srftd(i,j+1,itda)+
     &                                    srftd(i+1,j,itda)+
     &                                    srftd(i+1,j+1,itda))
     &                                 + (srftd(i,j,itd)+
     &                                    srftd(i,j+1,itd)+
     &                                    srftd(i+1,j,itd)+
     &                                    srftd(i+1,j+1,itd)))
# endif
     &                                ) + spngtwt*evbco(i,ibn,itb,north)
  60     continue
      endif
c
#endif
#if defined surfpress
c-----------------------------------------------------------------------
# if defined transbc | defined nest2larger
c  Average (subtidal) transport data.
# else
c  Average (subtidal) barotropic velocity data.
# endif
c-----------------------------------------------------------------------
c
      if (ibcavg(4)) then
c
c  East/West Boundaries.
c
         do 70, ibn=1,3
         do 70, j=1,jmtm1
# if defined transbc | defined nest2larger
c Update boundary transports.
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            utrano(j,ibn,itbp,west) = (ubaronew(ibn,j)*hdvcf(ibn,j)+
     &                                 ubaro(ibn,j)*hdvbf(ibn,j)
#  else
            utrano(j,ibn,itbp,west) = (ubaronew(ibn,j)*hdvcfx(ibn,j)+
     &                                 ubaro(ibn,j)*hdvbfx(ibn,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                             - (ubartd(ibn,j,itda)*hdv(ibn,j)
     &                              + ubartd(ibn,j,itd)*hdv(ibn,j))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*utrano(j,ibn,itb,west)
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            vtrano(j,ibn,itbp,west) = (vbaronew(ibn,j)*hdvcf(ibn,j)+
     &                                 vbaro(ibn,j)*hdvbf(ibn,j)
#  else
            vtrano(j,ibn,itbp,west) = (vbaronew(ibn,j)*hdvcfy(ibn,j)+
     &                                 vbaro(ibn,j)*hdvbfy(ibn,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                             - (vbartd(ibn,j,itda)*hdv(ibn,j)
     &                              + vbartd(ibn,j,itd)*hdv(ibn,j))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*vtrano(j,ibn,itb,west)
            i = imup1 - ibn
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            utrano(j,ibn,itbp,east) = (ubaronew(i,j)*hdvcf(i,j)+
     &                                 ubaro(i,j)*hdvbf(i,j)
#  else
            utrano(j,ibn,itbp,east) = (ubaronew(i,j)*hdvcfx(i,j)+
     &                                 ubaro(i,j)*hdvbfx(i,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                             - (ubartd(i,j,itda)*hdv(i,j)
     &                              + ubartd(i,j,itd)*hdv(i,j))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*utrano(j,ibn,itb,east)
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            vtrano(j,ibn,itbp,east) = (vbaronew(i,j)*hdvcf(i,j)+
     &                                 vbaro(i,j)*hdvbf(i,j)
#  else
            vtrano(j,ibn,itbp,east) = (vbaronew(i,j)*hdvcfy(i,j)+
     &                                 vbaro(i,j)*hdvbfy(i,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                             - (vbartd(i,j,itda)*hdv(i,j)
     &                              + vbartd(i,j,itd)*hdv(i,j))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*vtrano(j,ibn,itb,east)
# else
c Update boundary barotropic velocities.
            ubaroo(j,ibn,itbp,west) = (ubaronew(ibn,j)+ubaro(ibn,j)
#  if defined ext_tide & !defined mixtideonly
     &                          - (ubartd(ibn,j,itda)+ubartd(ibn,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*ubaroo(j,ibn,itb,west)
            vbaroo(j,ibn,itbp,west) = (vbaronew(ibn,j)+vbaro(ibn,j)
#  if defined ext_tide & !defined mixtideonly
     &                          - (vbartd(ibn,j,itda)+vbartd(ibn,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*vbaroo(j,ibn,itb,west)
            i = imup1 - ibn
            ubaroo(j,ibn,itbp,east) = (ubaronew(i,j)+ubaro(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                              - (ubartd(i,j,itda)+ubartd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*ubaroo(j,ibn,itb,east)
            vbaroo(j,ibn,itbp,east) = (vbaronew(i,j)+vbaro(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                              - (vbartd(i,j,itda)+vbartd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*vbaroo(j,ibn,itb,east)
# endif
  70     continue
c
c  North/South Boundaries.
c
         do 80, ibn=1,3
         do 80, i=1,imu
# if defined transbc | defined nest2larger
c Update boundary transports.
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            utrano(i,ibn,itbp,south) = (ubaronew(i,ibn)*hdvcf(i,ibn)
     &                                  +ubaro(i,ibn)*hdvbf(i,ibn)
#  else
            utrano(i,ibn,itbp,south) = (ubaronew(i,ibn)*hdvcfx(i,ibn)
     &                                  +ubaro(i,ibn)*hdvbfx(i,ibn)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                              - (ubartd(i,ibn,itda)*hdv(i,ibn)
     &                               + ubartd(i,ibn,itd)*hdv(i,ibn))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*utrano(i,ibn,itb,south)
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            vtrano(i,ibn,itbp,south) = (vbaronew(i,ibn)*hdvcf(i,ibn)
     &                                  +vbaro(i,ibn)*hdvbf(i,ibn)
#  else
            vtrano(i,ibn,itbp,south) = (vbaronew(i,ibn)*hdvcfy(i,ibn)
     &                                  +vbaro(i,ibn)*hdvbfy(i,ibn)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                              - (vbartd(i,ibn,itda)*hdv(i,ibn)
     &                               + vbartd(i,ibn,itd)*hdv(i,ibn))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*vtrano(i,ibn,itb,south)
            j = jmt - ibn
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            utrano(i,ibn,itbp,north) = (ubaronew(i,j)*hdvcf(i,j)
     &                                  +ubaro(i,j)*hdvbf(i,j)
#  else
            utrano(i,ibn,itbp,north) = (ubaronew(i,j)*hdvcfx(i,j)
     &                                  +ubaro(i,j)*hdvbfx(i,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                              - (ubartd(i,j,itda)*hdv(i,j)
     &                               + ubartd(i,j,itd)*hdv(i,j))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*utrano(i,ibn,itb,north)
#  if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
            vtrano(i,ibn,itbp,north) = (vbaronew(i,j)*hdvcf(i,j)
     &                                  +vbaro(i,j)*hdvbf(i,j)
#  else
            vtrano(i,ibn,itbp,north) = (vbaronew(i,j)*hdvcfy(i,j)
     &                                  +vbaro(i,j)*hdvbfy(i,j)
#  endif
#  if defined ext_tide & !defined mixtideonly
     &                              - (vbartd(i,j,itda)*hdv(i,j)
     &                               + vbartd(i,j,itd)*hdv(i,j))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*vtrano(i,ibn,itb,north)
# else
c Update boundary barotropic velocities.
            ubaroo(i,ibn,itbp,south) = (ubaronew(i,ibn)+ubaro(i,ibn)
#  if defined ext_tide & !defined mixtideonly
     &                          - (ubartd(i,ibn,itda)+ubartd(i,ibn,itd))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*ubaroo(i,ibn,itb,south)
            vbaroo(i,ibn,itbp,south) = (vbaronew(i,ibn)+vbaro(i,ibn)
#  if defined ext_tide & !defined mixtideonly
     &                          - (vbartd(i,ibn,itda)+vbartd(i,ibn,itd))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*vbaroo(i,ibn,itb,south)
            j = jmt - ibn
            ubaroo(i,ibn,itbp,north) = (ubaronew(i,j)+ubaro(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                              - (ubartd(i,j,itda)+ubartd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*ubaroo(i,ibn,itb,north)
            vbaroo(i,ibn,itbp,north) = (vbaronew(i,j)+vbaro(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                              - (vbartd(i,j,itda)+vbartd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                 + spngtwt*vbaroo(i,ibn,itb,north)
# endif
  80     continue
      endif
c
#endif
c-----------------------------------------------------------------------
#if defined surfpress
c  Average (subtidal) surface pressure data.
#else
c  Average transport streamfunction data.
#endif
c-----------------------------------------------------------------------
c
      if (ibcavg(3)) then
c            
c  East/West Boundaries.
c
         do 90, ibn=1,3
         do 90, j=1,jmt
            pbc0(j,ibn,itbp,west) = (p(ibn,j)+pb(ibn,j)
#  if defined ext_tide & !defined mixtideonly
     &                       - grav*(srftd(ibn,j,itda)+srftd(ibn,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*pbc0(j,ibn,itb,west)
            i = imtp1 - ibn
            pbc0(j,ibn,itbp,east) = (p(i,j)+pb(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                           - grav*(srftd(i,j,itda)+srftd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*pbc0(j,ibn,itb,east)
  90     continue
c
c  North/South Boundaries.
c
         do 100, ibn=1,3
         do 100, i=1,imt
            pbc0(i,ibn,itbp,south) = (p(i,ibn)+pb(i,ibn)
#  if defined ext_tide & !defined mixtideonly
     &                       - grav*(srftd(i,ibn,itda)+srftd(i,ibn,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*pbc0(i,ibn,itb,south)
            j = jmtp1 - ibn
            pbc0(i,ibn,itbp,north) = (p(i,j)+pb(i,j)
#  if defined ext_tide & !defined mixtideonly
     &                           - grav*(srftd(i,j,itda)+srftd(i,j,itd))
#  endif
     &                            )*spngtp1w
     &                                  + spngtwt*pbc0(i,ibn,itb,north)
 100     continue
      endif
c
      return
      end

