      subroutine rntp_fs (fld,z0,scl,etaj)
c
c=======================================================================
c                                                                    ===
c  This routine re-interpolates the given field to grid distorted by ===
c  the given free surface.                                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     FLD    Original field.                  (real array)           ===
c     Z0     Unperturbed depths.              (real array)           ===
c     SCL    Scaling factor along the slab.   (real vector)          ===
c     ETAJ   Free surface along the slab.     (real vector)          ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /OPTIONS/                                                         ===
c                                                                    ===
c     IFLAG   initialization flags:              (integer vector)    ===
c             IFLAG(2)   interpolation switch:                       ===
c                        [0] linear, [1] cubic-spline                ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     FLD    Re-interpolated field.           (real array)           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <options.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,k
      FLOAT
     &      der1,derkm,frsd
      FLOAT
     &      d2fdz(km),etaj(imt),fld(imt,km),fin(km),scl(imt),wk(km),
     &      z0(imt,km),zin(km),zout(km)
c
      parameter (der1=c1e30, derkm=c1e30)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Loop over entire slab, reinterpolating the field.
c-----------------------------------------------------------------------
c
      do 30 i = 1, imt
c
c    Extract original and perturbed depths, and original field.
c
         do 10 k = 1, km
            zin(k)  = z0(i,k)
            zout(k) = zin(k)*scl(i) - etaj(i)
            fin(k)  = fld(i,k)
  10     continue
c
c    Interpolate field to new depths.
c
         if (iflag(2).eq.1) then
            call spline (zin,fin,km,der1,derkm,d2fdz,wk)
         endif
c
         do 20 k = 1, km
            if (iflag(2).eq.1) then
               call splint (zin,fin,d2fdz,km,zout(k),fld(i,k),frsd)
            else
               call lintrp (km,zin,fin,1,zout(k),fld(i,k))
            end if
  20     continue
  30  continue
c
      return
      end
