      subroutine rsetubaro (method,puse)
c
c=======================================================================
c                                                                    ===
c  This routine resets the barotropic velocity by either removing a  ===
c  contribution from the surface pressure or adding one back in.     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fullwd.h>
#include <scalar.h>
#include <onedim.h>
#include <fields.h>
#include <fieldsbar.h>
#include <workspb.h>
#include <sinfo.h>
#ifdef use_mpi
# include <mpif.h>
#else
# include <fpvm3.h>
#endif
#include <nest.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j,n
#ifdef coast
      integer istr,iend,jptr,l
#endif
      integer puse(imt,jmt)
      FLOAT 
     &      presscorru,presscorrv,fx,fac
      FLOAT 
     &              pwrk(imt,jmt)
      character*(*) method
c
      save pwrk
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save solution not updated by nesting
c-----------------------------------------------------------------------
c
      if (method.eq.'Remove') then
         do 10, j = 1, jmt
         do 10, i = 1, imt
            pwrk(i,j) = -p(i,j)
  10     continue
         return
      endif
c
c-----------------------------------------------------------------------
c  Solve for the updated barotropic velocities.
c-----------------------------------------------------------------------
c
c  Set time scaling.
c
#ifdef freesurf
      fx=alphav*c2dtsf
#else
      fx=c2dtsf
#endif
      if((mix.eq.1).and.eb) then
         fac=c1
      else
         if((mxp.ne.0).or.(mix.ne.0)) then
            fac=p5
         else
            fac=c1
         endif
      endif
      fx=fac*fx
      do 20, j = 1, jmt
      do 20, i = 1, imt
         pwrk(i,j) = pwrk(i,j) + p(i,j)
  20  continue
c
c  Update barotropic velocity with time change of surface pressure gradient.
c
      do 40, n = 1, nosubd
      do 40, j=j_ll_s(n)-1, j_ur_s(n)
#if defined coast & !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
c
c  Choose to compute at sea points only and avoid land points
c
         jptr = min( max(j, 2), jmtm2)
c
         do 40 l=1,lseg
            istr=isq(jptr,l)
            if(istr.eq.0) go to 40
# ifndef cyclic
            if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
# endif
            iend=ieq(jptr,l)
            if ((iend.eq.imtm2).and.(fkmq(imtm2,jptr).gt.c0)) iend=imtm1
            if ((istr.gt.i_ur_s(n)).or.(iend.lt.(i_ll_s(n)-1))) go to 40
            if (istr.lt.(i_ll_s(n)-1)) istr=i_ll_s(n)-1
            if (iend.gt.i_ur_s(n)) iend=i_ur_s(n)
            do 30 i=istr,iend
#else
c
            do 30 i=i_ll_s(n)-1, i_ur_s(n)
#endif
c
               if ((puse(i,j).eq.1) .or. (puse(i+1,j).eq.1) .or.
     &             (puse(i,j+1).eq.1) .or. (puse(i+1,j+1).eq.1)) then
# if !(defined sprsnrm01 & defined sprsnrm02 & defined sprsnrm05)
                  presscorru = (pwrk(i+1,j+1)+pwrk(i+1,j))
     &                         - (pwrk(i,j+1)+pwrk(i,j))
                  presscorru = fx*presscorru*csr(j)*dxu2r(i)
c
                  presscorrv = (pwrk(i+1,j+1)+pwrk(i,j+1))
     &                         - (pwrk(i+1,j)+pwrk(i,j))
                  presscorrv = fx*presscorrv*dyu2r(j)
c
                  ubaro(i,j) = ubaro(i,j) - presscorru
                  vbaro(i,j) = vbaro(i,j) - presscorrv
# else
                  if (uland(i,j).gt.0) then
                     presscorru = (pwrk(i+1,j+1)-pwrk(i,j+1))
     &                            *min(landt(i+1,j+1),landt(i,j+1))
     &                            + (pwrk(i+1,j)-pwrk(i,j))
     &                              *min(landt(i+1,j),landt(i,j))
                     presscorru = fx*presscorru*csr(j)*dxu2r(i)
#  if defined sprsnrm04
     &                                 *ugdwt(i,j)
#  endif
                     ubaro(i,j) = ubaro(i,j) - presscorru
                  endif
c
                  if (vland(i,j).gt.0) then
                     presscorrv = (pwrk(i+1,j+1)-pwrk(i+1,j))
     &                            *min(landt(i+1,j+1),landt(i+1,j))
     &                            + (pwrk(i,j+1)-pwrk(i,j))
     &                              *min(landt(i,j+1),landt(i,j))
                     presscorrv = fx*presscorrv*dyu2r(j)
# if defined sprsnrm04
     &                                 *vgdwt(i,j)
# endif
                     vbaro(i,j) = vbaro(i,j) - presscorrv
                  endif
# endif
               endif
c
  30        continue
  40  continue
c
#ifdef cyclic
c  Impose periodic boundary conditions.
c
      do 50 j = 1, jmtm1
         ubaro(1,j)=ubaro(imtm1,j)
         vbaro(1,j)=vbaro(imtm1,j)
         ubaro(imt,j)=ubaro(2,j)
         vbaro(imt,j)=vbaro(2,j)
  50  continue
c            
#endif
      return
      end
