      subroutine scaltrc (trcin,trcout)
c
c=======================================================================
c                                                                    ===
c  This routine multiplies the supplied baroclinic velocity          ===
c  component by the local box thickness.  Used in nesting to         ===
c  ensure baroclinicity of passed velocities.                        ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TRCIN    Tracer to scale.                    (real array)      ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /VERTICAL/                                                        ===
c                                                                    ===
c     DZT     Thicknesses of T vertical boxes.     (real array; cm)  ===
#if defined surfpress & defined freesurf 
c     FRACT   Expansion coeff. at tracer points.   (real; ND)        ===
#endif
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     TRCOUT   Scaled tracer.                      (real array)      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     none                                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <vertical.h>
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer i,j,k
      FLOAT
     *      trcin(imt,jmt,km),trcout(imt,jmt,km)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      do 10 j = 1, jmt
         do 10 k = 1, km
         do 10 i = 1, imt
#if !defined surfpress | !defined freesurf 
            trcout(i,j,k) = trcin(i,j,k)*dzt(i,j,k)
#else
            trcout(i,j,k) = trcin(i,j,k)*dzt(i,j,k)*fract(i,j)
#endif
  10  continue
c
      return
      end
