      subroutine set_brlx
c
c=======================================================================
c                                                                    ===
c     This routine sets the coefficients for the boundary relaxation ===
c     terms.                                                         ===
c                                                                    ===
c     Calls:  none                                                   ===
c                                                                    ===
c     ------                                                         ===
c     Input:                                                         ===
c     ------                                                         ===
c                                                                    ===
c     Common Blocks:                                                 ===
c                                                                    ===
c     /BNDYRLX/                                                      ===
c                                                                    ===
#ifdef bndy_rlx
c     DVBRLX    V-grid Spatial e-folding scale for bndy relaxation.  ===
c     TVBRLX    V-grid Temporal e-folding scale for bndy relaxation. ===
c     DTBRLX    T-grid Spatial e-folding scale for bndy relaxation.  ===
c     TTBRLX    T-grid Temporal e-folding scale for bndy relaxation. ===
#endif
#ifdef cstfrc
c     DCSFRC    Spatial e-folding scale for coastal friction.        ===
c     TCSFRC    Temporal e-folding scale for coastal friction.       ===
#endif
#ifdef botfrc
c     DBTFRC    Spatial e-folding scale for bottom friction.         ===
c     TBTFRC    Temporal e-folding scale for bottom friction.        ===
#endif
c                                                                    ===
#ifdef coast
c     /FULLWD/                                                       ===
c                                                                    ===
c     LANDT     land/sea mask at the tracer points                   ===
c     LANDV     land/sea mask at the velocity points                 ===
c                                                                    ===
#endif
c     -------                                                        ===
c     Output:                                                        ===
c     -------                                                        ===
c                                                                    ===
c     Common Blocks:                                                 ===
c                                                                    ===
c     /BNDYRLX/                                                      ===
c                                                                    ===
#ifdef bndy_rlx
c     TFACBRLX  Boundary relaxation coefficient at tracer points.    ===
# ifndef sponge_uvsplit
c     VFACBRLX  Boundary relaxation coefficient at velocity points.  ===
# else
c     UFACBRLX  Zonal boundary relaxation coeff. at velocity points. ===
c     VFACBRLX  Meridional bndy. relaxation coeff. at V-points.      ===
# endif
#endif
#ifdef cstfrc
c     FACCSFRC  Coastal friction cofficients.                        ===
#endif
#ifdef botfrc
c     FACBTFRC  Bottom friction cofficients.                         ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c     Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <bndyrlx.h>
#ifdef coast
# include <fullwd.h>
#endif
#if defined smallpsdt & defined small5psdt & defined botfrc
# include <vertical.h>
# include <vertslabs.h>
#endif
c
c-----------------------------------------------------------------------
c     Define local data.
c-----------------------------------------------------------------------
c
      integer i
#if defined bndy_rlx | defined cstfrc | (defined smallpsdt & defined small5psdt & defined botfrc)
     &        ,j
#endif
#if defined smallpsdt & defined small5psdt & defined botfrc
     &        ,k
#endif
#if defined bndy_rlx
     &        ,iust,iund,just,jund,itst,itnd,jtst,jtnd
#endif
#if defined coast & ((defined bndy_rlx & !defined no_sponge_coast) | defined cstfrc)
     &        ,ii,jj
      FLOAT
     &      dist
#  ifdef cstfrc
     &      ,spdist
#  endif
#if defined bndy_rlx
     &      ,spngmin
#endif
#endif
c
#if defined bndy_rlx
# ifndef hyperbolicsponge
      parameter (iust=2, iund=imtm2, just=2, jund=jmtm2,
     &           itst=2, itnd=imtm2, jtst=2, jtnd=jmtm2,
     &           spngmin=c0)
# else
      parameter (iust=1, iund=imtm1, just=1, jund=jmtm1,
     &           itst=1, itnd=imt,   jtst=1, jtnd=jmtm1,
     &           spngmin=c1)
# endif
#endif
c
c=======================================================================
c     Begin executable code.
c=======================================================================
c
#ifdef bndy_rlx
c-----------------------------------------------------------------------
c     Define boundary relaxation coefficients at velocity points.
c-----------------------------------------------------------------------
c
      do 30 j = 1, jmt
      do 30 i = 1, imt
c
        if ((dvbrlx.gt.c0).and.(tvbrlx.gt.c0)) then

c
c         -- Find distance to nearest open boundary.
c
# if !defined coast | !defined no_sponge_coast
#  if !defined sponge_uvsplit & !defined cyclic
          vfacbrlx(i,j) = FLoaT( min( i-iust, iund-i, j-just, jund-j ) )
#  else
#   ifdef sponge_uvsplit
          ufacbrlx(i,j) = FLoaT( min( i-iust, iund-i ) )
          ufacbrlx(i,j) = max( ufacbrlx(i,j), spngmin )
#   endif
          vfacbrlx(i,j) = FLoaT( min( j-just, jund-j ) )
#  endif
# else
          vfacbrlx(i,j) = sqrt(FLoaT(imt*imt + jmt*jmt))
          ii = 1
          do 03 while ((ii.le.imt).and.(vfacbrlx(i,j).gt.c0))
             jj = just
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.vfacbrlx(i,j)) vfacbrlx(i,j) = dist
             end if
             jj = jund
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.vfacbrlx(i,j)) vfacbrlx(i,j) = dist
             end if
             ii = ii + 1
 03       continue
#  if !defined sponge_uvsplit & !defined cyclic
          jj = 1
          do 07 while ((jj.le.jmt).and.(vfacbrlx(i,j).gt.c0))
             ii = iust
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.vfacbrlx(i,j)) vfacbrlx(i,j) = dist
             end if
             ii = iund
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.vfacbrlx(i,j)) vfacbrlx(i,j) = dist
             end if
             jj = jj + 1
 07       continue
#  elif defined sponge_uvsplit
          ufacbrlx(i,j) = sqrt(FLoaT(imt*imt + jmt*jmt))
          jj = 1
          do 07 while ((jj.le.jmt).and.(ufacbrlx(i,j).gt.c0))
             ii = iust
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.ufacbrlx(i,j)) ufacbrlx(i,j) = dist
             end if
             ii = iund
             if (landv(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.ufacbrlx(i,j)) ufacbrlx(i,j) = dist
             end if
             jj = jj + 1
 07       continue
          ufacbrlx(i,j) = max( ufacbrlx(i,j), spngmin )
#  endif
# endif
          vfacbrlx(i,j) = max( vfacbrlx(i,j), spngmin )
# if defined coast & !defined no_sponge_coast & !defined sponge_uvsplit
c
c         -- Find distance to nearest boundary/coastline.
c
          jj = 1
          do 20 while ((jj.le.jmt).and.(vfacbrlx(i,j).gt.c0))
            ii = 1
            do 10 while ((ii.le.imt).and.(vfacbrlx(i,j).gt.c0))
              if (landv(ii,jj).eq.0) then
                 dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                 if (dist.lt.vfacbrlx(i,j)) vfacbrlx(i,j) = dist
              end if
              ii = ii + 1
 10         continue
            jj = jj + 1
 20       continue
# endif
c
c         -- Compute boundary relaxation coefficient from minimum distance.
c
# ifdef sponge_uvsplit
#  ifndef cyclic
#   ifndef hyperbolicsponge
          ufacbrlx(i,j) = exp( cm1*(ufacbrlx(i,j)/dvbrlx)**2 ) / tvbrlx
#   else
          if (ufacbrlx(i,j).le.dvbrlx) then
             ufacbrlx(i,j) = ( dvbrlx*(dvbrlx+c1-ufacbrlx(i,j)) ) 
     &                       / (tvbrlx*(dvbrlx+c1)*ufacbrlx(i,j))
          else
             ufacbrlx(i,j) = c0
          end if
#   endif
#  else
          ufacbrlx(i,j) = c0
#  endif
# endif
# ifndef hyperbolicsponge
          vfacbrlx(i,j) = exp( cm1*(vfacbrlx(i,j)/dvbrlx)**2 ) / tvbrlx
# else
          if (vfacbrlx(i,j).le.dvbrlx) then
             vfacbrlx(i,j) = ( dvbrlx*(dvbrlx+c1-vfacbrlx(i,j)) ) 
     &                       / (tvbrlx*(dvbrlx+c1)*vfacbrlx(i,j))
          else
             vfacbrlx(i,j) = c0
          end if
# endif
c
         else
c
c           -- No boundary relaxation on velocity grid.
c
# ifdef sponge_uvsplit
          ufacbrlx(i,j) = c0
# endif
          vfacbrlx(i,j) = c0
c
        end if
c
 30   continue
c
c-----------------------------------------------------------------------
c     Define boundary relaxation coefficients at tracer points.
c-----------------------------------------------------------------------
c
      do 60 j = 1, jmt
      do 60 i = 1, imt
c
        if ((dtbrlx.gt.c0).and.(ttbrlx.gt.c0)) then
c
c         -- Find distance to nearest open boundary.
c
# if !defined coast | !defined no_sponge_coast
#  ifndef cyclic
          tfacbrlx(i,j) = FLoaT( min( i-itst, itnd-i, j-jtst, jtnd-j ) )
#  else
          tfacbrlx(i,j) = FLoaT( min( j-jtst, jtnd-j ) )
#  endif
# else
          tfacbrlx(i,j) = sqrt(FLoaT(imt*imt + jmt*jmt))
          ii = 1
          do 33 while ((ii.le.imt).and.(tfacbrlx(i,j).gt.c0))
             jj = jtst
             if (landt(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.tfacbrlx(i,j)) tfacbrlx(i,j) = dist
             end if
             jj = jtnd
             if (landt(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.tfacbrlx(i,j)) tfacbrlx(i,j) = dist
             end if
             ii = ii + 1
 33       continue
#  ifndef cyclic
          jj = 1
          do 37 while ((jj.le.jmt).and.(tfacbrlx(i,j).gt.c0))
             ii = itst
             if (landt(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.tfacbrlx(i,j)) tfacbrlx(i,j) = dist
             end if
             ii = itnd
             if (landt(ii,jj).ne.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.tfacbrlx(i,j)) tfacbrlx(i,j) = dist
             end if
             jj = jj + 1
 37       continue
#  endif
# endif
          tfacbrlx(i,j) = max( tfacbrlx(i,j), spngmin )
# if defined coast & !defined no_sponge_coast
c
c         -- Find distance to nearest boundary/coastline.
c
          jj = 1
          do 50 while ((jj.le.jmt).and.(tfacbrlx(i,j).gt.c0))
            ii = 1
            do 40 while ((ii.le.imt).and.(tfacbrlx(i,j).gt.c0))
              if (landt(ii,jj).eq.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.tfacbrlx(i,j)) tfacbrlx(i,j) = dist
              end if
              ii = ii + 1
 40         continue
            jj = jj + 1
 50       continue
# endif
c
c         -- Compute boundary relaxation coefficient from minimum distance.
c
# ifndef hyperbolicsponge
          tfacbrlx(i,j) = exp( cm1*(tfacbrlx(i,j)/dtbrlx)**2 ) /ttbrlx
# else
          if (tfacbrlx(i,j).le.dtbrlx) then
             tfacbrlx(i,j) = ( dtbrlx*(dtbrlx+c1-tfacbrlx(i,j)) ) 
     &                       / (ttbrlx*(dtbrlx+c1)*tfacbrlx(i,j))
          else
             tfacbrlx(i,j) = c0
          end if
# endif
c
         else
c
c         -- No boundary relaxation on tracer grid.
c
          tfacbrlx(i,j) = c0
c
        end if
c
 60   continue
c
#endif
#ifdef cstfrc
c-----------------------------------------------------------------------
c     Define coastal friction coefficients.
c-----------------------------------------------------------------------
c
# ifdef coast
      spdist = c2*sqrt( FLoaT(imt*imt) + FLoaT(jmt*jmt) )
c
# endif
      do 90 j = 1, jmt
      do 90 i = 1, imt
c
#  ifdef coast
        if ((dcsfrc.gt.c0).and.(tcsfrc.gt.c0)) then
c
c         -- Find distance to nearest coastline.
c
          faccsfrc(i,j) = spdist
          jj = 1
          do 80 while ((jj.le.jmt).and.(faccsfrc(i,j).gt.c0))
            ii = 1
            do 70 while ((ii.le.imt).and.(faccsfrc(i,j).gt.c0))
              if (landv(ii,jj).eq.0) then
                dist = sqrt( (FLoaT(ii-i))**2 + (FLoaT(jj-j))**2 )
                if (dist.lt.faccsfrc(i,j)) faccsfrc(i,j) = dist
              end if
              ii = ii + 1
 70         continue
            jj = jj + 1
 80       continue
c
c         -- Compute coastal friction coefficient from minimum distance.
c
          if (faccsfrc(i,j).lt.spdist) then
            faccsfrc(i,j) = exp(cm1*(faccsfrc(i,j)/dcsfrc)**2)/tcsfrc
           else
            faccsfrc(i,j) = c0
          end if
c
         else
# endif
c
c         -- No coastal friction.
c
          faccsfrc(i,j) = c0
# ifdef coast
c
        end if
# endif
c
 90   continue
c
#endif
#ifdef botfrc
c-----------------------------------------------------------------------
c     Define bottom friction coefficients.
c-----------------------------------------------------------------------
c
      do 100 i = 1, km
c
        if ((dbtfrc.gt.c0).and.(tbtfrc.gt.c0)) then
          facbtfrc(i) = exp(cm1*(FLoaT(i-km)/dbtfrc)**2)/tbtfrc
         else
          facbtfrc(i) = c0
        end if
c
100   continue
c
# if defined smallpsdt & defined small5psdt
c  compute mean bottom friction coefficient for use in fast-time
c
      do 110 j = 1, jmt
      do 110 i = 1, imt
         fmnbtfrc(i,j) = facbtfrc(1)*dzv(i,j,1)
110   continue
c
      do 120 k = 2, km
      do 120 j = 1, jmt
      do 120 i = 1, imt
         fmnbtfrc(i,j) = fmnbtfrc(i,j) + facbtfrc(k)*dzv(i,j,k)
120   continue
c
      do 130 j = 1, jmt
      do 130 i = 1, imt
         fmnbtfrc(i,j) = fmnbtfrc(i,j)*hvav(i,j)
130   continue
c
# endif
#endif
      return
      end
