      subroutine shap1do (zz,lnz,nord)
c
c=======================================================================
c                                                                    ===
c  This routine applies a Shapiro filter on an open curve.           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     LNZ    The length of ZZ.                 (integer)             ===
c     NORD   The order of the Shapiro filter.  (integer)             ===
c     ZZ     The field to be filtered.         (real vector)         ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ZZ     The filtered field.               (real vector)         ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     none                                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer mxexp1
      parameter (mxexp1=maxext+1)
      integer i,idown,iodev,iup,n,lnz,lnzm1,lnzp1,nord
      real    fac
      real g(0:mxexp1,0:1),zz(lnz)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize pointer & scale factors.
c-----------------------------------------------------------------------
c
      iup   = 1
      lnzm1 = lnz - 1
      lnzp1 = lnz + 1
c
      iodev=(nord+1)/2-nord/2
      fac=cm1+c2*float(iodev)
      fac=fac/c2**(2*nord)
c
c-----------------------------------------------------------------------
c  Load data into work array.
c-----------------------------------------------------------------------
c
      do 10 i=1,lnz
         g(i,iup)=zz(i)
  10  continue
c
#if (!defined flppbc & !defined shbc2drv) | defined prs1stord
      g(0,iup)     = zz(1)
      g(lnzp1,iup) = zz(lnz)
#elif !defined shbc2drv
      g(0,iup)     = zz(2)
      g(lnzp1,iup) = zz(lnzm1)
#else
      g(0,iup)     = c2*zz(1)-zz(2)
      g(lnzp1,iup) = c2*zz(lnz)-zz(lnzm1)
#endif
c
c-----------------------------------------------------------------------
c  Construct differences.
c-----------------------------------------------------------------------
c
       do 30 n=1,nord
         idown=1-iup
         do 20 i=1,lnz
            g(i,idown)=(g(i+1,iup)-g(i,iup))+(g(i-1,iup)-g(i,iup))
  20     continue
#if !defined shbc2drv
         g(0,idown)     = g(2,idown)
         g(lnzp1,idown) = g(lnzm1,idown)
#else
         g(0,idown)     = c2*g(1,idown)-g(2,idown)
         g(lnzp1,idown) = c2*g(lnz,idown)-g(lnzm1,idown)
#endif
         iup=idown
  30  continue
c
c-----------------------------------------------------------------------
c  Apply filter.
c-----------------------------------------------------------------------
c
      do 40 i=1,lnz
         zz(i) = zz(i) + fac*g(i,iup)
  40  continue
c
      return
      end
