      subroutine shap_pslim (iopt)
c
c=======================================================================
c                                                                    ===
c  This routine limits the result of shapiro filtering tracers       ===
c  fields to bounds based on the pre-existing tracer fields.         ===
c                                                                    ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c    IOPT    Job control.            (integer)                       ===
c               [0] compute limits                                   ===
c               [1] impose limits                                    ===
c                                                                    ===
c    Common Blocks:                                                  ===
c                                                                    ===
c    /FILTDAT/                                                       ===
c                                                                    ===
c       NORDT    tracers: order of the Shapiro filter.               ===
c                                                                    ===
#ifdef coast
c    /FULLWD/                                                        ===
c                                                                    ===
c       LANDT      land/sea mask at tracer points.                   ===
c                                                                    ===
#endif
c    /VOLDAT/                                                        ===
c                                                                    ===
c       XT    Tracer fields at TAU+1 time level.       (real array)  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <filtdat.h>
#include <fields.h>
#ifdef coast
# include <fullwd.h>
#endif
#include <voldat.h>
#if defined limpstshap
# include <scalar.h>
# include <workspr.h>
#endif
#if defined surfpress & defined freesurf
# include <vertical.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
#if defined limpstshap & defined shlmfdg & !defined vlfdg
      FLOAT
     &      fdgfac
# ifndef shfdg1p2
      parameter (fdgfac=1.1)
# else
      parameter (fdgfac=1.2)
# endif
c
#elif defined limpstshap & defined shlmfdg & defined vlfdg
      FLOAT
     &      fdgfac,ffaclo,ffachi,fnum,fden
      parameter (ffaclo=c9/c10, ffachi=c10/c9)
c
#endif
      integer iopt,itau,itaum1
      integer dij,i2,ii,ind,ist,j2,jj,jnd,jst,k,n,ip,ip2
      FLOAT
     &      psmax(imt,jmt),psmin(imt,jmt)
#ifdef limpstshap
     &      ,xtn(nwds,km,nt),xtnm1(nwds,km,nt)
      FLOAT
     &      fn,fnm1,ftn,ftnm1,ftnp1
#endif
c
      save psmax,psmin
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute local limits.
c-----------------------------------------------------------------------
c
      if (iopt.eq.0) then
c
c  Initialize limits with value at the point.
c
         do 10, jj=1,jmt
            do 10, ii=1,imt
               ip=ii+(jj-1)*imt
#ifndef limpstshap
# ifdef shapetalag
               psmax(ii,jj)=pb(ii,jj)
               psmin(ii,jj)=pb(ii,jj)
# else
               psmax(ii,jj)=p(ii,jj)
               psmin(ii,jj)=p(ii,jj)
# endif
#else
# ifdef shapetalag
               ftn   = pb(ii,jj)
               ftnm1 = grav*etatbb(ii,jj)
# else
               ftn   = p(ii,jj)
               ftnm1 = pb(ii,jj)
# endif
# if defined shapetalag & !defined shapetalaglim
               ftnp1 = p(ii,jj)
# elif !defined shlmfdg
               ftnp1 = ftn + (ftn-ftnm1)
# elif !defined vlfdg
               ftnp1 = ftn + fdgfac*(ftn-ftnm1)
# else
               fnum = abs(fract(ii,jj) - fractb(ii,jj))
               fden = abs(fractb(ii,jj) - fractbb(ii,jj))
               if ((ffaclo*fden.lt.fnum).and.(fnum.lt.ffachi*fden)) then
                  fdgfac = fnum/fden
               elseif (fnum.gt.ffachi*fden) then
                  fdgfac = ffachi
               elseif (ffaclo*fden.gt.fnum) then
                  fdgfac = ffaclo
               else
                  fdgfac = c1
               endif
               ftnp1 = ftn + fdgfac*(ftn-ftnm1)
# endif
               psmax(ii,jj) = max(ftn, ftnm1,
# if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | defined shapetalag
     &                             ftnp1 )
# else
     &                             min(ftnp1,p(ii,jj)) )
# endif
               psmin(ii,jj) = min(ftn, ftnm1,
# if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | defined shapetalag
     &                             ftnp1 )
# else
     &                             max(ftnp1,p(ii,jj)) )
# endif
#endif
 10      continue
c
c  Update limits with neighboring values.
c
#ifndef limlimshap
         dij = nordp/2
#else
         dij = 1
#endif
            do 40, jj=1,jmt
               jst = max(jj-dij, 1)
               jnd = min(jj+dij, jmt)
               do 40, ii=1,imt
                  ist = max(ii-dij, 1)
                  ind = min(ii+dij, imt)
#ifdef coast
                  if (landt(ii,jj).eq.1) then
#endif
                     ip = ii + (jj-1)*imt
                     do 30, j2 = jst, jnd
#ifndef limlimshap
                     do 30, i2 = ist, ind
#else
                        i2 = ii
#endif
#ifdef coast
                        if (landt(i2,j2).eq.1) then
#endif
                           ip2 = i2 + (j2-1)*imt
#if defined limpstshap & defined surfpress & defined freesurf
# if defined vlfdg
               fnum = abs(fract(i2,j2) - fractb(i2,j2))
               fden = abs(fractb(i2,j2) - fractbb(i2,j2))
               if ((ffaclo*fden.lt.fnum).and.(fnum.lt.ffachi*fden)) then
                  fdgfac = fnum/fden
               elseif (fnum.gt.ffachi*fden) then
                  fdgfac = ffachi
               elseif (ffaclo*fden.gt.fnum) then
                  fdgfac = ffaclo
               else
                  fdgfac = c1
               endif
# endif
#endif
#ifndef limpstshap
# ifdef shapetalag
                              psmax(ii,jj) = max( psmax(ii,jj) ,
     &                                             pb(i2,j2) )
                              psmin(ii,jj) = min( psmin(ii,jj) ,
     &                                             pb(i2,j2) )
# else
                              psmax(ii,jj) = max( psmax(ii,jj) ,
     &                                             p(i2,j2) )
                              psmin(ii,jj) = min( psmin(ii,jj) ,
     &                                             p(i2,j2) )
# endif
#else
# if defined shapetalag
                              ftn   = pb(i2,j2)
                              ftnm1 = grav*etatbb(i2,j2)
# else
                              ftn   = p(i2,j2)
                              ftnm1 = pb(i2,j2)
# endif
# if defined shapetalag & !defined shapetalaglim
                              ftnp1 = p(i2,j2)
# elif !defined shlmfdg
                              ftnp1 = ftn + (ftn-ftnm1)
# else
                              ftnp1 = ftn + fdgfac*(ftn-ftnm1)
# endif
                              psmax(ii,jj) = max( psmax(ii,jj), ftnm1,
# if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | defined shapetalag
     &                                             ftn, ftnp1 )
# else
     &                                     ftn, min(ftnp1,p(i2,j2)) )
# endif
                              psmin(ii,jj) = min( psmin(ii,jj), ftnm1,
# if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | defined shapetalag
     &                                             ftn, ftnp1 )
# else
     &                                     ftn, max(ftnp1,p(i2,j2)) )
# endif
#endif
C
#ifdef coast
                        end if
#endif
  30                 continue
#ifdef limlimshap
                     j2 = jj
                     do 37, i2 = ist, ind
# ifdef coast
                        if (landt(i2,j2).eq.1) then
# endif
                           ip2 = i2 + (j2-1)*imt
# if defined limpstshap & defined surfpress & defined freesurf
#  if defined vlfdg
               fnum = abs(fract(i2,j2) - fractb(i2,j2))
               fden = abs(fractb(i2,j2) - fractbb(i2,j2))
               if ((ffaclo*fden.lt.fnum).and.(fnum.lt.ffachi*fden)) then
                  fdgfac = fnum/fden
               elseif (fnum.gt.ffachi*fden) then
                  fdgfac = ffachi
               elseif (ffaclo*fden.gt.fnum) then
                  fdgfac = ffaclo
               else
                  fdgfac = c1
               endif
#  endif
# endif
c
# ifndef limpstshap
#  if defined shapetalag
                              psmax(ii,jj) = max( psmax(ii,jj) ,
     &                                             pb(i2,j2) )
                              psmin(ii,jj) = min( psmin(ii,jj) ,
     &                                             pb(i2,j2) )
#  else
                              psmax(ii,jj) = max( psmax(ii,jj) ,
     &                                             p(i2,j2) )
                              psmin(ii,jj) = min( psmin(ii,jj) ,
     &                                             p(i2,j2) )
#  endif
# else
#  if defined shapetalag
                              ftn   = pb(i2,j2)
                              ftnm1 = grav*etatbb(i2,j2)
#  else
                              ftn   = p(i2,j2)
                              ftnm1 = pb(i2,j2)
#  endif
#  if defined shapetalag & !defined shapetalaglim
                              ftnp1 = p(i2,j2)
#  elif !defined shlmfdg
                              ftnp1 = ftn + (ftn-ftnm1)
#  else
                              ftnp1 = ftn + fdgfac*(ftn-ftnm1)
#  endif
                              psmax(ii,jj) = max( psmax(ii,jj), ftnm1,
#  if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | shapetalag
     &                                             ftn, ftnp1 )
#  else
     &                                     ftn, min(ftnp1,p(i2,j2)) )
#  endif
                              psmin(ii,jj) = min( psmin(ii,jj), ftnm1,
#  if ( !defined shlmfdg & !defined shlinchk ) | defined shnobnd | shapetalag
     &                                             ftn, ftnp1 )
#  else
     &                                     ftn, max(ftnp1,p(i2,j2)) )
#  endif
# endif
c
# ifdef coast
                        end if
# endif
  37                 continue
#endif
#ifdef coast
                  end if
#endif
  40     continue
c
c-----------------------------------------------------------------------
c  Impose local limits.
c-----------------------------------------------------------------------
c
      elseif (iopt.eq.1) then
c
         do 60, jj=1,jmt
         do 60, ii=1,imt
#ifdef coast
            if (landt(ii,jj).eq.1) then
#endif
#ifdef shapetalag
               pb(ii,jj) = min( max( pb(ii,jj), psmin(ii,jj)) ,
#else
               p(ii,jj) = min( max( p(ii,jj), psmin(ii,jj)) ,
#endif
     &                              psmax(ii,jj) )
#ifdef coast
            end if
#endif
 60      continue
      end if
c
      return
      end
