#if !defined nest2larger & !defined nest2smaller
        subroutine UV_hat
#else
        subroutine UV_hat (filtflag)
#endif
c
c=======================================================================
c                                                                    ===
c  This subroutine calculates the augmented velocities used in order ===
c  to split the Barotropic velocity equations from the Elliptic      ===
c  equation for the change in surface pressure (J. K. Dukowicz and   ===
c  R. D. Smith,JGR,99,7991-8014,1994).                               ===
c                                                                    ===
c=======================================================================
c
c----------------------------------------------------------------------
c  Define global data.
c----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fieldsbar.h>
#include <fields.h>
#include <scalar.h>
#include <fullwd.h>
#include <onedim.h>
#include <options.h>
#include <sinfo.h>
#ifdef shapiro
# include <filtdat.h>
#endif
#if defined spliterr | defined lagnonlin | defined tidepredctr | defined fdgtidpot | defined smallpsdt
# include <vertical.h>
#endif
#if defined lagnonlin | defined tidepredctr | defined fdgtidpot | defined tidvforc | (defined sprsnrm01 & defined sprsnrm02) | (defined smallpsdt & defined small5psdt)
# include <vertslabs.h>
#endif
#if defined fdguvhttd | defined fdguvhtnm1td | defined tidepredctr | defined fdgtidpot | defined tidvforc | (smallpsdt & defined small5psdt & defined bndy_rlx)
# include <tidesp.h>
#endif
#if defined cdbotsep & defined smallpsdt & defined small5psdt & !defined cdbotmagvsum
# include <cvmix.h>
#endif
#if (defined botfrc | defined cstfrc) & defined smallpsdt & defined small5psdt
# include <bndyrlx.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j
#ifdef coast
     &        ,iend,istr,jptr,l
#endif
#ifdef shapiro
     &        ,nn
#endif
      FLOAT
     &     fcori,frhsu,frhsv,pressgradu,pressgradu1,pressgradu2,
     &     pressgradv,pressgradv1,pressgradv2,ww
#if defined spliterr | ((defined botfrc | defined cstfrc) & defined smallpsdt & defined small5psdt)
     &        ,fac
#endif
#if defined spliterr
     &        ,fac2
#endif
#if defined cdbotsep & defined smallpsdt & defined small5psdt & !defined cdbotmagvsum
     &        ,uvmag
#endif
#if defined nest2larger | defined nest2smaller
      character*(*) filtflag
#endif
#ifdef divdump
      FLOAT
     &     pgrdx(imt,jmt),pgrdy(imt,jmt),rhsx(imt,jmt),rhsy(imt,jmt)
      integer dmpcnt,dmptim
      save dmpcnt,dmptim
      data dmpcnt,dmptim/0,1/
#endif
#if defined bndy_rlx & defined smallpsdt & defined small5psdt
      FLOAT
     &     ubar0(imt,jmt),vbar0(imt,jmt)
      logical first
      save first,ubar0,vbar0
      data first/.true./
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef divdump
      dmpcnt = dmpcnt + 1
      if (dmpcnt.eq.dmptim) then
         do j = 1, jmt
            do i = 1, imt
               pgrdx(i,j) = c0
               pgrdy(i,j) = c0
               rhsx(i,j)  = c0
               rhsy(i,j)  = c0
            end do
         end do
      endif
#endif
# ifdef check_dt
      print *,'***UV_HAT: c2dtsf=',c2dtsf,'  c2dtps=',c2dtps
# endif
#if defined bndy_rlx & defined smallpsdt & defined small5psdt
c-----------------------------------------------------------------------
c  Save/update sponging barotropic velocities for small time.
c-----------------------------------------------------------------------
c
      if (first)then
         do j = 1, jmt
            do i = 1, imt
# if !defined ext_tide | !defined surfpress | !defined freesurf | defined mixtideonly
               ubar0(i,j) = ubarob(i,j)
               vbar0(i,j) = vbarob(i,j)
# else
#  if !defined transspng
               ubar0(i,j) = ubarob(i,j) - ubartd(i,j,itdb)
               vbar0(i,j) = vbarob(i,j) - vbartd(i,j,itdb)
#  else
               ubar0(i,j) = ubarob(i,j) - ubartd(i,j,itdb)/fracvb(i,j)
               vbar0(i,j) = vbarob(i,j) - vbartd(i,j,itdb)/fracvb(i,j)
#  endif
# endif
            end do
         end do
         first = .false.
# if defined sponge_timave
      else
         do j = 1, jmt
            do i = 1, imt
#  if !defined ext_tide | !defined surfpress | !defined freesurf | defined mixtideonly
               ubar0(i,j) =bspngtp1w*c2*ubarob(i,j) +bspngtwt*ubar0(i,j)
               vbar0(i,j) =bspngtp1w*c2*vbarob(i,j) +bspngtwt*vbar0(i,j)
#  else
#   if !defined transspng
               ubar0(i,j) = bspngtwt*ubar0(i,j) +
     &                       bspngtp1w*c2*(ubarob(i,j)-ubartd(i,j,itdb))
               vbar0(i,j) = bspngtwt*vbar0(i,j) +
     &                       bspngtp1w*c2*(vbarob(i,j)-vbartd(i,j,itdb))
#   else
               ubar0(i,j) = bspngtwt*ubar0(i,j) +
     &           bspngtp1w*c2*(ubarob(i,j)-ubartd(i,j,itdb)/fracvb(i,j))
               vbar0(i,j) = bspngtwt*vbar0(i,j) +
     &           bspngtp1w*c2*(vbarob(i,j)-vbartd(i,j,itdb)/fracvb(i,j))
#   endif
#  endif
            end do
         end do
# endif
      endif
#endif
c-----------------------------------------------------------------------
c  Solve for the augmented velocities.
c-----------------------------------------------------------------------
#if defined spliterr
c
      fac2 = alphav*alphav*grav*c2dtps
#endif
c
      do 30 j=1,jmtm1
#if defined coast & !(defined sprsnrm01 & defined sprsnrm02)
c
c  Choose to compute at sea points only and avoid land points
c
         jptr = min( max(j, 2), jmtm2)
c
         do 20 l=1,lseg
            istr=isq(jptr,l)
            if (istr.eq.0) go to 30
# ifndef cyclic
            if ((istr.eq.2).and.(fkmq(2,jptr).gt.c0)) istr=1
# endif
            iend=ieq(jptr,l)
            if ((iend.eq.imtm2).and.(fkmq(imtm2,jptr).gt.c0)) iend=imtm1
        do 10 i=istr,iend
#elif !defined cyclic
c
        do 10 i=1,imtm1
#else
c
        do 10 i=2,imtm1
#endif
c
c    Surface pressure gradient contributions:
c
#if !defined fdguvhtnm1td & !defined tidepredctr
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradu1=(pb(i+1,j+1)+pb(i+1,j))-(pb(i,j+1)+pb(i,j))
# else
              pressgradu1=(pb(i+1,j+1)-pb(i,j+1))
#  if defined coast
     &                     *min(landt(i+1,j+1),landt(i,j+1))
#  endif
     &                     + (pb(i+1,j)-pb(i,j))
#  if defined coast
     &                     *min(landt(i+1,j),landt(i,j))
#  endif
# endif
              pressgradu1=(c1-gammabar)*pressgradu1*csr(j)*dxu2r(i)
#elif defined fdguvhtnm1td
              pressgradu1=(srftd(i+1,j+1,itdb)+srftd(i+1,j,itdb))
     &                     -(srftd(i,j+1,itdb)+srftd(i,j,itdb))
              pressgradu1=(c1-gammabar)*pressgradu1*csr(j)*dxu2r(i)*grav
#else
              pressgradu1=(pb(i+1,j+1)+pb(i+1,j))-(pb(i,j+1)+pb(i,j))
              pressgradu2=((srftd(i+1,j+1,itda)+srftd(i+1,j,itda))
     &                     -(srftd(i,j+1,itda)+srftd(i,j,itda)))*grav
              pressgradu1=alphav*(pressgradu1+pressgradu2)
     &                                                  *csr(j)*dxu2r(i)
C    &                                                                 ^
#endif
#if defined fdgtidpot
              pressgradu2=((srftd(i+1,j+1,itda)+srftd(i+1,j,itda))
     &                     -(srftd(i,j+1,itda)+srftd(i,j,itda)))*grav
# if defined fdgtdpot2
     &                     *min(fkmq(i,j),0.69)
# endif
              pressgradu1 = pressgradu1 - pressgradu2*csr(j)*dxu2r(i)
C    &                                                                 ^
#endif
c
#ifndef fdguvhttd
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradu2=(p(i+1,j+1)+p(i+1,j))-(p(i,j+1)+p(i,j))
# else
              pressgradu2=(p(i+1,j+1)-p(i,j+1))
#  if defined coast
     &                     *min(landt(i+1,j+1),landt(i,j+1))
#  endif
     &                     + (p(i+1,j)-p(i,j))
#  if defined coast
     &                     *min(landt(i+1,j),landt(i,j))
#  endif
# endif
              pressgradu2=gammabar*pressgradu2*csr(j)*dxu2r(i)
#else
              pressgradu2=(srftd(i+1,j+1,itd)+srftd(i+1,j,itd))
     &                     -(srftd(i,j+1,itd)+srftd(i,j,itd))
              pressgradu2=gammabar*pressgradu2*csr(j)*dxu2r(i)*grav
#endif
c     
              pressgradu=pressgradu1+pressgradu2
c
#if !defined fdguvhtnm1td & !defined tidepredctr
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradv1=(pb(i+1,j+1)+pb(i,j+1))-(pb(i+1,j)+pb(i,j))
# else
              pressgradv1=(pb(i+1,j+1)-pb(i+1,j))
#  if defined coast
     &                     *min(landt(i+1,j+1),landt(i+1,j))
#  endif
     &                     + (pb(i,j+1)-pb(i,j))
#  if defined coast
     &                     *min(landt(i,j+1),landt(i,j))
#  endif
# endif
              pressgradv1=(c1-gammabar)*pressgradv1*dyu2r(j)
#elif defined fdguvhtnm1td
              pressgradv1=(srftd(i+1,j+1,itdb)+srftd(i,j+1,itdb))
     &                     -(srftd(i+1,j,itdb)+srftd(i,j,itdb))
              pressgradv1=(c1-gammabar)*pressgradv1*dyu2r(j)*grav
#else
              pressgradv1=(pb(i+1,j+1)+pb(i,j+1))-(pb(i+1,j)+pb(i,j))
              pressgradv2=((srftd(i+1,j+1,itda)+srftd(i,j+1,itda))
     &                     -(srftd(i+1,j,itda)+srftd(i,j,itda)))*grav
              pressgradv1=alphav*(pressgradv1+pressgradv2)*dyu2r(j)
C    &                                                                 ^
#endif
#if defined fdgtidpot
              pressgradv2=((srftd(i+1,j+1,itda)+srftd(i,j+1,itda))
     &                     -(srftd(i+1,j,itda)+srftd(i,j,itda)))*grav
# if defined fdgtdpot2
     &                     *min(fkmq(i,j),0.69)
# endif
              pressgradv1= pressgradv1 - pressgradv2*dyu2r(j)
C    &                                                                 ^
#endif
c
#ifndef fdguvhttd
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradv2=(p(i+1,j+1)+p(i,j+1))-(p(i+1,j)+p(i,j))
# else
              pressgradv2=(p(i+1,j+1)-p(i+1,j))
#  if defined coast
     &                     *min(landt(i+1,j+1),landt(i+1,j))
#  endif
     &                    + (p(i,j+1)-p(i,j))
#  if defined coast
     &                     *min(landt(i,j+1),landt(i,j))
#  endif
# endif
              pressgradv2=gammabar*pressgradv2*dyu2r(j)
#else
              pressgradv2=(srftd(i+1,j+1,itd)+srftd(i,j+1,itd))
     &                     -(srftd(i+1,j,itd)+srftd(i,j,itd))
              pressgradv2=gammabar*pressgradv2*dyu2r(j)*grav
#endif
c
              pressgradv=pressgradv1+pressgradv2
c
#if defined spliterr
c    Splitting error, gradient term (with coriolis curl) lagged a time step:
c
              fcori = c2*omega*sine(i,j)
              fac   = fac2*fcori
c
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradu2 = (detat(i+1,j+1)+detat(i,j+1))
     &                      -(detat(i+1,j)+detat(i,j))
# else
              pressgradu2 = (detat(i+1,j+1)-detat(i+1,j))
#  if defined coast
     &                       *min(landt(i+1,j+1),landt(i+1,j))
#  endif
     &                      + (detat(i,j+1)-detat(i,j))
#  if defined coast
     &                       *min(landt(i,j+1),landt(i,j))
#  endif
# endif
              pressgradu2 = fac*pressgradu2*dyu2r(j)
c     
              pressgradu = pressgradu + pressgradu2
c
# if !defined sprsnrm01 | !defined sprsnrm02
              pressgradv2 = (detat(i+1,j+1)+detat(i+1,j))
     &                      -(detat(i,j+1)+detat(i,j))
# else
              pressgradv2 = (detat(i+1,j+1)-detat(i,j+1))
#  if defined coast
     &                       *min(landt(i+1,j+1),landt(i,j+1))
#  endif
     &                      + (detat(i+1,j)-detat(i,j))
#  if defined coast
     &                       *min(landt(i+1,j),landt(i,j))
#  endif
# endif
              pressgradv2 = -fac*pressgradv2*csr(j)*dxu2r(i)
c
              pressgradv = pressgradv + pressgradv2
c
#endif
c    Combine all of the contributions:
c
#if !defined spliterr & defined smallpsdt
             fcori=c2*omega*sine(i,j)
#endif
#if defined cdbotsep & defined smallpsdt & defined small5psdt & !defined cdbotmagvsum
             uvmag=sqrt(ubarob(i,j)**2+vbarob(i,j)**2)
#  ifdef cdbotminmag
             uvmag=max(uvmag,c10)
#  endif
#  ifdef cdbotdhoh
             uvmag=uvmag*c1padhoh(i,j)
#  endif
             uvmag=uvmag*hvav(i,j)
c
#endif
#if defined smallpsdt & defined small5psdt
# if defined botfrc & defined cstfrc
             fac = faccsfrc(i,j) + fmnbtfrc(i,j)
# elif defined botfrc
             fac = fmnbtfrc(i,j)
# elif defined cstfrc
             fac = faccsfrc(i,j)
# endif
#endif
c
             frhsu=zum(i,j)-c2dtps*pressgradu
#  if defined smallpsdt & !defined small5psdt & !defined small6psdt
     &           +gammabarp*fcori*vbaro(i,j)+c2*alphap*fcori*vbarob(i,j)
#   ifdef freesurf
     &                        *fracvb(i,j)/fracv(i,j)
#   endif
#  elif defined smallpsdt & (defined small5psdt | defined small6psdt)
     &           +c2dtps*(gammabarp*fcori*vbaro(i,j)
#   ifdef small5psdt
     &                    -cdbot*ubarob(i,j)*uvmag
#   endif
     &                    +(c2*alphap*fcori*vbarob(i,j)
#   if (defined botfrc | defined cstfrc) & defined small5psdt
     &                      -fac*ubarob(i,j)
#   endif
#   if defined bndy_rlx & defined small5psdt
#    ifndef sponge_uvsplit
     &                  +vfacbrlx(i,j)*(ubar0(i,j)
#    else
     &                  +ufacbrlx(i,j)*(ubar0(i,j)
#    endif
#    if defined ext_tide & defined surfpress & defined freesurf & !defined mixtideonly
#     if !defined transspng
     &                                  + ubartd(i,j,itdb)
#     else
     &                                  + ubartd(i,j,itdb)/fracvb(i,j)
#     endif
#    endif
     &                                  - ubarob(i,j) )
#   endif
     &                     )
#   ifdef freesurf
     &                        *fracvb(i,j)/fracv(i,j)
#   endif
     &           )
#  endif
#if defined lagnonlin
     &              +uclsf(i,j)*hvav(i,j)*detav(i,j)
# if defined sprsnrm01 & defined sprsnrm02 & ! defined sprsnrm06
     &                 *uland(i,j)
# endif
#elif defined tidepredctr
     &              +uclsf(i,j)*hvav(i,j)*(srftd(i,j,itda)-etavb(i,j))
#endif
#if defined tidvforc
     &             +c2dtps*dtubartd(i,j,itd)*hdv(i,j)*hvav(i,j)
#endif
c
             frhsv=zvm(i,j)-c2dtps*pressgradv
#  if defined smallpsdt & !defined small5psdt & !defined small6psdt
     &           -gammabarp*fcori*ubaro(i,j)-c2*alphap*fcori*ubarob(i,j)
#   ifdef freesurf
     &                  *fracvb(i,j)/fracv(i,j)
#   endif
#  elif defined smallpsdt & (defined small5psdt | defined small6psdt)
     &           -c2dtps*(gammabarp*fcori*ubaro(i,j)
#   ifdef small5psdt
     &                    +cdbot*vbarob(i,j)*uvmag
#   endif
     &                    +(c2*alphap*fcori*ubarob(i,j)
#   if (defined botfrc | defined cstfrc) & defined small5psdt
     &                      +fac*vbarob(i,j)
#   endif
#   if defined bndy_rlx & defined small5psdt
     &                  -vfacbrlx(i,j)*(vbar0(i,j)
#    if defined ext_tide & defined surfpress & defined freesurf & !defined mixtideonly
#     if !defined transspng
     &                                  + vbartd(i,j,itdb)
#     else
     &                                  + vbartd(i,j,itdb)/fracvb(i,j)
#     endif
#    endif
     &                                  - vbarob(i,j) )
#   endif
     &                     )
#   ifdef freesurf
     &                  *fracvb(i,j)/fracv(i,j)
#   endif
     &           )
#  endif
#if defined lagnonlin
     &              +vclsf(i,j)*hvav(i,j)*detav(i,j)
# if defined sprsnrm01 & defined sprsnrm02 & ! defined sprsnrm06
     &                 *vland(i,j)
# endif
#elif defined tidepredctr
     &              +vclsf(i,j)*hvav(i,j)*(srftd(i,j,itda)-etavb(i,j))
#endif
#if defined tidvforc
     &             +c2dtps*dtvbartd(i,j,itd)*hdv(i,j)*hvav(i,j)
#endif
c
c    Get Coriolis and inversion parameters:
c
#if !defined spliterr & !defined smallpsdt
             fcori=c2*omega*sine(i,j)
#endif
             ww=alphap*fcori*c2dtps
c
c    Invert 2x2 matrix to get uhat and vhat velocities:
c
             ubarhat(i,j)=(+frhsu+ww*frhsv)/(c1+ww*ww)
# if defined sprsnrm01 & defined sprsnrm02
     &                     *uland(i,j)
# endif
     &                       +ubarob(i,j)
             vbarhat(i,j)=(-ww*frhsu+frhsv)/(c1+ww*ww)
# if defined sprsnrm01 & defined sprsnrm02
     &                     *vland(i,j)
# endif
     &                       +vbarob(i,j)
c
#ifdef divdump
            if (dmpcnt.eq.dmptim) then
               pgrdx(i,j) =-c2dtps*(pressgradu+ww*pressgradv)/(c1+ww*ww)
               pgrdy(i,j) = c2dtps*(ww*pressgradu-pressgradv)/(c1+ww*ww)
               rhsx(i,j)  = (zum(i,j)+ww*zvm(i,j))/(c1+ww*ww)
               rhsy(i,j)  = (-ww*zum(i,j)+zvm(i,j))/(c1+ww*ww)
            endif
#endif
  10     continue
#ifdef coast
  20     continue
#endif
  30  continue
c
#if defined uvhattdbc & defined ext_tide
c-----------------------------------------------------------------------
c  Apply boundary conditions directly to the augmented velocities.
c-----------------------------------------------------------------------
c
      call bdy_tide_uhat
c
#elif defined uvhatcpbc
c-----------------------------------------------------------------------
c  Apply 1pt copy boundary conditions directly to the augmented velocities.
c-----------------------------------------------------------------------
c
      do 33, j = 1, jmtm1
         ubarhat(1,j)  =ubarhat(2,j)
         ubarhat(imu,j)=ubarhat(imum1,j)
         vbarhat(1,j)  =vbarhat(2,j)
         vbarhat(imu,j)=vbarhat(imum1,j)
  33  continue
c
      do 37, i = 1, imu
         ubarhat(i,1)    =ubarhat(i,2)
         ubarhat(i,jmtm1)=ubarhat(i,jmt-2)
         vbarhat(i,1)    =vbarhat(i,2)
         vbarhat(i,jmtm1)=vbarhat(i,jmt-2)
  37  continue
c
#endif
#ifdef divdump
      if (dmpcnt.eq.dmptim) then
         open (413, file='scalars_uhat.dat', status='unknown')
         write (413,*) gammabar
         write (413,*) c2dtps
         write (413,*) alphap
         close(413)
         open (413, file='p.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) p(i,j)
            enddo
         enddo
         close(413)
         open (413, file='pb.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) pb(i,j)
            enddo
         enddo
         close(413)
         open (413, file='pgrdx.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) pgrdx(i,j)
            enddo
         enddo
         close(413)
         open (413, file='pgrdy.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) pgrdy(i,j)
            enddo
         enddo
         close(413)
         open (413, file='rhsx.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) rhsx(i,j)
            enddo
         enddo
         close(413)
         open (413, file='rhsy.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) rhsy(i,j)
            enddo
         enddo
         close(413)
         open (413, file='ubarb.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) ubarob(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vbarb.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vbarob(i,j)
            enddo
         enddo
         close(413)
         open (413, file='uhatunflt.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) ubarhat(i,j)
            enddo
         enddo
         close(413)
         open (413, file='vhatunflt.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) vbarhat(i,j)
            enddo
         enddo
         close(413)
         open (413, file='fkmq.dat', status='unknown')
         do j = 1, jmt
            do i = 1, imt
               write (413,*) fkmq(i,j)
            enddo
         enddo
         close(413)
# ifdef sunflush
         call flush (413)
# endif
      endif
#endif
#ifdef shapiro
c-----------------------------------------------------------------------
c  If applicable, Shapiro filter the 2-d horizontal vertical averaged
c  modified accelerations
c-----------------------------------------------------------------------
c
c       ICNTZ = counter (for frequency of application)
c       NFRQZ = frequency with which filter is applied
c       NTIMZ = number of times filter is applied per time step
c       NORDZ = order of the filter
c
#if !defined nest2larger & !defined nest2smaller
      if ((mixztd.eq.1).and.(nordz.ne.0)) then
#else
      entry uvhatflt (filtflag)
c
      if ((mixztd.eq.1).and.(nordz.ne.0).and.(filtflag.eq.'Filter'))then
#endif
         icntz=icntz+1
         if (icntz.eq.nfrqz) then
            icntz=0
#if defined filtduvhat
            do 39, j = 1, jmt
            do 39, i = 1, imt
               ubarhat(i,j) = ubarhat(i,j) - ubarob(i,j)
               vbarhat(i,j) = vbarhat(i,j) - vbarob(i,j)
  39        continue
#endif
            do 40 nn=1,ntimz
#if !defined sprsnrm07
               call shap_lev(ubarhat,imu,jmtm1,hgrid,nordz)
               call shap_lev(vbarhat,imu,jmtm1,hgrid,nordz)
#else
               call shap_levb(ubarhat,imu,jmtm1,isu,ieu,jsu,jeu,nordz)
               call shap_levb(vbarhat,imu,jmtm1,isv,iev,jsv,jev,nordz)
#endif
  40        continue
#if defined filtduvhat
            do 41, j = 1, jmt
            do 41, i = 1, imt
               ubarhat(i,j) = ubarhat(i,j) + ubarob(i,j)
               vbarhat(i,j) = vbarhat(i,j) + vbarob(i,j)
  41        continue
#endif
#if defined filtduvhat2
            do 42 nn=1,ntimv
# if !defined sprsnrm07
               call shap_lev(ubarhat,imu,jmtm1,vgrid,nordv)
               call shap_lev(vbarhat,imu,jmtm1,vgrid,nordv)
# else
               call shap_levb(ubarhat,imu,jmtm1,isu,ieu,jsu,jeu,nordv)
               call shap_levb(vbarhat,imu,jmtm1,isv,iev,jsv,jev,nordv)
# endif
  42        continue
#endif
c
# if !defined cyclic & !defined filtduvhat3
c  Why this next section?
c
c          if ((iopt(4).ne.7).and.(iopt(4).ne.1)) then
            ubarhat(1,1)=p5*ubarhat(1,2)+p5*ubarhat(2,1)
            ubarhat(imu,1)=p5*ubarhat(imum1,1)+p5*ubarhat(imu,2)
            ubarhat(1,jmtm1)=p5*ubarhat(1,jmtm2)+p5*ubarhat(2,jmtm1)
            ubarhat(imu,jmtm1)=p5*ubarhat(imu,jmtm2)+
     *                         p5*ubarhat(imum1,jmtm1)
            vbarhat(1,1)=p5*vbarhat(1,2)+p5*vbarhat(2,1)
            vbarhat(imu,1)=p5*vbarhat(imum1,1)+p5*vbarhat(imu,2)
            vbarhat(1,jmtm1)=p5*vbarhat(1,jmtm2)+p5*vbarhat(2,jmtm1)
            vbarhat(imu,jmtm1)=p5*vbarhat(imu,jmtm2)+
     *                         p5*vbarhat(imum1,jmtm1)
c          endif
c
# endif
         endif
#if defined filtduvhat3
         icntz2=icntz2+1
         if (icntz2.eq.nfrqz2) then
            icntz2=0
            do 46 nn=1,ntimz2
#if !defined sprsnrm07
               call shap_lev(ubarhat,imu,jmtm1,hgrid,nordz2)
               call shap_lev(vbarhat,imu,jmtm1,hgrid,nordz2)
#else
               call shap_levb(ubarhat,imu,jmtm1,isu,ieu,jsu,jeu,nordz2)
               call shap_levb(vbarhat,imu,jmtm1,isv,iev,jsv,jev,nordz2)
#endif
  46        continue
# if !defined cyclic
c  Why this next section?
c
c          if ((iopt(4).ne.7).and.(iopt(4).ne.1)) then
            ubarhat(1,1)=p5*ubarhat(1,2)+p5*ubarhat(2,1)
            ubarhat(imu,1)=p5*ubarhat(imum1,1)+p5*ubarhat(imu,2)
            ubarhat(1,jmtm1)=p5*ubarhat(1,jmtm2)+p5*ubarhat(2,jmtm1)
            ubarhat(imu,jmtm1)=p5*ubarhat(imu,jmtm2)+
     *                         p5*ubarhat(imum1,jmtm1)
            vbarhat(1,1)=p5*vbarhat(1,2)+p5*vbarhat(2,1)
            vbarhat(imu,1)=p5*vbarhat(imum1,1)+p5*vbarhat(imu,2)
            vbarhat(1,jmtm1)=p5*vbarhat(1,jmtm2)+p5*vbarhat(2,jmtm1)
            vbarhat(imu,jmtm1)=p5*vbarhat(imu,jmtm2)+
     *                         p5*vbarhat(imum1,jmtm1)
c          endif
c
# endif
         endif
#endif
      endif
c
#endif
#ifdef cyclic
c-----------------------------------------------------------------------
c  Set Cyclic boundary conditions.
c-----------------------------------------------------------------------
c
      do 50 j=1,jmt
        ubarhat(1  ,j)=ubarhat(imtm1,j)
        vbarhat(1  ,j)=vbarhat(imtm1,j)
        ubarhat(imt,j)=ubarhat(2    ,j)
        vbarhat(imt,j)=vbarhat(2    ,j)
  50  continue
c
#endif
      return
      end
