c
c=======================================================================
c  Include file "vertslabs.h"
c=======================================================================
#ifndef rmdocinc
c
# ifdef analytical
c  BTDEPTH    depth of the middle of the tracer vertical box at the
c             domain boundary.
c  BVDEPTH    depth of the middle of the velocity vertical box at the
c             domain boundary.
# endif
c  DZQZ       vertical thickness of the tracer box.
c  DZ2RQZ     reciprocal of 2 times DZQZ.
c  DZVQZ      vertical thickness of the velocity box.
c  DZV2RQZ    reciprocal of 2 times DZVQZ.
c  DZZQZ      vertical grid spacing between tracer points.
c  DZZ2RQZ    reciprocal of 2 times DZZQZ.
c  DZZVQZ     vertical grid spacing between velocity points.
c  HD         bottom topography at the tracer points.
c  HDV        bottom topography at the velocity points.
# if defined surfpress | defined stream9pt
c  HDVC       weighted  bottom topography at the velocity points.
# endif
# if defined surfpress & defined freesurf
c  HDVCF      weighted  bottom topography at the velocity points 
c             with respect to mean free surface.
c  HDVBF      HDVCF at the previous time step.
# endif
# if defined surfpress & defined freesurf
c  HTAV       reciprocal thickness, tracer points.
# endif
c  HVAV       reciprocal of total thickness at the velocity points.
# if defined surfpress & defined freesurf & (defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx))
c  HVAVB      reciprocal of total thickness at the velocity points (prev time).
# endif
c  JRN        rolling index for the north face of the T,U,V box.
c  JRNP1      rolling index for the row above the north face of the
c             T,U,V box.
c  IORD       order of horizontal operators (second or forth order).
c  JRS        rolling index for the south face of the T,U,V box
c  JRSM1      rolling index for the row below the south face of the
c             T,U,V box.
c  TDEPTH     depth at the center of the tracer vertical box.
c  VDEPTH     depth at the center of the velocity vertical box.
#if defined ext_tide & defined advtide
c  USTRETCH   stretch factor of vertical at  u-points.
c  TSTRETCH   stretch factor of vertical at  t-points.
#endif
c
c  The third dimension in arrays TDEPTH and VDEPTH corresponds to
c  the following indices according to the horizontal operator used:
c
c    Index       Tracer box       Velocity box      Order
c
c    JRNP1        J+2 slab          J+1 slab       4th only
c    JRN          J+1 slab          J   slab       2nd & 4th
c    JRS          J   slab          J-1 slab       2nd & 4th
c    JRSM1        J-1 slab          J-2 slab       4th only
c
c  The third dimension in the vertical grid spacing and thicknesses
c  arrays corresponds to the following slabs:
c
c    Index       Tracer box       Velocity box
c
c     0           J   slab          J   slab
c     1           J+1 slab          J-1 slab
c
c=======================================================================
#endif
c
      integer iord,iordm1
#if defined hpg4 | !defined shapiro
      parameter (iord=4,iordm1=iord-1)
#else
      parameter (iord=2,iordm1=iord-1)
#endif
#ifndef analytical
      common /ivertslab/ jrsm1,jrs,jrn,jrnp1
      integer jrn,jrnp1,jrs,jrsm1
c
      common /fvertslab/ hd,hdv,hvav,dzqz,dz2rqz,dzvqz,
     *       dzv2rqz,dzzqz,dzz2rqz,dzzvqz,tdepth,vdepth
# if defined ext_tide & defined advtide
     *       ,ustretch,tstretch
# endif
# if defined stream9pt | defined surfpress
     *       ,hdvc
# endif
# if defined freesurf & defined surfpress 
     *       ,hdvcf,dzvqzb,htav
#  if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
     *       ,hvavb
#  endif
     *       ,hdvbf
# endif
# if defined surfpress & defined sprsnrm01
     &                ,uland,vland,hdvcfx,hdvcfy
#  if defined sprsnrm04
     &       ,ugdwt,vgdwt
#  endif
#  if defined sprsnrm05
     &       ,hdvbfx,hdvbfy
#  endif
# endif
      FLOAT 
     *      dzqz(imt,km,0:1),dz2rqz(imt,km,0:1),dzvqz(imt,km,0:1),
     *      dzv2rqz(imt,km),dzzqz(imt,kmp1,0:1),dzz2rqz (imt,km,0:1),
     *      dzzvqz(imt,kmp1,0:1),hd(imt,jmt),hdv(imt,jmt),hvav(imt,jmt),
     *      tdepth(imt,km,0:iordm1),vdepth(imt,km,0:iordm1)
# if defined ext_tide & defined advtide
     *       ,ustretch(imt,jmt),tstretch(imt,jmt)
# endif
# if defined stream9pt | defined surfpress
     *       ,hdvc(imt,jmt)
# endif
# if defined freesurf & defined surfpress 
     *       ,hdvcf(imt,jmt),dzvqzb(imt,km,0:1),htav(imt,jmt)
#  if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
     *       ,hvavb(imt,jmt)
#  endif
     *       ,hdvbf(imt,jmt)
# endif
# if defined surfpress & defined sprsnrm01
     &      ,uland(imt,jmt),vland(imt,jmt),hdvcfx(imt,jmt),
     &       hdvcfy(imt,jmt)
#  if defined sprsnrm04
     &       ,ugdwt(imt,jmt),vgdwt(imt,jmt)
#  endif
#  if defined sprsnrm05
     &       ,hdvbfx(imt,jmt),hdvbfy(imt,jmt)
#  endif
# endif
#else
      common /ivertslab/ jrsm1,jrs,jrn,jrnp1
      integer jrn,jrnp1,jrs,jrsm1
c
      common /fvertslab/ hd,hdv,hvav,dzqz,dz2rqz,dzvqz,
     *       dzv2rqz,dzzqz,dzz2rqz,dzzvqz,tdepth,vdepth,btdepth,
     *       bvdepth
# if defined ext_tide & defined advtide
     *       ,ustretch,tstretch
# endif
# if defined stream9pt | defined surfpress
     *       ,hdvc
# endif
# if defined freesurf & defined surfpress 
     *       ,hdvcf,dzvqzb,htav
#  if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
     *       ,hvavb
#  endif
# endif
# if defined surfpress & defined sprsnrm01
     &                ,uland,vland,hdvcfx,hdvcfy
#  if defined sprsnrm04
     &       ,ugdwt,vgdwt
#  endif
#  if defined sprsnrm05
     &       ,hdvbfx,hdvbfy
#  endif
# endif
      FLOAT 
     *      dzqz(imt,km,0:1),dz2rqz(imt,km,0:1),dzvqz(imt,km,0:1),
     *      dzv2rqz(imt,km),dzzqz(imt,kmp1,0:1),dzz2rqz (imt,km,0:1),
     *      dzzvqz(imt,kmp1,0:1),hd(imt,jmt),hdv(imt,jmt),hvav(imt,jmt),
     *      tdepth(imt,km,0:iordm1),vdepth(imt,km,0:iordm1),
     *      btdepth(ijmx,km,4),bvdepth(ijmx,km,4)
# if defined ext_tide & defined advtide
     *       ,ustretch(imt,jmt),tstretch(imt,jmt)
# endif
# if defined stream9pt | defined surfpress
     *       ,hdvc(0:imt+1,0:jmt+1)
# endif
# if defined freesurf & defined surfpress 
     *       ,hdvcf(0:imt+1,0:jmt+1),dzvqzb(imt,km,0:1),htav(imt,jmt)
#  if defined oias | (defined nest2larger & defined spongenest & defined bndy_rlx)
     *       ,hvavb(imt,jmt)
#  endif
# endif
# if defined surfpress & defined sprsnrm01
     &      ,uland(imt,jmt),vland(imt,jmt),hdvcfx(imt,jmt),
     &       hdvcfy(imt,jmt)
#  if defined sprsnrm04
     &       ,ugdwt(imt,jmt),vgdwt(imt,jmt)
#  endif
#  if defined sprsnrm05
     &       ,hdvbfx(imt,jmt),hdvbfy(imt,jmt)
#  endif
# endif
#endif
